# This file is automatically generated. Do not modify it manually!
from functools import lru_cache
import numpy as np

from .config import cond
from .OneLoop import B0fin, B0del
from .T134 import T134fin


@lru_cache(maxsize=150)
def T113344(m1: float, m2: float, m3: float, m4: float, m5: float, m6) -> float:
	""" Computes the UV-finite part of the T113344 integral.

	Args:
		m1: internal mass
		m2: internal mass
		m3: internal mass
		m4: internal mass
		m5: internal mass
		m6: internal mass

	Returns:
		finite part of the T113344 integral.
	"""

	try:

		m1, m2 = np.sort([m1, m2])
		m3, m4 = np.sort([m3, m4])
		m5, m6 = np.sort([m5, m6])

		m1sq = m1**2
		m2sq = m2**2
		m3sq = m3**2
		m4sq = m4**2
		m5sq = m5**2
		m6sq = m6**2

		def eval_1():
			return 0
		def eval_2():
			return (3*m6 + 2*m6*B0fin(0,0,m6) - 2*T134fin(m6,0,0))/m6**6
		def eval_3():
			return (3*m4 + 2*m4*B0fin(0,0,m4) - 2*T134fin(m4,0,0))/m4**6
		def eval_4():
			return (3*m2 + 2*m2*B0fin(0,0,m2) - 2*T134fin(m2,0,0))/m2**6
		def eval_5():
			return (2 - 3*m3 - 4*B0fin(0,0,m3) + 2*m3*B0fin(0,0,m3sq))/(2.*m3**5)
		def eval_6():
			return (2 - 3*m1 - 4*B0fin(0,0,m1) + 2*m1*B0fin(0,0,m1sq))/(2.*m1**5)
		def eval_7():
			return (2 - 3*m1 - 4*B0fin(0,0,m1) + 2*m1*B0fin(0,0,m1sq))/(2.*m1**5)
		def eval_8():
			return (4*m3**4*m4**4*(B0del(0,0,m3sq) + B0del(0,0,m4sq) - B0fin(0,0,m3sq) - B0fin(0,0,m4sq) + B0fin(0,0,m3sq)*B0fin(0,0,m4sq)) + m3sq*(m3sq - m4sq)**2*m4sq*(6 + 2*B0del(0,0,m4sq) - 6*B0fin(0,0,m4sq) + B0fin(0,0,m4sq)**2) - 2*(-(m3sq*m4) + m4**3)**2*(m3 + 2*m3*B0fin(0,0,m3) - T134fin(m3,0,0)) + 2*(m3**3 - m3*m4sq)**2*(m4 + 2*m4*B0fin(0,0,m4) - T134fin(m4,0,0)) + 2*m3sq*m4sq*(m3sq + m4sq)*(m3 + m4 + 2*m3*B0fin(0,0,m3) + 2*m4*B0fin(0,0,m4) - T134fin(m4,m3,0)))/(2.*m3**2*m4**4*(m3sq - m4sq)**3)
		def eval_9():
			return -0.5*(m3sq*(m3sq - m4sq)**2*m4sq*(6 + 2*B0del(0,0,m3sq) - 6*B0fin(0,0,m3sq) + B0fin(0,0,m3sq)**2) + 4*m3**4*m4**4*(B0del(0,0,m3sq) + B0del(0,0,m4sq) - B0fin(0,0,m3sq) - B0fin(0,0,m4sq) + B0fin(0,0,m3sq)*B0fin(0,0,m4sq)) + 2*(-(m3sq*m4) + m4**3)**2*(m3 + 2*m3*B0fin(0,0,m3) - T134fin(m3,0,0)) - 2*(m3**3 - m3*m4sq)**2*(m4 + 2*m4*B0fin(0,0,m4) - T134fin(m4,0,0)) + 2*m3sq*m4sq*(m3sq + m4sq)*(m3 + m4 + 2*m3*B0fin(0,0,m3) + 2*m4*B0fin(0,0,m4) - T134fin(m4,m3,0)))/(m3**4*m4**2*(m3sq - m4sq)**3)
		def eval_10():
			return (4*m1**4*m2**4*(B0del(0,0,m1sq) + B0del(0,0,m2sq) - B0fin(0,0,m1sq) - B0fin(0,0,m2sq) + B0fin(0,0,m1sq)*B0fin(0,0,m2sq)) + m1sq*(m1sq - m2sq)**2*m2sq*(6 + 2*B0del(0,0,m2sq) - 6*B0fin(0,0,m2sq) + B0fin(0,0,m2sq)**2) - 2*(-(m1sq*m2) + m2**3)**2*(m1 + 2*m1*B0fin(0,0,m1) - T134fin(m1,0,0)) + 2*(m1**3 - m1*m2sq)**2*(m2 + 2*m2*B0fin(0,0,m2) - T134fin(m2,0,0)) + 2*m1sq*m2sq*(m1sq + m2sq)*(m1 + m2 + 2*m1*B0fin(0,0,m1) + 2*m2*B0fin(0,0,m2) - T134fin(m2,m1,0)))/(2.*m1**2*m2**4*(m1sq - m2sq)**3)
		def eval_11():
			return (4*m1**4*m2**4*(B0del(0,0,m1sq) + B0del(0,0,m2sq) - B0fin(0,0,m1sq) - B0fin(0,0,m2sq) + B0fin(0,0,m1sq)*B0fin(0,0,m2sq)) + m1sq*(m1sq - m2sq)**2*m2sq*(6 + 2*B0del(0,0,m2sq) - 6*B0fin(0,0,m2sq) + B0fin(0,0,m2sq)**2) - 2*(-(m1sq*m2) + m2**3)**2*(m1 + 2*m1*B0fin(0,0,m1) - T134fin(m1,0,0)) + 2*(m1**3 - m1*m2sq)**2*(m2 + 2*m2*B0fin(0,0,m2) - T134fin(m2,0,0)) + 2*m1sq*m2sq*(m1sq + m2sq)*(m1 + m2 + 2*m1*B0fin(0,0,m1) + 2*m2*B0fin(0,0,m2) - T134fin(m2,m1,0)))/(2.*m1**2*m2**4*(m1sq - m2sq)**3)
		def eval_12():
			return -0.5*(m1sq*(m1sq - m2sq)**2*m2sq*(6 + 2*B0del(0,0,m1sq) - 6*B0fin(0,0,m1sq) + B0fin(0,0,m1sq)**2) + 4*m1**4*m2**4*(B0del(0,0,m1sq) + B0del(0,0,m2sq) - B0fin(0,0,m1sq) - B0fin(0,0,m2sq) + B0fin(0,0,m1sq)*B0fin(0,0,m2sq)) + 2*(-(m1sq*m2) + m2**3)**2*(m1 + 2*m1*B0fin(0,0,m1) - T134fin(m1,0,0)) - 2*(m1**3 - m1*m2sq)**2*(m2 + 2*m2*B0fin(0,0,m2) - T134fin(m2,0,0)) + 2*m1sq*m2sq*(m1sq + m2sq)*(m1 + m2 + 2*m1*B0fin(0,0,m1) + 2*m2*B0fin(0,0,m2) - T134fin(m2,m1,0)))/(m1**4*m2**2*(m1sq - m2sq)**3)
		def eval_13():
			return -0.5*(m1sq*(m1sq - m2sq)**2*m2sq*(6 + 2*B0del(0,0,m1sq) - 6*B0fin(0,0,m1sq) + B0fin(0,0,m1sq)**2) + 4*m1**4*m2**4*(B0del(0,0,m1sq) + B0del(0,0,m2sq) - B0fin(0,0,m1sq) - B0fin(0,0,m2sq) + B0fin(0,0,m1sq)*B0fin(0,0,m2sq)) + 2*(-(m1sq*m2) + m2**3)**2*(m1 + 2*m1*B0fin(0,0,m1) - T134fin(m1,0,0)) - 2*(m1**3 - m1*m2sq)**2*(m2 + 2*m2*B0fin(0,0,m2) - T134fin(m2,0,0)) + 2*m1sq*m2sq*(m1sq + m2sq)*(m1 + m2 + 2*m1*B0fin(0,0,m1) + 2*m2*B0fin(0,0,m2) - T134fin(m2,m1,0)))/(m1**4*m2**2*(m1sq - m2sq)**3)
		def eval_14():
			return (1 - 3*B0fin(0,0,m3sq))/(9.*m3**4)
		def eval_15():
			return (1 - 3*B0fin(0,0,m1sq))/(9.*m1**4)
		def eval_16():
			return (-6*m1 - 6*m1sq*B0del(0,0,m1sq) - 12*m1*B0fin(0,0,m1) + 6*m1sq*B0fin(0,0,m1sq) - 3*m1sq*B0fin(0,0,m1sq)**2 + 3*T134fin(m1,0,0) + T134fin(m1,m1,m1))/(3.*m1**6)
		def eval_17():
			return (1 - 3*B0fin(0,0,m1sq))/(9.*m1**4)
		def eval_18():
			return ((m3sq - m4sq)**3*(6 - 4*B0fin(0,0,m4sq)) - 2*m3sq*m4sq*(8*m4sq - 2*(m3sq + m4sq)*B0del(0,0,m3sq) - 2*(m3sq + m4sq)*B0del(0,0,m4sq) + 2*(m3sq - 3*m4sq)*B0fin(0,0,m3sq) - (-2*m3sq + 6*m4sq + 2*(m3sq + m4sq)*B0fin(0,0,m3sq))*B0fin(0,0,m4sq)) + 4*m4sq*(2*(m3 + m4)*(m3sq + m4sq) + (m3sq - m4sq)*(m3 + m4 + 2*m3*B0fin(0,0,m3) + 2*m4*B0fin(0,0,m4)) - 2*m3sq*T134fin(m4,m3,0)))/(4.*m4**2*(m3sq - m4sq)**4)
		def eval_19():
			return -0.5*((m3sq - m4sq)**2*(6 + 2*B0del(0,0,m3sq) - 6*B0fin(0,0,m3sq) + B0fin(0,0,m3sq)**2) + 8*m3sq*m4sq*(B0del(0,0,m3sq) + B0del(0,0,m4sq) - B0fin(0,0,m3sq) - B0fin(0,0,m4sq) + B0fin(0,0,m3sq)*B0fin(0,0,m4sq)) + (m3sq - m4sq)**2*(6 + 2*B0del(0,0,m4sq) - 6*B0fin(0,0,m4sq) + B0fin(0,0,m4sq)**2) + 4*(m3sq + m4sq)*(m3 + m4 + 2*m3*B0fin(0,0,m3) + 2*m4*B0fin(0,0,m4) - T134fin(m4,m3,0)))/(m3sq - m4sq)**4
		def eval_20():
			return (8*(m3 + m6)*(m3sq + m6sq) + ((m3sq - m6sq)**3*(-6 + 4*B0fin(0,0,m3sq)))/m3**2 + 4*(-m3sq + m6sq)*(m3 + m6 + 2*m3*B0fin(0,0,m3) + 2*m6*B0fin(0,0,m6)) + 2*m6sq*(-8*m3sq + 2*(m3sq + m6sq)*B0del(0,0,m3sq) + 2*(m3sq + m6sq)*B0del(0,0,m6sq) + 2*(3*m3sq - m6sq)*B0fin(0,0,m3sq) + (6*m3sq - 2*m6sq + 2*(m3sq + m6sq)*B0fin(0,0,m3sq))*B0fin(0,0,m6sq)) - 8*m6sq*T134fin(m6,m3,0))/(4.*(m3sq - m6sq)**4)
		def eval_21():
			return (8*(m3 + m4)*(m3sq + m4sq) + ((m3sq - m4sq)**3*(-6 + 4*B0fin(0,0,m3sq)))/m3**2 + 4*(-m3sq + m4sq)*(m3 + m4 + 2*m3*B0fin(0,0,m3) + 2*m4*B0fin(0,0,m4)) + 2*m4sq*(-8*m3sq + 2*(m3sq + m4sq)*B0del(0,0,m3sq) + 2*(m3sq + m4sq)*B0del(0,0,m4sq) + 2*(3*m3sq - m4sq)*B0fin(0,0,m3sq) + (6*m3sq - 2*m4sq + 2*(m3sq + m4sq)*B0fin(0,0,m3sq))*B0fin(0,0,m4sq)) - 8*m4sq*T134fin(m4,m3,0))/(4.*(m3sq - m4sq)**4)
		def eval_22():
			return ((m1sq - m2sq)**3*(6 - 4*B0fin(0,0,m2sq)) - 2*m1sq*m2sq*(8*m2sq - 2*(m1sq + m2sq)*B0del(0,0,m1sq) - 2*(m1sq + m2sq)*B0del(0,0,m2sq) + 2*(m1sq - 3*m2sq)*B0fin(0,0,m1sq) - (-2*m1sq + 6*m2sq + 2*(m1sq + m2sq)*B0fin(0,0,m1sq))*B0fin(0,0,m2sq)) + 4*m2sq*(2*(m1 + m2)*(m1sq + m2sq) + (m1sq - m2sq)*(m1 + m2 + 2*m1*B0fin(0,0,m1) + 2*m2*B0fin(0,0,m2)) - 2*m1sq*T134fin(m2,m1,0)))/(4.*m2**2*(m1sq - m2sq)**4)
		def eval_23():
			return ((m1sq - m2sq)**3*(6 - 4*B0fin(0,0,m2sq)) - 2*m1sq*m2sq*(8*m2sq - 2*(m1sq + m2sq)*B0del(0,0,m1sq) - 2*(m1sq + m2sq)*B0del(0,0,m2sq) + 2*(m1sq - 3*m2sq)*B0fin(0,0,m1sq) - (-2*m1sq + 6*m2sq + 2*(m1sq + m2sq)*B0fin(0,0,m1sq))*B0fin(0,0,m2sq)) + 4*m2sq*(2*(m1 + m2)*(m1sq + m2sq) + (m1sq - m2sq)*(m1 + m2 + 2*m1*B0fin(0,0,m1) + 2*m2*B0fin(0,0,m2)) - 2*m1sq*T134fin(m2,m1,0)))/(4.*m2**2*(m1sq - m2sq)**4)
		def eval_24():
			return -0.5*((m1sq - m2sq)**2*(6 + 2*B0del(0,0,m1sq) - 6*B0fin(0,0,m1sq) + B0fin(0,0,m1sq)**2) + 8*m1sq*m2sq*(B0del(0,0,m1sq) + B0del(0,0,m2sq) - B0fin(0,0,m1sq) - B0fin(0,0,m2sq) + B0fin(0,0,m1sq)*B0fin(0,0,m2sq)) + (m1sq - m2sq)**2*(6 + 2*B0del(0,0,m2sq) - 6*B0fin(0,0,m2sq) + B0fin(0,0,m2sq)**2) + 4*(m1sq + m2sq)*(m1 + m2 + 2*m1*B0fin(0,0,m1) + 2*m2*B0fin(0,0,m2) - T134fin(m2,m1,0)))/(m1sq - m2sq)**4
		def eval_25():
			return -0.5*((m1sq - m2sq)**2*(6 + 2*B0del(0,0,m1sq) - 6*B0fin(0,0,m1sq) + B0fin(0,0,m1sq)**2) + 8*m1sq*m2sq*(B0del(0,0,m1sq) + B0del(0,0,m2sq) - B0fin(0,0,m1sq) - B0fin(0,0,m2sq) + B0fin(0,0,m1sq)*B0fin(0,0,m2sq)) + (m1sq - m2sq)**2*(6 + 2*B0del(0,0,m2sq) - 6*B0fin(0,0,m2sq) + B0fin(0,0,m2sq)**2) + 4*(m1sq + m2sq)*(m1 + m2 + 2*m1*B0fin(0,0,m1) + 2*m2*B0fin(0,0,m2) - T134fin(m2,m1,0)))/(m1sq - m2sq)**4
		def eval_26():
			return (8*(m1 + m6)*(m1sq + m6sq) + ((m1sq - m6sq)**3*(-6 + 4*B0fin(0,0,m1sq)))/m1**2 + 4*(-m1sq + m6sq)*(m1 + m6 + 2*m1*B0fin(0,0,m1) + 2*m6*B0fin(0,0,m6)) + 2*m6sq*(-8*m1sq + 2*(m1sq + m6sq)*B0del(0,0,m1sq) + 2*(m1sq + m6sq)*B0del(0,0,m6sq) + 2*(3*m1sq - m6sq)*B0fin(0,0,m1sq) + (6*m1sq - 2*m6sq + 2*(m1sq + m6sq)*B0fin(0,0,m1sq))*B0fin(0,0,m6sq)) - 8*m6sq*T134fin(m6,m1,0))/(4.*(m1sq - m6sq)**4)
		def eval_27():
			return (8*(m1 + m4)*(m1sq + m4sq) + ((m1sq - m4sq)**3*(-6 + 4*B0fin(0,0,m1sq)))/m1**2 + 4*(-m1sq + m4sq)*(m1 + m4 + 2*m1*B0fin(0,0,m1) + 2*m4*B0fin(0,0,m4)) + 2*m4sq*(-8*m1sq + 2*(m1sq + m4sq)*B0del(0,0,m1sq) + 2*(m1sq + m4sq)*B0del(0,0,m4sq) + 2*(3*m1sq - m4sq)*B0fin(0,0,m1sq) + (6*m1sq - 2*m4sq + 2*(m1sq + m4sq)*B0fin(0,0,m1sq))*B0fin(0,0,m4sq)) - 8*m4sq*T134fin(m4,m1,0))/(4.*(m1sq - m4sq)**4)
		def eval_28():
			return (8*(m1 + m2)*(m1sq + m2sq) + ((m1sq - m2sq)**3*(-6 + 4*B0fin(0,0,m1sq)))/m1**2 + 4*(-m1sq + m2sq)*(m1 + m2 + 2*m1*B0fin(0,0,m1) + 2*m2*B0fin(0,0,m2)) + 2*m2sq*(-8*m1sq + 2*(m1sq + m2sq)*B0del(0,0,m1sq) + 2*(m1sq + m2sq)*B0del(0,0,m2sq) + 2*(3*m1sq - m2sq)*B0fin(0,0,m1sq) + (6*m1sq - 2*m2sq + 2*(m1sq + m2sq)*B0fin(0,0,m1sq))*B0fin(0,0,m2sq)) - 8*m2sq*T134fin(m2,m1,0))/(4.*(m1sq - m2sq)**4)
		def eval_29():
			return (8*(m1 + m2)*(m1sq + m2sq) + ((m1sq - m2sq)**3*(-6 + 4*B0fin(0,0,m1sq)))/m1**2 + 4*(-m1sq + m2sq)*(m1 + m2 + 2*m1*B0fin(0,0,m1) + 2*m2*B0fin(0,0,m2)) + 2*m2sq*(-8*m1sq + 2*(m1sq + m2sq)*B0del(0,0,m1sq) + 2*(m1sq + m2sq)*B0del(0,0,m2sq) + 2*(3*m1sq - m2sq)*B0fin(0,0,m1sq) + (6*m1sq - 2*m2sq + 2*(m1sq + m2sq)*B0fin(0,0,m1sq))*B0fin(0,0,m2sq)) - 8*m2sq*T134fin(m2,m1,0))/(4.*(m1sq - m2sq)**4)
		def eval_30():
			return (4*m3sq*(m4sq - m6sq)**3*(m3**4 - m4sq*m6sq)*B0del(0,0,m3sq) + 4*m3sq*m4sq*(m3sq - m6sq)**2*(m4sq - m6sq)**2*(B0del(0,0,m4sq) - B0fin(0,0,m4sq)) + (m3sq - m4sq)**2*(m3sq - m6sq)**2*(m4sq - m6sq)**2*(6 + 2*B0del(0,0,m4sq) - 6*B0fin(0,0,m4sq) + B0fin(0,0,m4sq)**2) - 4*m3sq*(m4sq - m6sq)**2*B0fin(0,0,m3sq)*(-(m4sq*(m3sq - m6sq)**2*(-1 + B0fin(0,0,m4sq))) + (m3sq - m4sq)**2*m6sq*(-1 + B0fin(0,0,m6sq))) - 4*m3sq*(m3sq - m4sq)**2*(m4sq - m6sq)**2*m6sq*(B0del(0,0,m6sq) - B0fin(0,0,m6sq)) + 4*(m3sq - m4sq)**2*m4sq*(m3sq - m6sq)**2*m6sq*(B0del(0,0,m4sq) + B0del(0,0,m6sq) - B0fin(0,0,m4sq) - B0fin(0,0,m6sq) + B0fin(0,0,m4sq)*B0fin(0,0,m6sq)) + 2*(m3sq + m4sq)*(m3sq - m6sq)**2*(m4sq - m6sq)**2*(m3 + m4 + 2*m3*B0fin(0,0,m3) + 2*m4*B0fin(0,0,m4) - T134fin(m4,m3,0)) - 2*(m3sq - m4sq)**2*(m4sq - m6sq)**2*(m3sq + m6sq)*(m3 + m6 + 2*m3*B0fin(0,0,m3) + 2*m6*B0fin(0,0,m6) - T134fin(m6,m3,0)) + 2*(m3sq - m4sq)**2*(m3sq - m6sq)**2*(m4sq + m6sq)*(m4 + m6 + 2*m4*B0fin(0,0,m4) + 2*m6*B0fin(0,0,m6) - T134fin(m6,m4,0)))/(2.*(m3sq - m4sq)**3*(m3sq - m6sq)**2*(m4sq - m6sq)**3)
		def eval_31():
			return -0.5*(4*m3sq*(m4sq - m6sq)**2*(m4sq*(m3sq - m6sq)**2 + (m3sq - m4sq)**2*m6sq)*B0del(0,0,m3sq) + (m3sq - m4sq)**2*(m3sq - m6sq)**2*(m4sq - m6sq)**2*(6 + 2*B0del(0,0,m3sq) - 6*B0fin(0,0,m3sq) + B0fin(0,0,m3sq)**2) + 4*m3sq*m4sq*(m3sq - m6sq)**2*(m4sq - m6sq)**2*(B0del(0,0,m4sq) - B0fin(0,0,m4sq)) - 4*m3sq*(m4sq - m6sq)**2*B0fin(0,0,m3sq)*(-(m4sq*(m3sq - m6sq)**2*(-1 + B0fin(0,0,m4sq))) - (m3sq - m4sq)**2*m6sq*(-1 + B0fin(0,0,m6sq))) + 4*m3sq*(m3sq - m4sq)**2*(m4sq - m6sq)**2*m6sq*(B0del(0,0,m6sq) - B0fin(0,0,m6sq)) - 4*(m3sq - m4sq)**2*m4sq*(m3sq - m6sq)**2*m6sq*(B0del(0,0,m4sq) + B0del(0,0,m6sq) - B0fin(0,0,m4sq) - B0fin(0,0,m6sq) + B0fin(0,0,m4sq)*B0fin(0,0,m6sq)) + 2*(m3sq + m4sq)*(m3sq - m6sq)**2*(m4sq - m6sq)**2*(m3 + m4 + 2*m3*B0fin(0,0,m3) + 2*m4*B0fin(0,0,m4) - T134fin(m4,m3,0)) + 2*(m3sq - m4sq)**2*(m4sq - m6sq)**2*(m3sq + m6sq)*(m3 + m6 + 2*m3*B0fin(0,0,m3) + 2*m6*B0fin(0,0,m6) - T134fin(m6,m3,0)) - 2*(m3sq - m4sq)**2*(m3sq - m6sq)**2*(m4sq + m6sq)*(m4 + m6 + 2*m4*B0fin(0,0,m4) + 2*m6*B0fin(0,0,m6) - T134fin(m6,m4,0)))/((m3sq - m4sq)**3*(m3sq - m6sq)**3*(m4sq - m6sq)**2)
		def eval_32():
			return (4*m1sq*(m2sq - m6sq)**3*(m1**4 - m2sq*m6sq)*B0del(0,0,m1sq) + 4*m1sq*m2sq*(m1sq - m6sq)**2*(m2sq - m6sq)**2*(B0del(0,0,m2sq) - B0fin(0,0,m2sq)) + (m1sq - m2sq)**2*(m1sq - m6sq)**2*(m2sq - m6sq)**2*(6 + 2*B0del(0,0,m2sq) - 6*B0fin(0,0,m2sq) + B0fin(0,0,m2sq)**2) - 4*m1sq*(m2sq - m6sq)**2*B0fin(0,0,m1sq)*(-(m2sq*(m1sq - m6sq)**2*(-1 + B0fin(0,0,m2sq))) + (m1sq - m2sq)**2*m6sq*(-1 + B0fin(0,0,m6sq))) - 4*m1sq*(m1sq - m2sq)**2*(m2sq - m6sq)**2*m6sq*(B0del(0,0,m6sq) - B0fin(0,0,m6sq)) + 4*(m1sq - m2sq)**2*m2sq*(m1sq - m6sq)**2*m6sq*(B0del(0,0,m2sq) + B0del(0,0,m6sq) - B0fin(0,0,m2sq) - B0fin(0,0,m6sq) + B0fin(0,0,m2sq)*B0fin(0,0,m6sq)) + 2*(m1sq + m2sq)*(m1sq - m6sq)**2*(m2sq - m6sq)**2*(m1 + m2 + 2*m1*B0fin(0,0,m1) + 2*m2*B0fin(0,0,m2) - T134fin(m2,m1,0)) - 2*(m1sq - m2sq)**2*(m2sq - m6sq)**2*(m1sq + m6sq)*(m1 + m6 + 2*m1*B0fin(0,0,m1) + 2*m6*B0fin(0,0,m6) - T134fin(m6,m1,0)) + 2*(m1sq - m2sq)**2*(m1sq - m6sq)**2*(m2sq + m6sq)*(m2 + m6 + 2*m2*B0fin(0,0,m2) + 2*m6*B0fin(0,0,m6) - T134fin(m6,m2,0)))/(2.*(m1sq - m2sq)**3*(m1sq - m6sq)**2*(m2sq - m6sq)**3)
		def eval_33():
			return (4*m1sq*(m2sq - m4sq)**3*(m1**4 - m2sq*m4sq)*B0del(0,0,m1sq) + 4*m1sq*m2sq*(m1sq - m4sq)**2*(m2sq - m4sq)**2*(B0del(0,0,m2sq) - B0fin(0,0,m2sq)) + (m1sq - m2sq)**2*(m1sq - m4sq)**2*(m2sq - m4sq)**2*(6 + 2*B0del(0,0,m2sq) - 6*B0fin(0,0,m2sq) + B0fin(0,0,m2sq)**2) - 4*m1sq*(m2sq - m4sq)**2*B0fin(0,0,m1sq)*(-(m2sq*(m1sq - m4sq)**2*(-1 + B0fin(0,0,m2sq))) + (m1sq - m2sq)**2*m4sq*(-1 + B0fin(0,0,m4sq))) - 4*m1sq*(m1sq - m2sq)**2*(m2sq - m4sq)**2*m4sq*(B0del(0,0,m4sq) - B0fin(0,0,m4sq)) + 4*(m1sq - m2sq)**2*m2sq*(m1sq - m4sq)**2*m4sq*(B0del(0,0,m2sq) + B0del(0,0,m4sq) - B0fin(0,0,m2sq) - B0fin(0,0,m4sq) + B0fin(0,0,m2sq)*B0fin(0,0,m4sq)) + 2*(m1sq + m2sq)*(m1sq - m4sq)**2*(m2sq - m4sq)**2*(m1 + m2 + 2*m1*B0fin(0,0,m1) + 2*m2*B0fin(0,0,m2) - T134fin(m2,m1,0)) - 2*(m1sq - m2sq)**2*(m2sq - m4sq)**2*(m1sq + m4sq)*(m1 + m4 + 2*m1*B0fin(0,0,m1) + 2*m4*B0fin(0,0,m4) - T134fin(m4,m1,0)) + 2*(m1sq - m2sq)**2*(m1sq - m4sq)**2*(m2sq + m4sq)*(m2 + m4 + 2*m2*B0fin(0,0,m2) + 2*m4*B0fin(0,0,m4) - T134fin(m4,m2,0)))/(2.*(m1sq - m2sq)**3*(m1sq - m4sq)**2*(m2sq - m4sq)**3)
		def eval_34():
			return -0.5*(4*m1sq*(m2sq - m6sq)**2*(m2sq*(m1sq - m6sq)**2 + (m1sq - m2sq)**2*m6sq)*B0del(0,0,m1sq) + (m1sq - m2sq)**2*(m1sq - m6sq)**2*(m2sq - m6sq)**2*(6 + 2*B0del(0,0,m1sq) - 6*B0fin(0,0,m1sq) + B0fin(0,0,m1sq)**2) + 4*m1sq*m2sq*(m1sq - m6sq)**2*(m2sq - m6sq)**2*(B0del(0,0,m2sq) - B0fin(0,0,m2sq)) - 4*m1sq*(m2sq - m6sq)**2*B0fin(0,0,m1sq)*(-(m2sq*(m1sq - m6sq)**2*(-1 + B0fin(0,0,m2sq))) - (m1sq - m2sq)**2*m6sq*(-1 + B0fin(0,0,m6sq))) + 4*m1sq*(m1sq - m2sq)**2*(m2sq - m6sq)**2*m6sq*(B0del(0,0,m6sq) - B0fin(0,0,m6sq)) - 4*(m1sq - m2sq)**2*m2sq*(m1sq - m6sq)**2*m6sq*(B0del(0,0,m2sq) + B0del(0,0,m6sq) - B0fin(0,0,m2sq) - B0fin(0,0,m6sq) + B0fin(0,0,m2sq)*B0fin(0,0,m6sq)) + 2*(m1sq + m2sq)*(m1sq - m6sq)**2*(m2sq - m6sq)**2*(m1 + m2 + 2*m1*B0fin(0,0,m1) + 2*m2*B0fin(0,0,m2) - T134fin(m2,m1,0)) + 2*(m1sq - m2sq)**2*(m2sq - m6sq)**2*(m1sq + m6sq)*(m1 + m6 + 2*m1*B0fin(0,0,m1) + 2*m6*B0fin(0,0,m6) - T134fin(m6,m1,0)) - 2*(m1sq - m2sq)**2*(m1sq - m6sq)**2*(m2sq + m6sq)*(m2 + m6 + 2*m2*B0fin(0,0,m2) + 2*m6*B0fin(0,0,m6) - T134fin(m6,m2,0)))/((m1sq - m2sq)**3*(m1sq - m6sq)**3*(m2sq - m6sq)**2)
		def eval_35():
			return -0.5*(4*m1sq*(m2sq - m4sq)**2*(m2sq*(m1sq - m4sq)**2 + (m1sq - m2sq)**2*m4sq)*B0del(0,0,m1sq) + (m1sq - m2sq)**2*(m1sq - m4sq)**2*(m2sq - m4sq)**2*(6 + 2*B0del(0,0,m1sq) - 6*B0fin(0,0,m1sq) + B0fin(0,0,m1sq)**2) + 4*m1sq*m2sq*(m1sq - m4sq)**2*(m2sq - m4sq)**2*(B0del(0,0,m2sq) - B0fin(0,0,m2sq)) - 4*m1sq*(m2sq - m4sq)**2*B0fin(0,0,m1sq)*(-(m2sq*(m1sq - m4sq)**2*(-1 + B0fin(0,0,m2sq))) - (m1sq - m2sq)**2*m4sq*(-1 + B0fin(0,0,m4sq))) + 4*m1sq*(m1sq - m2sq)**2*(m2sq - m4sq)**2*m4sq*(B0del(0,0,m4sq) - B0fin(0,0,m4sq)) - 4*(m1sq - m2sq)**2*m2sq*(m1sq - m4sq)**2*m4sq*(B0del(0,0,m2sq) + B0del(0,0,m4sq) - B0fin(0,0,m2sq) - B0fin(0,0,m4sq) + B0fin(0,0,m2sq)*B0fin(0,0,m4sq)) + 2*(m1sq + m2sq)*(m1sq - m4sq)**2*(m2sq - m4sq)**2*(m1 + m2 + 2*m1*B0fin(0,0,m1) + 2*m2*B0fin(0,0,m2) - T134fin(m2,m1,0)) + 2*(m1sq - m2sq)**2*(m2sq - m4sq)**2*(m1sq + m4sq)*(m1 + m4 + 2*m1*B0fin(0,0,m1) + 2*m4*B0fin(0,0,m4) - T134fin(m4,m1,0)) - 2*(m1sq - m2sq)**2*(m1sq - m4sq)**2*(m2sq + m4sq)*(m2 + m4 + 2*m2*B0fin(0,0,m2) + 2*m4*B0fin(0,0,m4) - T134fin(m4,m2,0)))/((m1sq - m2sq)**3*(m1sq - m4sq)**3*(m2sq - m4sq)**2)
		def eval_36():
			return (m2**6 + 6*m2sq*m3**3 - 4*m2*m3**4 + 14*m2sq*m3**4 - 8*m3**5 + 3*m2**3*m3sq - 9*m2**4*m3sq + 2*m2sq*(m2sq - 2*m3sq)*m3sq*B0del(0,0,m2sq) + 4*m3**4*(m2sq - 2*m3sq)*B0del(0,0,m3sq) - 8*m2*m3**4*B0fin(0,0,m2) + 2*m2**3*m3sq*B0fin(0,0,m2) + 12*m2sq*m3**4*B0fin(0,0,m2sq) - 2*m2**4*m3sq*B0fin(0,0,m2sq) + 4*m2sq*m3**3*B0fin(0,0,m3) - 16*m3**5*B0fin(0,0,m3) - 8*m2sq*m3**4*B0fin(0,0,m3sq) + 8*m3**6*B0fin(0,0,m3sq) + 2*m2**4*m3sq*B0fin(0,0,m3sq) - 4*m2sq*m3**4*B0fin(0,0,m2sq)*B0fin(0,0,m3sq) + 2*m2**4*m3sq*B0fin(0,0,m2sq)*B0fin(0,0,m3sq) + 4*m2sq*m3**4*B0fin(0,0,m3sq)**2 - 4*m3**6*B0fin(0,0,m3sq)**2 - m2**4*m3sq*B0fin(0,0,m3sq)**2 + 4*m3**4*T134fin(m3,m3,m2) - 2*m2sq*m3sq*T134fin(m3,m3,m2))/(m2**4*m3**2*(m2sq - 4*m3sq)**2)
		def eval_37():
			return (-8*m1**5 - 4*m1**4*m6 + 3*m1sq*m6**3 - 9*m1sq*m6**4 + m6**6 + 6*m1**3*m6sq + 14*m1**4*m6sq + (-8*m1**6 + 4*m1**4*m6sq)*B0del(0,0,m1sq) + (2*m1sq*m6**4 - 4*m1**4*m6sq)*B0del(0,0,m6sq) - 16*m1**5*B0fin(0,0,m1) + 4*m1**3*m6sq*B0fin(0,0,m1) + 8*m1**6*B0fin(0,0,m1sq) + 2*m1sq*m6**4*B0fin(0,0,m1sq) - 8*m1**4*m6sq*B0fin(0,0,m1sq) - 4*m1**6*B0fin(0,0,m1sq)**2 - m1sq*m6**4*B0fin(0,0,m1sq)**2 + 4*m1**4*m6sq*B0fin(0,0,m1sq)**2 - 8*m1**4*m6*B0fin(0,0,m6) + 2*m1sq*m6**3*B0fin(0,0,m6) - 2*m1sq*m6**4*B0fin(0,0,m6sq) + 12*m1**4*m6sq*B0fin(0,0,m6sq) + 2*m1sq*m6**4*B0fin(0,0,m1sq)*B0fin(0,0,m6sq) - 4*m1**4*m6sq*B0fin(0,0,m1sq)*B0fin(0,0,m6sq) + 4*m1**4*T134fin(m6,m1,m1) - 2*m1sq*m6sq*T134fin(m6,m1,m1))/(m6**4*(-4*m1**3 + m1*m6sq)**2)
		def eval_38():
			return (-8*m1**5 - 4*m1**4*m4 + 3*m1sq*m4**3 - 9*m1sq*m4**4 + m4**6 + 6*m1**3*m4sq + 14*m1**4*m4sq + (-8*m1**6 + 4*m1**4*m4sq)*B0del(0,0,m1sq) + (2*m1sq*m4**4 - 4*m1**4*m4sq)*B0del(0,0,m4sq) - 16*m1**5*B0fin(0,0,m1) + 4*m1**3*m4sq*B0fin(0,0,m1) + 8*m1**6*B0fin(0,0,m1sq) + 2*m1sq*m4**4*B0fin(0,0,m1sq) - 8*m1**4*m4sq*B0fin(0,0,m1sq) - 4*m1**6*B0fin(0,0,m1sq)**2 - m1sq*m4**4*B0fin(0,0,m1sq)**2 + 4*m1**4*m4sq*B0fin(0,0,m1sq)**2 - 8*m1**4*m4*B0fin(0,0,m4) + 2*m1sq*m4**3*B0fin(0,0,m4) - 2*m1sq*m4**4*B0fin(0,0,m4sq) + 12*m1**4*m4sq*B0fin(0,0,m4sq) + 2*m1sq*m4**4*B0fin(0,0,m1sq)*B0fin(0,0,m4sq) - 4*m1**4*m4sq*B0fin(0,0,m1sq)*B0fin(0,0,m4sq) + 4*m1**4*T134fin(m4,m1,m1) - 2*m1sq*m4sq*T134fin(m4,m1,m1))/(m4**4*(-4*m1**3 + m1*m4sq)**2)
		def eval_39():
			return (3*m1sq*m5sq*(m1sq - m6sq)*(4*m1sq - m6sq)*B0del(0,0,m1sq) + 2*m1sq*(m1sq - m5sq)*(m1sq - m6sq)*(m5sq - m6sq)*B0del(0,0,m1sq) - 3*m1sq*(m1sq - m5sq)*(4*m1sq - m5sq)*m6sq*B0del(0,0,m1sq) + 3*m1sq*m5sq*(m1sq - m6sq)*(4*m1sq - m6sq)*B0del(0,0,m5sq) - 3*m1sq*(m1sq - m5sq)*(4*m1sq - m5sq)*m6sq*B0del(0,0,m6sq) - 3*m1sq*m5sq*(m1sq - m6sq)*(4*m1sq - m6sq)*B0fin(0,0,m1sq) - 2*m1sq*(m1sq - m5sq)*(m1sq - m6sq)*(m5sq - m6sq)*B0fin(0,0,m1sq) + 3*m1sq*(m1sq - m5sq)*(4*m1sq - m5sq)*m6sq*B0fin(0,0,m1sq) + m1sq*(m1sq - m5sq)*(m1sq - m6sq)*(m5sq - m6sq)*B0fin(0,0,m1sq)**2 + (4*m1sq - m5sq)*(m1sq - m6sq)*(4*m1sq - m6sq)*(m1 + m5 + 2*m1*B0fin(0,0,m1) + 2*m5*B0fin(0,0,m5)) - (m1sq - m5sq)*(m1sq - m6sq)*(4*m1sq - m6sq)*(2*m1 + m5 + 4*m1*B0fin(0,0,m1) + 2*m5*B0fin(0,0,m5)) - 3*m1sq*m5sq*(m1sq - m6sq)*(4*m1sq - m6sq)*B0fin(0,0,m5sq) + 3*m1sq*m5sq*(m1sq - m6sq)*(4*m1sq - m6sq)*B0fin(0,0,m1sq)*B0fin(0,0,m5sq) - (m1sq - m5sq)*(4*m1sq - m5sq)*(4*m1sq - m6sq)*(m1 + m6 + 2*m1*B0fin(0,0,m1) + 2*m6*B0fin(0,0,m6)) + (m1sq - m5sq)*(4*m1sq - m5sq)*(m1sq - m6sq)*(2*m1 + m6 + 4*m1*B0fin(0,0,m1) + 2*m6*B0fin(0,0,m6)) + 3*m1sq*(m1sq - m5sq)*(4*m1sq - m5sq)*m6sq*B0fin(0,0,m6sq) - 3*m1sq*(m1sq - m5sq)*(4*m1sq - m5sq)*m6sq*B0fin(0,0,m1sq)*B0fin(0,0,m6sq) - (4*m1sq - m5sq)*(m1sq - m6sq)*(4*m1sq - m6sq)*T134fin(m5,m1,0) + (m1sq - m5sq)*(m1sq - m6sq)*(4*m1sq - m6sq)*T134fin(m5,m1,m1) + (m1sq - m5sq)*(4*m1sq - m5sq)*(4*m1sq - m6sq)*T134fin(m6,m1,0) - (m1sq - m5sq)*(4*m1sq - m5sq)*(m1sq - m6sq)*T134fin(m6,m1,m1))/(m1**2*(m1sq - m5sq)*(4*m1sq - m5sq)*(m1sq - m6sq)*(4*m1sq - m6sq)*(m5sq - m6sq))
		def eval_40():
			return ((2*(m1sq - m4sq)*(2*m1sq - m6sq)*B0del(0,0,m1sq))/(m6**4 - 4*m1sq*m6sq) + (2*m4sq*(3*m1sq + m4sq - m6sq)*B0del(0,0,m1sq))/(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq)) + (2*(m1sq - m4sq)*(3*m1**4 - m4**4 + m1sq*(6*m4sq - 3*m6sq) + m4sq*m6sq)*B0del(0,0,m1sq))/((4*m1sq - m6sq)*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) + (4*m4sq*(-m1sq + m4sq)*B0del(0,0,m4sq))/(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq)) + (2*m4sq*(3*m1sq + m4sq - m6sq)*B0del(0,0,m4sq))/(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq)) + (4*m4sq*(-m1sq + m4sq)*B0del(0,0,m6sq))/(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq)) + (2*(m1sq - m4sq)*(3*m1**4 - m4**4 + m1sq*(6*m4sq - 3*m6sq) + m4sq*m6sq)*B0del(0,0,m6sq))/((4*m1sq - m6sq)*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) - (2*(m1sq - m4sq)*(2*m1sq - m6sq)*B0fin(0,0,m1sq))/(m6**4 - 4*m1sq*m6sq) - (2*m4sq*(3*m1sq + m4sq - m6sq)*B0fin(0,0,m1sq))/(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq)) - (2*(m1sq - m4sq)*(3*m1**4 - m4**4 + m1sq*(6*m4sq - 3*m6sq) + m4sq*m6sq)*B0fin(0,0,m1sq))/((4*m1sq - m6sq)*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) + ((m1sq - m4sq)*(2*m1sq - m6sq)*B0fin(0,0,m1sq)**2)/(m6**4 - 4*m1sq*m6sq) - (2*(m1 + m4 + 2*m1*B0fin(0,0,m1) + 2*m4*B0fin(0,0,m4)))/m6**2 + (4*(m1sq - m4sq)*m4sq*B0fin(0,0,m4sq))/(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq)) - (2*m4sq*(3*m1sq + m4sq - m6sq)*B0fin(0,0,m4sq))/(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq)) + (2*m4sq*(3*m1sq + m4sq - m6sq)*B0fin(0,0,m1sq)*B0fin(0,0,m4sq))/(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq)) + (2*(m1sq - m4sq)*(2*m1 + m6 + 4*m1*B0fin(0,0,m1) + 2*m6*B0fin(0,0,m6)))/(m6**4 - 4*m1sq*m6sq) + (2*(m1sq - m4sq)*(m1sq - m4sq - m6sq)*(m1 + m4 + m6 + 2*m1*B0fin(0,0,m1) + 2*m4*B0fin(0,0,m4) + 2*m6*B0fin(0,0,m6)))/(m6**2*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) + (4*(m1sq - m4sq)*m4sq*B0fin(0,0,m6sq))/(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq)) - (2*(m1sq - m4sq)*(3*m1**4 - m4**4 + m1sq*(6*m4sq - 3*m6sq) + m4sq*m6sq)*B0fin(0,0,m6sq))/((4*m1sq - m6sq)*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) + (2*(m1sq - m4sq)*(3*m1**4 - m4**4 + m1sq*(6*m4sq - 3*m6sq) + m4sq*m6sq)*B0fin(0,0,m1sq)*B0fin(0,0,m6sq))/((4*m1sq - m6sq)*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) + (4*m4sq*(-m1sq + m4sq)*B0fin(0,0,m4sq)*B0fin(0,0,m6sq))/(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq)) + (2*T134fin(m4,m1,0))/m6**2 + (2*(m1sq - m4sq)*T134fin(m6,m1,m1))/(-m6**4 + 4*m1sq*m6sq) + (2*(m1sq - m4sq)*(m1sq - m4sq - m6sq)*T134fin(m6,m4,m1))/(m6**2*(4*m4sq*m6sq - (-m1sq + m4sq + m6sq)**2)))/(2.*(m1sq - m4sq)**2)
		def eval_41():
			return (3*m1sq*m3sq*(m1sq - m4sq)*(4*m1sq - m4sq)*B0del(0,0,m1sq) + 2*m1sq*(m1sq - m3sq)*(m1sq - m4sq)*(m3sq - m4sq)*B0del(0,0,m1sq) - 3*m1sq*(m1sq - m3sq)*(4*m1sq - m3sq)*m4sq*B0del(0,0,m1sq) + 3*m1sq*m3sq*(m1sq - m4sq)*(4*m1sq - m4sq)*B0del(0,0,m3sq) - 3*m1sq*(m1sq - m3sq)*(4*m1sq - m3sq)*m4sq*B0del(0,0,m4sq) - 3*m1sq*m3sq*(m1sq - m4sq)*(4*m1sq - m4sq)*B0fin(0,0,m1sq) - 2*m1sq*(m1sq - m3sq)*(m1sq - m4sq)*(m3sq - m4sq)*B0fin(0,0,m1sq) + 3*m1sq*(m1sq - m3sq)*(4*m1sq - m3sq)*m4sq*B0fin(0,0,m1sq) + m1sq*(m1sq - m3sq)*(m1sq - m4sq)*(m3sq - m4sq)*B0fin(0,0,m1sq)**2 + (4*m1sq - m3sq)*(m1sq - m4sq)*(4*m1sq - m4sq)*(m1 + m3 + 2*m1*B0fin(0,0,m1) + 2*m3*B0fin(0,0,m3)) - (m1sq - m3sq)*(m1sq - m4sq)*(4*m1sq - m4sq)*(2*m1 + m3 + 4*m1*B0fin(0,0,m1) + 2*m3*B0fin(0,0,m3)) - 3*m1sq*m3sq*(m1sq - m4sq)*(4*m1sq - m4sq)*B0fin(0,0,m3sq) + 3*m1sq*m3sq*(m1sq - m4sq)*(4*m1sq - m4sq)*B0fin(0,0,m1sq)*B0fin(0,0,m3sq) - (m1sq - m3sq)*(4*m1sq - m3sq)*(4*m1sq - m4sq)*(m1 + m4 + 2*m1*B0fin(0,0,m1) + 2*m4*B0fin(0,0,m4)) + (m1sq - m3sq)*(4*m1sq - m3sq)*(m1sq - m4sq)*(2*m1 + m4 + 4*m1*B0fin(0,0,m1) + 2*m4*B0fin(0,0,m4)) + 3*m1sq*(m1sq - m3sq)*(4*m1sq - m3sq)*m4sq*B0fin(0,0,m4sq) - 3*m1sq*(m1sq - m3sq)*(4*m1sq - m3sq)*m4sq*B0fin(0,0,m1sq)*B0fin(0,0,m4sq) - (4*m1sq - m3sq)*(m1sq - m4sq)*(4*m1sq - m4sq)*T134fin(m3,m1,0) + (m1sq - m3sq)*(m1sq - m4sq)*(4*m1sq - m4sq)*T134fin(m3,m1,m1) + (m1sq - m3sq)*(4*m1sq - m3sq)*(4*m1sq - m4sq)*T134fin(m4,m1,0) - (m1sq - m3sq)*(4*m1sq - m3sq)*(m1sq - m4sq)*T134fin(m4,m1,m1))/(m1**2*(m1sq - m3sq)*(4*m1sq - m3sq)*(m1sq - m4sq)*(4*m1sq - m4sq)*(m3sq - m4sq))
		def eval_42():
			return ((2*(m1sq - m2sq)*(2*m1sq - m6sq)*B0del(0,0,m1sq))/(m6**4 - 4*m1sq*m6sq) + (2*m2sq*(3*m1sq + m2sq - m6sq)*B0del(0,0,m1sq))/(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq)) + (2*(m1sq - m2sq)*(3*m1**4 - m2**4 + m1sq*(6*m2sq - 3*m6sq) + m2sq*m6sq)*B0del(0,0,m1sq))/((4*m1sq - m6sq)*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))) + (4*m2sq*(-m1sq + m2sq)*B0del(0,0,m2sq))/(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq)) + (2*m2sq*(3*m1sq + m2sq - m6sq)*B0del(0,0,m2sq))/(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq)) + (4*m2sq*(-m1sq + m2sq)*B0del(0,0,m6sq))/(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq)) + (2*(m1sq - m2sq)*(3*m1**4 - m2**4 + m1sq*(6*m2sq - 3*m6sq) + m2sq*m6sq)*B0del(0,0,m6sq))/((4*m1sq - m6sq)*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))) - (2*(m1sq - m2sq)*(2*m1sq - m6sq)*B0fin(0,0,m1sq))/(m6**4 - 4*m1sq*m6sq) - (2*m2sq*(3*m1sq + m2sq - m6sq)*B0fin(0,0,m1sq))/(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq)) - (2*(m1sq - m2sq)*(3*m1**4 - m2**4 + m1sq*(6*m2sq - 3*m6sq) + m2sq*m6sq)*B0fin(0,0,m1sq))/((4*m1sq - m6sq)*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))) + ((m1sq - m2sq)*(2*m1sq - m6sq)*B0fin(0,0,m1sq)**2)/(m6**4 - 4*m1sq*m6sq) - (2*(m1 + m2 + 2*m1*B0fin(0,0,m1) + 2*m2*B0fin(0,0,m2)))/m6**2 + (4*(m1sq - m2sq)*m2sq*B0fin(0,0,m2sq))/(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq)) - (2*m2sq*(3*m1sq + m2sq - m6sq)*B0fin(0,0,m2sq))/(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq)) + (2*m2sq*(3*m1sq + m2sq - m6sq)*B0fin(0,0,m1sq)*B0fin(0,0,m2sq))/(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq)) + (2*(m1sq - m2sq)*(2*m1 + m6 + 4*m1*B0fin(0,0,m1) + 2*m6*B0fin(0,0,m6)))/(m6**4 - 4*m1sq*m6sq) + (2*(m1sq - m2sq)*(m1sq - m2sq - m6sq)*(m1 + m2 + m6 + 2*m1*B0fin(0,0,m1) + 2*m2*B0fin(0,0,m2) + 2*m6*B0fin(0,0,m6)))/(m6**2*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))) + (4*(m1sq - m2sq)*m2sq*B0fin(0,0,m6sq))/(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq)) - (2*(m1sq - m2sq)*(3*m1**4 - m2**4 + m1sq*(6*m2sq - 3*m6sq) + m2sq*m6sq)*B0fin(0,0,m6sq))/((4*m1sq - m6sq)*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))) + (2*(m1sq - m2sq)*(3*m1**4 - m2**4 + m1sq*(6*m2sq - 3*m6sq) + m2sq*m6sq)*B0fin(0,0,m1sq)*B0fin(0,0,m6sq))/((4*m1sq - m6sq)*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))) + (4*m2sq*(-m1sq + m2sq)*B0fin(0,0,m2sq)*B0fin(0,0,m6sq))/(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq)) + (2*T134fin(m2,m1,0))/m6**2 + (2*(m1sq - m2sq)*T134fin(m6,m1,m1))/(-m6**4 + 4*m1sq*m6sq) + (2*(m1sq - m2sq)*(m1sq - m2sq - m6sq)*T134fin(m6,m2,m1))/(m6**2*(4*m2sq*m6sq - (-m1sq + m2sq + m6sq)**2)))/(2.*(m1sq - m2sq)**2)
		def eval_43():
			return ((2*(m1sq - m2sq)*(2*m1sq - m4sq)*B0del(0,0,m1sq))/(m4**4 - 4*m1sq*m4sq) + (2*m2sq*(3*m1sq + m2sq - m4sq)*B0del(0,0,m1sq))/(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq)) + (2*(m1sq - m2sq)*(3*m1**4 - m2**4 + m1sq*(6*m2sq - 3*m4sq) + m2sq*m4sq)*B0del(0,0,m1sq))/((4*m1sq - m4sq)*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))) + (4*m2sq*(-m1sq + m2sq)*B0del(0,0,m2sq))/(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq)) + (2*m2sq*(3*m1sq + m2sq - m4sq)*B0del(0,0,m2sq))/(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq)) + (4*m2sq*(-m1sq + m2sq)*B0del(0,0,m4sq))/(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq)) + (2*(m1sq - m2sq)*(3*m1**4 - m2**4 + m1sq*(6*m2sq - 3*m4sq) + m2sq*m4sq)*B0del(0,0,m4sq))/((4*m1sq - m4sq)*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))) - (2*(m1sq - m2sq)*(2*m1sq - m4sq)*B0fin(0,0,m1sq))/(m4**4 - 4*m1sq*m4sq) - (2*m2sq*(3*m1sq + m2sq - m4sq)*B0fin(0,0,m1sq))/(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq)) - (2*(m1sq - m2sq)*(3*m1**4 - m2**4 + m1sq*(6*m2sq - 3*m4sq) + m2sq*m4sq)*B0fin(0,0,m1sq))/((4*m1sq - m4sq)*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))) + ((m1sq - m2sq)*(2*m1sq - m4sq)*B0fin(0,0,m1sq)**2)/(m4**4 - 4*m1sq*m4sq) - (2*(m1 + m2 + 2*m1*B0fin(0,0,m1) + 2*m2*B0fin(0,0,m2)))/m4**2 + (4*(m1sq - m2sq)*m2sq*B0fin(0,0,m2sq))/(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq)) - (2*m2sq*(3*m1sq + m2sq - m4sq)*B0fin(0,0,m2sq))/(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq)) + (2*m2sq*(3*m1sq + m2sq - m4sq)*B0fin(0,0,m1sq)*B0fin(0,0,m2sq))/(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq)) + (2*(m1sq - m2sq)*(2*m1 + m4 + 4*m1*B0fin(0,0,m1) + 2*m4*B0fin(0,0,m4)))/(m4**4 - 4*m1sq*m4sq) + (2*(m1sq - m2sq)*(m1sq - m2sq - m4sq)*(m1 + m2 + m4 + 2*m1*B0fin(0,0,m1) + 2*m2*B0fin(0,0,m2) + 2*m4*B0fin(0,0,m4)))/(m4**2*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))) + (4*(m1sq - m2sq)*m2sq*B0fin(0,0,m4sq))/(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq)) - (2*(m1sq - m2sq)*(3*m1**4 - m2**4 + m1sq*(6*m2sq - 3*m4sq) + m2sq*m4sq)*B0fin(0,0,m4sq))/((4*m1sq - m4sq)*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))) + (2*(m1sq - m2sq)*(3*m1**4 - m2**4 + m1sq*(6*m2sq - 3*m4sq) + m2sq*m4sq)*B0fin(0,0,m1sq)*B0fin(0,0,m4sq))/((4*m1sq - m4sq)*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))) + (4*m2sq*(-m1sq + m2sq)*B0fin(0,0,m2sq)*B0fin(0,0,m4sq))/(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq)) + (2*T134fin(m2,m1,0))/m4**2 + (2*(m1sq - m2sq)*T134fin(m4,m1,m1))/(-m4**4 + 4*m1sq*m4sq) + (2*(m1sq - m2sq)*(m1sq - m2sq - m4sq)*T134fin(m4,m2,m1))/(m4**2*(4*m2sq*m4sq - (-m1sq + m2sq + m4sq)**2)))/(2.*(m1sq - m2sq)**2)
		def eval_44():
			return -0.3333333333333333*(12*m1**5 + 18*m1**4*m2 - 30*m1sq*m2**3 + 18*m1*m2**4 + 12*m2**5 - 30*m1**3*m2sq + 6*(2*m1**6 + 3*m1sq*m2**4 - 5*m1**4*m2sq)*B0del(0,0,m1sq) + 6*(-5*m1sq*m2**4 + 2*m2**6 + 3*m1**4*m2sq)*B0del(0,0,m2sq) + 24*m1**5*B0fin(0,0,m1) + 36*m1*m2**4*B0fin(0,0,m1) - 60*m1**3*m2sq*B0fin(0,0,m1) - 12*m1**6*B0fin(0,0,m1sq) - 18*m1sq*m2**4*B0fin(0,0,m1sq) + 30*m1**4*m2sq*B0fin(0,0,m1sq) + 6*m1**6*B0fin(0,0,m1sq)**2 - 24*m1**4*m2sq*B0fin(0,0,m1sq)**2 + 36*m1**4*m2*B0fin(0,0,m2) - 60*m1sq*m2**3*B0fin(0,0,m2) + 24*m2**5*B0fin(0,0,m2) + 30*m1sq*m2**4*B0fin(0,0,m2sq) - 12*m2**6*B0fin(0,0,m2sq) - 18*m1**4*m2sq*B0fin(0,0,m2sq) + 18*m1sq*m2**4*B0fin(0,0,m1sq)*B0fin(0,0,m2sq) + 18*m1**4*m2sq*B0fin(0,0,m1sq)*B0fin(0,0,m2sq) - 24*m1sq*m2**4*B0fin(0,0,m2sq)**2 + 6*m2**6*B0fin(0,0,m2sq)**2 - 6*m1**4*T134fin(m2,m1,m1) - 12*m2**4*T134fin(m2,m1,m1) + 27*m1sq*m2sq*T134fin(m2,m1,m1) + 6*m2**4*T134fin(m2,m2,m1) - 24*m1sq*m2sq*T134fin(m2,m2,m1) - 4*m1**4*T134fin(m2,m2,m2) - 4*m2**4*T134fin(m2,m2,m2) + 17*m1sq*m2sq*T134fin(m2,m2,m2))/((-(m1sq*m2) + m2**3)**2*(4*m1**4 + 4*m2**4 - 17*m1sq*m2sq))
		def eval_45():
			return -0.3333333333333333*(12*m1**5 + 18*m1**4*m2 - 30*m1sq*m2**3 + 18*m1*m2**4 + 12*m2**5 - 30*m1**3*m2sq + 6*(2*m1**6 + 3*m1sq*m2**4 - 5*m1**4*m2sq)*B0del(0,0,m1sq) + 6*(-5*m1sq*m2**4 + 2*m2**6 + 3*m1**4*m2sq)*B0del(0,0,m2sq) + 24*m1**5*B0fin(0,0,m1) + 36*m1*m2**4*B0fin(0,0,m1) - 60*m1**3*m2sq*B0fin(0,0,m1) - 12*m1**6*B0fin(0,0,m1sq) - 18*m1sq*m2**4*B0fin(0,0,m1sq) + 30*m1**4*m2sq*B0fin(0,0,m1sq) + 6*m1**6*B0fin(0,0,m1sq)**2 - 24*m1**4*m2sq*B0fin(0,0,m1sq)**2 + 36*m1**4*m2*B0fin(0,0,m2) - 60*m1sq*m2**3*B0fin(0,0,m2) + 24*m2**5*B0fin(0,0,m2) + 30*m1sq*m2**4*B0fin(0,0,m2sq) - 12*m2**6*B0fin(0,0,m2sq) - 18*m1**4*m2sq*B0fin(0,0,m2sq) + 18*m1sq*m2**4*B0fin(0,0,m1sq)*B0fin(0,0,m2sq) + 18*m1**4*m2sq*B0fin(0,0,m1sq)*B0fin(0,0,m2sq) - 24*m1sq*m2**4*B0fin(0,0,m2sq)**2 + 6*m2**6*B0fin(0,0,m2sq)**2 - 6*m1**4*T134fin(m2,m1,m1) - 12*m2**4*T134fin(m2,m1,m1) + 27*m1sq*m2sq*T134fin(m2,m1,m1) + 6*m2**4*T134fin(m2,m2,m1) - 24*m1sq*m2sq*T134fin(m2,m2,m1) - 4*m1**4*T134fin(m2,m2,m2) - 4*m2**4*T134fin(m2,m2,m2) + 17*m1sq*m2sq*T134fin(m2,m2,m2))/((-(m1sq*m2) + m2**3)**2*(4*m1**4 + 4*m2**4 - 17*m1sq*m2sq))
		def eval_46():
			return (2*m1sq*m2sq*(m1sq - 4*m3sq)*(m2sq - 4*m3sq)*(4*m2sq - m3sq)*m3sq*B0del(0,0,m1sq) - m1sq*(m2sq - 4*m3sq)*(4*m2sq - m3sq)*m3sq*(m2**4 - 3*m3**4 - m1sq*(m2sq - 3*m3sq) - 6*m2sq*m3sq)*B0del(0,0,m1sq) + 2*m1sq*m2sq*(m1sq - 4*m3sq)*(m2sq - 4*m3sq)*(4*m2sq - m3sq)*m3sq*B0del(0,0,m2sq) + 4*m2**4*(m1sq - 4*m3sq)*(m2sq - 4*m3sq)*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*B0del(0,0,m2sq) + m2sq*(m1sq - 4*m3sq)*m3sq*(m1**4*(2*m2sq + 7*m3sq) + 3*(2*m2**6 + 3*m2sq*m3**4 + m3**6 - 6*m2**4*m3sq) - m1sq*(8*m2**4 + 18*m3**4 + m2sq*m3sq))*B0del(0,0,m2sq) - m1sq*(m2sq - 4*m3sq)*(4*m2sq - m3sq)*m3sq*(m2**4 - 3*m3**4 - m1sq*(m2sq - 3*m3sq) - 6*m2sq*m3sq)*B0del(0,0,m3sq) - 2*(m1sq - m2sq)*m3**4*(4*m2sq - m3sq)*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*B0del(0,0,m3sq) + m2sq*(m1sq - 4*m3sq)*m3sq*(m1**4*(2*m2sq + 7*m3sq) + 3*(2*m2**6 + 3*m2sq*m3**4 + m3**6 - 6*m2**4*m3sq) - m1sq*(8*m2**4 + 18*m3**4 + m2sq*m3sq))*B0del(0,0,m3sq) - 2*m1sq*m2sq*(m1sq - 4*m3sq)*(m2sq - 4*m3sq)*(4*m2sq - m3sq)*m3sq*B0fin(0,0,m1sq) + m1sq*(m2sq - 4*m3sq)*(4*m2sq - m3sq)*m3sq*(m2**4 - 3*m3**4 - m1sq*(m2sq - 3*m3sq) - 6*m2sq*m3sq)*B0fin(0,0,m1sq) - 2*m1sq*m2sq*(m1sq - 4*m3sq)*(m2sq - 4*m3sq)*(4*m2sq - m3sq)*m3sq*B0fin(0,0,m2sq) - 4*m2**4*(m1sq - 4*m3sq)*(m2sq - 4*m3sq)*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*B0fin(0,0,m2sq) - m2sq*(m1sq - 4*m3sq)*m3sq*(m1**4*(2*m2sq + 7*m3sq) + 3*(2*m2**6 + 3*m2sq*m3**4 + m3**6 - 6*m2**4*m3sq) - m1sq*(8*m2**4 + 18*m3**4 + m2sq*m3sq))*B0fin(0,0,m2sq) + 2*m1sq*m2sq*(m1sq - 4*m3sq)*(m2sq - 4*m3sq)*(4*m2sq - m3sq)*m3sq*B0fin(0,0,m1sq)*B0fin(0,0,m2sq) + 2*m2**4*(m1sq - 4*m3sq)*(m2sq - 4*m3sq)*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*B0fin(0,0,m2sq)**2 + 2*(m1sq - 4*m3sq)*(m2sq - 4*m3sq)*(m1sq + m2sq - m3sq)*(4*m2sq - m3sq)*m3sq*((m1 + m2 + m3)/2. + m1*B0fin(0,0,m1) + m2*B0fin(0,0,m2) + m3*B0fin(0,0,m3)) + 2*(m1sq - 4*m3sq)*(m2sq - 4*m3sq)*(2*m2sq - m3sq)*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*(m2 + m3/2. + 2*m2*B0fin(0,0,m2) + m3*B0fin(0,0,m3)) - 2*(m2sq - 4*m3sq)*(4*m2sq - m3sq)*m3sq*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*(m1/2. + m3 + m1*B0fin(0,0,m1) + 2*m3*B0fin(0,0,m3)) + 2*(m1sq - 4*m3sq)*(4*m2sq - m3sq)*m3sq*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*(m2/2. + m3 + m2*B0fin(0,0,m2) + 2*m3*B0fin(0,0,m3)) + m1sq*(m2sq - 4*m3sq)*(4*m2sq - m3sq)*m3sq*(m2**4 - 3*m3**4 - m1sq*(m2sq - 3*m3sq) - 6*m2sq*m3sq)*B0fin(0,0,m3sq) + 2*(m1sq - m2sq)*m3**4*(4*m2sq - m3sq)*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*B0fin(0,0,m3sq) - m2sq*(m1sq - 4*m3sq)*m3sq*(m1**4*(2*m2sq + 7*m3sq) + 3*(2*m2**6 + 3*m2sq*m3**4 + m3**6 - 6*m2**4*m3sq) - m1sq*(8*m2**4 + 18*m3**4 + m2sq*m3sq))*B0fin(0,0,m3sq) - m1sq*(m2sq - 4*m3sq)*(4*m2sq - m3sq)*m3sq*(m2**4 - 3*m3**4 - m1sq*(m2sq - 3*m3sq) - 6*m2sq*m3sq)*B0fin(0,0,m1sq)*B0fin(0,0,m3sq) + m2sq*(m1sq - 4*m3sq)*m3sq*(m1**4*(2*m2sq + 7*m3sq) + 3*(2*m2**6 + 3*m2sq*m3**4 + m3**6 - 6*m2**4*m3sq) - m1sq*(8*m2**4 + 18*m3**4 + m2sq*m3sq))*B0fin(0,0,m2sq)*B0fin(0,0,m3sq) - (m1sq - m2sq)*m3**4*(4*m2sq - m3sq)*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*B0fin(0,0,m3sq)**2 - (m1sq - 4*m3sq)*(m2sq - 4*m3sq)*(m1sq + m2sq - m3sq)*(4*m2sq - m3sq)*m3sq*T134fin(m3,m2,m1) - (m1sq - 4*m3sq)*(m2sq - 4*m3sq)*(2*m2sq - m3sq)*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*T134fin(m3,m2,m2) + (m2sq - 4*m3sq)*(4*m2sq - m3sq)*m3sq*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*T134fin(m3,m3,m1) - (m1sq - 4*m3sq)*(4*m2sq - m3sq)*m3sq*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*T134fin(m3,m3,m2))/((m1sq - m2sq)*m3**2*(m1sq - 4*m3sq)*(m2sq - 4*m3sq)*(m2sq - m3sq)*(4*m2sq - m3sq)*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq)))
		def eval_47():
			return (-2*m1sq*m2sq*(m1sq - 4*m3sq)*(m2sq - 4*m3sq)*(4*m1sq - m3sq)*m3sq*B0del(0,0,m1sq) - 4*m1**4*(m1sq - 4*m3sq)*(m2sq - 4*m3sq)*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*B0del(0,0,m1sq) - m1sq*(m2sq - 4*m3sq)*m3sq*(6*m1**6 - 18*m2sq*m3**4 + 3*m3**6 + 7*m2**4*m3sq - 2*m1**4*(4*m2sq + 9*m3sq) + m1sq*(2*m2**4 + 9*m3**4 - m2sq*m3sq))*B0del(0,0,m1sq) - 2*m1sq*m2sq*(m1sq - 4*m3sq)*(m2sq - 4*m3sq)*(4*m1sq - m3sq)*m3sq*B0del(0,0,m2sq) + m2sq*(m1sq - 4*m3sq)*(4*m1sq - m3sq)*m3sq*(m1**4 + 3*(m2sq - m3sq)*m3sq - m1sq*(m2sq + 6*m3sq))*B0del(0,0,m2sq) - 2*(m1sq - m2sq)*m3**4*(4*m1sq - m3sq)*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*B0del(0,0,m3sq) + m2sq*(m1sq - 4*m3sq)*(4*m1sq - m3sq)*m3sq*(m1**4 + 3*(m2sq - m3sq)*m3sq - m1sq*(m2sq + 6*m3sq))*B0del(0,0,m3sq) - m1sq*(m2sq - 4*m3sq)*m3sq*(6*m1**6 - 18*m2sq*m3**4 + 3*m3**6 + 7*m2**4*m3sq - 2*m1**4*(4*m2sq + 9*m3sq) + m1sq*(2*m2**4 + 9*m3**4 - m2sq*m3sq))*B0del(0,0,m3sq) + 2*m1sq*m2sq*(m1sq - 4*m3sq)*(m2sq - 4*m3sq)*(4*m1sq - m3sq)*m3sq*B0fin(0,0,m1sq) + 4*m1**4*(m1sq - 4*m3sq)*(m2sq - 4*m3sq)*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*B0fin(0,0,m1sq) + m1sq*(m2sq - 4*m3sq)*m3sq*(6*m1**6 - 18*m2sq*m3**4 + 3*m3**6 + 7*m2**4*m3sq - 2*m1**4*(4*m2sq + 9*m3sq) + m1sq*(2*m2**4 + 9*m3**4 - m2sq*m3sq))*B0fin(0,0,m1sq) - 2*m1**4*(m1sq - 4*m3sq)*(m2sq - 4*m3sq)*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*B0fin(0,0,m1sq)**2 + 2*m1sq*m2sq*(m1sq - 4*m3sq)*(m2sq - 4*m3sq)*(4*m1sq - m3sq)*m3sq*B0fin(0,0,m2sq) - m2sq*(m1sq - 4*m3sq)*(4*m1sq - m3sq)*m3sq*(m1**4 + 3*(m2sq - m3sq)*m3sq - m1sq*(m2sq + 6*m3sq))*B0fin(0,0,m2sq) - 2*m1sq*m2sq*(m1sq - 4*m3sq)*(m2sq - 4*m3sq)*(4*m1sq - m3sq)*m3sq*B0fin(0,0,m1sq)*B0fin(0,0,m2sq) - 2*(m1sq - 4*m3sq)*(m2sq - 4*m3sq)*(2*m1sq - m3sq)*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*(m1 + m3/2. + 2*m1*B0fin(0,0,m1) + m3*B0fin(0,0,m3)) - 2*(m1sq - 4*m3sq)*(m2sq - 4*m3sq)*(4*m1sq - m3sq)*(m1sq + m2sq - m3sq)*m3sq*((m1 + m2 + m3)/2. + m1*B0fin(0,0,m1) + m2*B0fin(0,0,m2) + m3*B0fin(0,0,m3)) - 2*(m2sq - 4*m3sq)*(4*m1sq - m3sq)*m3sq*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*(m1/2. + m3 + m1*B0fin(0,0,m1) + 2*m3*B0fin(0,0,m3)) + 2*(m1sq - 4*m3sq)*(4*m1sq - m3sq)*m3sq*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*(m2/2. + m3 + m2*B0fin(0,0,m2) + 2*m3*B0fin(0,0,m3)) + 2*(m1sq - m2sq)*m3**4*(4*m1sq - m3sq)*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*B0fin(0,0,m3sq) - m2sq*(m1sq - 4*m3sq)*(4*m1sq - m3sq)*m3sq*(m1**4 + 3*(m2sq - m3sq)*m3sq - m1sq*(m2sq + 6*m3sq))*B0fin(0,0,m3sq) + m1sq*(m2sq - 4*m3sq)*m3sq*(6*m1**6 - 18*m2sq*m3**4 + 3*m3**6 + 7*m2**4*m3sq - 2*m1**4*(4*m2sq + 9*m3sq) + m1sq*(2*m2**4 + 9*m3**4 - m2sq*m3sq))*B0fin(0,0,m3sq) - m1sq*(m2sq - 4*m3sq)*m3sq*(6*m1**6 - 18*m2sq*m3**4 + 3*m3**6 + 7*m2**4*m3sq - 2*m1**4*(4*m2sq + 9*m3sq) + m1sq*(2*m2**4 + 9*m3**4 - m2sq*m3sq))*B0fin(0,0,m1sq)*B0fin(0,0,m3sq) + m2sq*(m1sq - 4*m3sq)*(4*m1sq - m3sq)*m3sq*(m1**4 + 3*(m2sq - m3sq)*m3sq - m1sq*(m2sq + 6*m3sq))*B0fin(0,0,m2sq)*B0fin(0,0,m3sq) - (m1sq - m2sq)*m3**4*(4*m1sq - m3sq)*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*B0fin(0,0,m3sq)**2 + (m1sq - 4*m3sq)*(m2sq - 4*m3sq)*(2*m1sq - m3sq)*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*T134fin(m3,m1,m1) + (m1sq - 4*m3sq)*(m2sq - 4*m3sq)*(4*m1sq - m3sq)*(m1sq + m2sq - m3sq)*m3sq*T134fin(m3,m2,m1) + (m2sq - 4*m3sq)*(4*m1sq - m3sq)*m3sq*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*T134fin(m3,m3,m1) - (m1sq - 4*m3sq)*(4*m1sq - m3sq)*m3sq*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*T134fin(m3,m3,m2))/((m1sq - m2sq)*m3**2*(m1sq - 4*m3sq)*(m2sq - 4*m3sq)*(m1sq - m3sq)*(4*m1sq - m3sq)*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq)))
		def eval_48():
			return -((3*m1**7 - 3*m1**8 + 3*m1**6*m3 - 3*m1**4*m3**3 - 3*m1**3*m3**4 - 10*m1**4*m3**4 - 3*m1sq*m3**5 + 3*m1*m3**6 + 8*m1sq*m3**6 + 3*m3**7 - 3*m3**8 - 3*m1**5*m3sq + 8*m1**6*m3sq + 3*m1**6*m5 - 3*m1sq*m3**4*m5 + 3*m3**6*m5 - 3*m1**4*m3sq*m5 - 3*m1**4*m5**3 - 3*m3**4*m5**3 + 22*m1sq*m3sq*m5**3 - 3*m1**3*m5**4 - 10*m1**4*m5**4 - 3*m1sq*m3*m5**4 - 3*m3**3*m5**4 - 10*m3**4*m5**4 - 3*m1*m3sq*m5**4 - 16*m1sq*m3sq*m5**4 - 3*m1sq*m5**5 - 3*m3sq*m5**5 + 3*m1*m5**6 + 8*m1sq*m5**6 + 3*m3*m5**6 + 8*m3sq*m5**6 + 3*m5**7 - 3*m5**8 - 3*m1**5*m5sq + 8*m1**6*m5sq - 3*m1**4*m3*m5sq + 22*m1sq*m3**3*m5sq - 3*m1*m3**4*m5sq - 16*m1sq*m3**4*m5sq - 3*m3**5*m5sq + 8*m3**6*m5sq + 22*m1**3*m3sq*m5sq - 16*m1**4*m3sq*m5sq + 2*(m1**8 - m1**6*(m3sq + m5sq) + m1sq*(m3sq - m5sq)**2*(m3sq + m5sq) - m1**4*(m3**4 + m5**4 - 6*m3sq*m5sq))*B0del(0,0,m1sq) + 2*m3sq*(m1**6 - m1**4*(m3sq + m5sq) + (m3sq - m5sq)**2*(m3sq + m5sq) - m1sq*(m3**4 + m5**4 - 6*m3sq*m5sq))*B0del(0,0,m3sq) - 2*m1**4*m5**4*B0del(0,0,m5sq) - 2*m3**4*m5**4*B0del(0,0,m5sq) + 12*m1sq*m3sq*m5**4*B0del(0,0,m5sq) - 2*m1sq*m5**6*B0del(0,0,m5sq) - 2*m3sq*m5**6*B0del(0,0,m5sq) + 2*m5**8*B0del(0,0,m5sq) + 2*m1**6*m5sq*B0del(0,0,m5sq) - 2*m1sq*m3**4*m5sq*B0del(0,0,m5sq) + 2*m3**6*m5sq*B0del(0,0,m5sq) - 2*m1**4*m3sq*m5sq*B0del(0,0,m5sq) - 2*m1**7*B0fin(0,0,m1) + 2*m1**3*m3**4*B0fin(0,0,m1) - 2*m1*m3**6*B0fin(0,0,m1) + 2*m1**5*m3sq*B0fin(0,0,m1) + 2*m1**3*m5**4*B0fin(0,0,m1) + 2*m1*m3sq*m5**4*B0fin(0,0,m1) - 2*m1*m5**6*B0fin(0,0,m1) + 2*m1**5*m5sq*B0fin(0,0,m1) + 2*m1*m3**4*m5sq*B0fin(0,0,m1) - 4*m1**3*m3sq*m5sq*B0fin(0,0,m1) - 10*m1**4*m3**4*B0fin(0,0,m1sq) + 2*m1sq*m3**6*B0fin(0,0,m1sq) + 2*m3**8*B0fin(0,0,m1sq) + 6*m1**6*m3sq*B0fin(0,0,m1sq) - 10*m1**4*m5**4*B0fin(0,0,m1sq) + 12*m3**4*m5**4*B0fin(0,0,m1sq) - 2*m1sq*m3sq*m5**4*B0fin(0,0,m1sq) + 2*m1sq*m5**6*B0fin(0,0,m1sq) - 8*m3sq*m5**6*B0fin(0,0,m1sq) + 2*m5**8*B0fin(0,0,m1sq) + 6*m1**6*m5sq*B0fin(0,0,m1sq) - 2*m1sq*m3**4*m5sq*B0fin(0,0,m1sq) - 8*m3**6*m5sq*B0fin(0,0,m1sq) + 12*m1**4*m3sq*m5sq*B0fin(0,0,m1sq) - 2*m1**6*m3*B0fin(0,0,m3) + 2*m1**4*m3**3*B0fin(0,0,m3) + 2*m1sq*m3**5*B0fin(0,0,m3) - 2*m3**7*B0fin(0,0,m3) + 2*m1sq*m3*m5**4*B0fin(0,0,m3) + 2*m3**3*m5**4*B0fin(0,0,m3) - 2*m3*m5**6*B0fin(0,0,m3) + 2*m1**4*m3*m5sq*B0fin(0,0,m3) - 4*m1sq*m3**3*m5sq*B0fin(0,0,m3) + 2*m3**5*m5sq*B0fin(0,0,m3) + 2*m1**8*B0fin(0,0,m3sq) - 10*m1**4*m3**4*B0fin(0,0,m3sq) + 6*m1sq*m3**6*B0fin(0,0,m3sq) + 2*m1**6*m3sq*B0fin(0,0,m3sq) + 12*m1**4*m5**4*B0fin(0,0,m3sq) - 10*m3**4*m5**4*B0fin(0,0,m3sq) - 2*m1sq*m3sq*m5**4*B0fin(0,0,m3sq) - 8*m1sq*m5**6*B0fin(0,0,m3sq) + 2*m3sq*m5**6*B0fin(0,0,m3sq) + 2*m5**8*B0fin(0,0,m3sq) - 8*m1**6*m5sq*B0fin(0,0,m3sq) + 12*m1sq*m3**4*m5sq*B0fin(0,0,m3sq) + 6*m3**6*m5sq*B0fin(0,0,m3sq) - 2*m1**4*m3sq*m5sq*B0fin(0,0,m3sq) + m1**8*B0fin(0,0,m1sq)*B0fin(0,0,m3sq) - 2*m1**4*m3**4*B0fin(0,0,m1sq)*B0fin(0,0,m3sq) + m3**8*B0fin(0,0,m1sq)*B0fin(0,0,m3sq) - 8*m1sq*m3sq*m5**4*B0fin(0,0,m1sq)*B0fin(0,0,m3sq) + 2*m1sq*m5**6*B0fin(0,0,m1sq)*B0fin(0,0,m3sq) + 2*m3sq*m5**6*B0fin(0,0,m1sq)*B0fin(0,0,m3sq) - m5**8*B0fin(0,0,m1sq)*B0fin(0,0,m3sq) - 2*m1**6*m5sq*B0fin(0,0,m1sq)*B0fin(0,0,m3sq) + 6*m1sq*m3**4*m5sq*B0fin(0,0,m1sq)*B0fin(0,0,m3sq) - 2*m3**6*m5sq*B0fin(0,0,m1sq)*B0fin(0,0,m3sq) + 6*m1**4*m3sq*m5sq*B0fin(0,0,m1sq)*B0fin(0,0,m3sq) - 2*m1**6*m5*B0fin(0,0,m5) + 2*m1sq*m3**4*m5*B0fin(0,0,m5) - 2*m3**6*m5*B0fin(0,0,m5) + 2*m1**4*m3sq*m5*B0fin(0,0,m5) + 2*m1**4*m5**3*B0fin(0,0,m5) + 2*m3**4*m5**3*B0fin(0,0,m5) - 4*m1sq*m3sq*m5**3*B0fin(0,0,m5) + 2*m1sq*m5**5*B0fin(0,0,m5) + 2*m3sq*m5**5*B0fin(0,0,m5) - 2*m5**7*B0fin(0,0,m5) + 2*m1**8*B0fin(0,0,m5sq) + 12*m1**4*m3**4*B0fin(0,0,m5sq) - 8*m1sq*m3**6*B0fin(0,0,m5sq) + 2*m3**8*B0fin(0,0,m5sq) - 8*m1**6*m3sq*B0fin(0,0,m5sq) - 10*m1**4*m5**4*B0fin(0,0,m5sq) - 10*m3**4*m5**4*B0fin(0,0,m5sq) + 12*m1sq*m3sq*m5**4*B0fin(0,0,m5sq) + 6*m1sq*m5**6*B0fin(0,0,m5sq) + 6*m3sq*m5**6*B0fin(0,0,m5sq) + 2*m1**6*m5sq*B0fin(0,0,m5sq) - 2*m1sq*m3**4*m5sq*B0fin(0,0,m5sq) + 2*m3**6*m5sq*B0fin(0,0,m5sq) - 2*m1**4*m3sq*m5sq*B0fin(0,0,m5sq) + m1**8*B0fin(0,0,m1sq)*B0fin(0,0,m5sq) + 2*m1sq*m3**6*B0fin(0,0,m1sq)*B0fin(0,0,m5sq) - m3**8*B0fin(0,0,m1sq)*B0fin(0,0,m5sq) - 2*m1**6*m3sq*B0fin(0,0,m1sq)*B0fin(0,0,m5sq) - 2*m1**4*m5**4*B0fin(0,0,m1sq)*B0fin(0,0,m5sq) + 6*m1sq*m3sq*m5**4*B0fin(0,0,m1sq)*B0fin(0,0,m5sq) - 2*m3sq*m5**6*B0fin(0,0,m1sq)*B0fin(0,0,m5sq) + m5**8*B0fin(0,0,m1sq)*B0fin(0,0,m5sq) - 8*m1sq*m3**4*m5sq*B0fin(0,0,m1sq)*B0fin(0,0,m5sq) + 2*m3**6*m5sq*B0fin(0,0,m1sq)*B0fin(0,0,m5sq) + 6*m1**4*m3sq*m5sq*B0fin(0,0,m1sq)*B0fin(0,0,m5sq) - m1**8*B0fin(0,0,m3sq)*B0fin(0,0,m5sq) - 2*m1sq*m3**6*B0fin(0,0,m3sq)*B0fin(0,0,m5sq) + m3**8*B0fin(0,0,m3sq)*B0fin(0,0,m5sq) + 2*m1**6*m3sq*B0fin(0,0,m3sq)*B0fin(0,0,m5sq) - 2*m3**4*m5**4*B0fin(0,0,m3sq)*B0fin(0,0,m5sq) + 6*m1sq*m3sq*m5**4*B0fin(0,0,m3sq)*B0fin(0,0,m5sq) - 2*m1sq*m5**6*B0fin(0,0,m3sq)*B0fin(0,0,m5sq) + m5**8*B0fin(0,0,m3sq)*B0fin(0,0,m5sq) + 2*m1**6*m5sq*B0fin(0,0,m3sq)*B0fin(0,0,m5sq) + 6*m1sq*m3**4*m5sq*B0fin(0,0,m3sq)*B0fin(0,0,m5sq) - 8*m1**4*m3sq*m5sq*B0fin(0,0,m3sq)*B0fin(0,0,m5sq) - 2*m1**6*T134fin(m5,m3,m1) + 2*m1sq*m3**4*T134fin(m5,m3,m1) - 2*m3**6*T134fin(m5,m3,m1) + 2*m1**4*m3sq*T134fin(m5,m3,m1) + 2*m1sq*m5**4*T134fin(m5,m3,m1) + 2*m3sq*m5**4*T134fin(m5,m3,m1) - 2*m5**6*T134fin(m5,m3,m1) + 2*m1**4*m5sq*T134fin(m5,m3,m1) + 2*m3**4*m5sq*T134fin(m5,m3,m1) - 12*m1sq*m3sq*m5sq*T134fin(m5,m3,m1))/(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))**3)
		def eval_49():
			return -((-2*m1sq*m3sq*(m1sq - 4*m4sq)*(m2sq - 4*m4sq)*(m2**4 + (m3sq - m4sq)**2 - 2*m2sq*(m3sq + m4sq))*B0del(0,0,m1sq) + m1sq*(m2sq - 4*m4sq)*(m3**4 - 3*m4**4 - m1sq*(m3sq - 3*m4sq) - 6*m3sq*m4sq)*(m2**4 + (m3sq - m4sq)**2 - 2*m2sq*(m3sq + m4sq))*B0del(0,0,m1sq) + 2*m2sq*m3sq*(m1sq - 4*m4sq)*(m2sq - 4*m4sq)*(m1**4 + (m3sq - m4sq)**2 - 2*m1sq*(m3sq + m4sq))*B0del(0,0,m2sq) - m2sq*(m1sq - 4*m4sq)*(m3**4 - 3*m4**4 - m2sq*(m3sq - 3*m4sq) - 6*m3sq*m4sq)*(m1**4 + (m3sq - m4sq)**2 - 2*m1sq*(m3sq + m4sq))*B0del(0,0,m2sq) + (m1sq - m2sq)*m3sq*(m1sq - 4*m4sq)*(m2sq - 4*m4sq)*((m2sq - m3sq - 3*m4sq)*(m3sq - m4sq) - m1sq*(m2sq - m3sq + m4sq))*B0del(0,0,m3sq) + 2*m2sq*m3sq*(m1sq - 4*m4sq)*(m2sq - 4*m4sq)*(m1**4 + (m3sq - m4sq)**2 - 2*m1sq*(m3sq + m4sq))*B0del(0,0,m3sq) - 2*m1sq*m3sq*(m1sq - 4*m4sq)*(m2sq - 4*m4sq)*(m2**4 + (m3sq - m4sq)**2 - 2*m2sq*(m3sq + m4sq))*B0del(0,0,m3sq) + (m1sq - m2sq)*m3sq*(m1sq - 4*m4sq)*(m2sq - 4*m4sq)*((m2sq - m3sq - 3*m4sq)*(m3sq - m4sq) - m1sq*(m2sq - m3sq + m4sq))*B0del(0,0,m4sq) - m2sq*(m1sq - 4*m4sq)*(m3**4 - 3*m4**4 - m2sq*(m3sq - 3*m4sq) - 6*m3sq*m4sq)*(m1**4 + (m3sq - m4sq)**2 - 2*m1sq*(m3sq + m4sq))*B0del(0,0,m4sq) + m1sq*(m2sq - 4*m4sq)*(m3**4 - 3*m4**4 - m1sq*(m3sq - 3*m4sq) - 6*m3sq*m4sq)*(m2**4 + (m3sq - m4sq)**2 - 2*m2sq*(m3sq + m4sq))*B0del(0,0,m4sq) + 2*(m1sq - m2sq)*m4sq*(m1**4 + (m3sq - m4sq)**2 - 2*m1sq*(m3sq + m4sq))*(m2**4 + (m3sq - m4sq)**2 - 2*m2sq*(m3sq + m4sq))*B0del(0,0,m4sq) + 2*m1sq*m3sq*(m1sq - 4*m4sq)*(m2sq - 4*m4sq)*(m2**4 + (m3sq - m4sq)**2 - 2*m2sq*(m3sq + m4sq))*B0fin(0,0,m1sq) - m1sq*(m2sq - 4*m4sq)*(m3**4 - 3*m4**4 - m1sq*(m3sq - 3*m4sq) - 6*m3sq*m4sq)*(m2**4 + (m3sq - m4sq)**2 - 2*m2sq*(m3sq + m4sq))*B0fin(0,0,m1sq) - 2*m2sq*m3sq*(m1sq - 4*m4sq)*(m2sq - 4*m4sq)*(m1**4 + (m3sq - m4sq)**2 - 2*m1sq*(m3sq + m4sq))*B0fin(0,0,m2sq) + m2sq*(m1sq - 4*m4sq)*(m3**4 - 3*m4**4 - m2sq*(m3sq - 3*m4sq) - 6*m3sq*m4sq)*(m1**4 + (m3sq - m4sq)**2 - 2*m1sq*(m3sq + m4sq))*B0fin(0,0,m2sq) - (m1sq - m2sq)*m3sq*(m1sq - 4*m4sq)*(m2sq - 4*m4sq)*((m2sq - m3sq - 3*m4sq)*(m3sq - m4sq) - m1sq*(m2sq - m3sq + m4sq))*B0fin(0,0,m3sq) - 2*m2sq*m3sq*(m1sq - 4*m4sq)*(m2sq - 4*m4sq)*(m1**4 + (m3sq - m4sq)**2 - 2*m1sq*(m3sq + m4sq))*B0fin(0,0,m3sq) + 2*m1sq*m3sq*(m1sq - 4*m4sq)*(m2sq - 4*m4sq)*(m2**4 + (m3sq - m4sq)**2 - 2*m2sq*(m3sq + m4sq))*B0fin(0,0,m3sq) - 2*m1sq*m3sq*(m1sq - 4*m4sq)*(m2sq - 4*m4sq)*(m2**4 + (m3sq - m4sq)**2 - 2*m2sq*(m3sq + m4sq))*B0fin(0,0,m1sq)*B0fin(0,0,m3sq) + 2*m2sq*m3sq*(m1sq - 4*m4sq)*(m2sq - 4*m4sq)*(m1**4 + (m3sq - m4sq)**2 - 2*m1sq*(m3sq + m4sq))*B0fin(0,0,m2sq)*B0fin(0,0,m3sq) - 2*(m1sq - 4*m4sq)*(m2sq - 4*m4sq)*(m1sq + m3sq - m4sq)*(m2**4 + (m3sq - m4sq)**2 - 2*m2sq*(m3sq + m4sq))*((m1 + m3 + m4)/2. + m1*B0fin(0,0,m1) + m3*B0fin(0,0,m3) + m4*B0fin(0,0,m4)) + 2*(m1sq - 4*m4sq)*(m2sq - 4*m4sq)*(m2sq + m3sq - m4sq)*(m1**4 + (m3sq - m4sq)**2 - 2*m1sq*(m3sq + m4sq))*((m2 + m3 + m4)/2. + m2*B0fin(0,0,m2) + m3*B0fin(0,0,m3) + m4*B0fin(0,0,m4)) + 2*(m2sq - 4*m4sq)*(m1**4 + (m3sq - m4sq)**2 - 2*m1sq*(m3sq + m4sq))*(m2**4 + (m3sq - m4sq)**2 - 2*m2sq*(m3sq + m4sq))*(m1/2. + m4 + m1*B0fin(0,0,m1) + 2*m4*B0fin(0,0,m4)) - 2*(m1sq - 4*m4sq)*(m1**4 + (m3sq - m4sq)**2 - 2*m1sq*(m3sq + m4sq))*(m2**4 + (m3sq - m4sq)**2 - 2*m2sq*(m3sq + m4sq))*(m2/2. + m4 + m2*B0fin(0,0,m2) + 2*m4*B0fin(0,0,m4)) - (m1sq - m2sq)*m3sq*(m1sq - 4*m4sq)*(m2sq - 4*m4sq)*((m2sq - m3sq - 3*m4sq)*(m3sq - m4sq) - m1sq*(m2sq - m3sq + m4sq))*B0fin(0,0,m4sq) + m2sq*(m1sq - 4*m4sq)*(m3**4 - 3*m4**4 - m2sq*(m3sq - 3*m4sq) - 6*m3sq*m4sq)*(m1**4 + (m3sq - m4sq)**2 - 2*m1sq*(m3sq + m4sq))*B0fin(0,0,m4sq) - m1sq*(m2sq - 4*m4sq)*(m3**4 - 3*m4**4 - m1sq*(m3sq - 3*m4sq) - 6*m3sq*m4sq)*(m2**4 + (m3sq - m4sq)**2 - 2*m2sq*(m3sq + m4sq))*B0fin(0,0,m4sq) - 2*(m1sq - m2sq)*m4sq*(m1**4 + (m3sq - m4sq)**2 - 2*m1sq*(m3sq + m4sq))*(m2**4 + (m3sq - m4sq)**2 - 2*m2sq*(m3sq + m4sq))*B0fin(0,0,m4sq) + m1sq*(m2sq - 4*m4sq)*(m3**4 - 3*m4**4 - m1sq*(m3sq - 3*m4sq) - 6*m3sq*m4sq)*(m2**4 + (m3sq - m4sq)**2 - 2*m2sq*(m3sq + m4sq))*B0fin(0,0,m1sq)*B0fin(0,0,m4sq) - m2sq*(m1sq - 4*m4sq)*(m3**4 - 3*m4**4 - m2sq*(m3sq - 3*m4sq) - 6*m3sq*m4sq)*(m1**4 + (m3sq - m4sq)**2 - 2*m1sq*(m3sq + m4sq))*B0fin(0,0,m2sq)*B0fin(0,0,m4sq) + (m1sq - m2sq)*m3sq*(m1sq - 4*m4sq)*(m2sq - 4*m4sq)*((m2sq - m3sq - 3*m4sq)*(m3sq - m4sq) - m1sq*(m2sq - m3sq + m4sq))*B0fin(0,0,m3sq)*B0fin(0,0,m4sq) + (m1sq - m2sq)*m4sq*(m1**4 + (m3sq - m4sq)**2 - 2*m1sq*(m3sq + m4sq))*(m2**4 + (m3sq - m4sq)**2 - 2*m2sq*(m3sq + m4sq))*B0fin(0,0,m4sq)**2 + (m1sq - 4*m4sq)*(m2sq - 4*m4sq)*(m1sq + m3sq - m4sq)*(m2**4 + (m3sq - m4sq)**2 - 2*m2sq*(m3sq + m4sq))*T134fin(m4,m3,m1) - (m1sq - 4*m4sq)*(m2sq - 4*m4sq)*(m2sq + m3sq - m4sq)*(m1**4 + (m3sq - m4sq)**2 - 2*m1sq*(m3sq + m4sq))*T134fin(m4,m3,m2) - (m2sq - 4*m4sq)*(m1**4 + (m3sq - m4sq)**2 - 2*m1sq*(m3sq + m4sq))*(m2**4 + (m3sq - m4sq)**2 - 2*m2sq*(m3sq + m4sq))*T134fin(m4,m4,m1) + (m1sq - 4*m4sq)*(m1**4 + (m3sq - m4sq)**2 - 2*m1sq*(m3sq + m4sq))*(m2**4 + (m3sq - m4sq)**2 - 2*m2sq*(m3sq + m4sq))*T134fin(m4,m4,m2))/((m1sq - m2sq)*(m1sq - 4*m4sq)*(m2sq - 4*m4sq)*(m3sq - m4sq)*(m1**4 + (m3sq - m4sq)**2 - 2*m1sq*(m3sq + m4sq))*(m2**4 + (m3sq - m4sq)**2 - 2*m2sq*(m3sq + m4sq))))
		def eval_50():
			return (m2**6*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2 + 3*m2sq*m3**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2 + 4*m2**4*m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2 + 3*m2sq*(m1 + m3 - m5)**2*m5**4*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2 - 2*m2**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m2 + m3 + m5) - m1**6*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2 - 3*m1sq*m3**4*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2 - 4*m1**4*m3sq*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2 - 3*m1sq*(m2 + m3 - m5)**2*m5**4*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2 + 2*m1**4*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(m1 + m3 + m5)*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2 - 4*m2sq*m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq - m5sq) + 4*m1sq*m3sq*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*(m3sq - m5sq) + 2*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m2 + m3 + m5)*(m3sq - m5sq)**2 - 2*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(m1 + m3 + m5)*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*(m3sq - m5sq)**2 + 4*m2**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m5sq - 6*m2sq*m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m5sq - 4*m1**4*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*m5sq + 6*m1sq*m3sq*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*m5sq + 4*m2sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq - m5sq)*m5sq - 4*m1sq*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*(m3sq - m5sq)*m5sq - 3*m2**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq + m5sq) + 3*m1**4*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*(m3sq + m5sq) - (m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq - m5sq)**2*(m3sq + m5sq) + (m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*(m3sq - m5sq)**2*(m3sq + m5sq) + 2*m1**6*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*B0del(0,0,m1sq) - 2*m1**4*m3sq*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*B0del(0,0,m1sq) - 2*m1**4*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*m5sq*B0del(0,0,m1sq) - 2*m2**6*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0del(0,0,m2sq) + 2*m2**4*m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0del(0,0,m2sq) + 2*m2**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m5sq*B0del(0,0,m2sq) + m2sq*m3**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0del(0,0,m3sq) + m2sq*(m1 + m3 - m5)**2*m5**4*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0del(0,0,m3sq) - m1sq*m3**4*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*B0del(0,0,m3sq) - m1sq*(m2 + m3 - m5)**2*m5**4*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*B0del(0,0,m3sq) + m2sq*m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq - m5sq)*B0del(0,0,m3sq) - m1sq*m3sq*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*(m3sq - m5sq)*B0del(0,0,m3sq) + 2*m2**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m5sq*B0del(0,0,m3sq) + 2*m2sq*m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m5sq*B0del(0,0,m3sq) - 2*m1**4*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*m5sq*B0del(0,0,m3sq) - 2*m1sq*m3sq*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*m5sq*B0del(0,0,m3sq) + m2sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq - m5sq)*m5sq*B0del(0,0,m3sq) - m1sq*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*(m3sq - m5sq)*m5sq*B0del(0,0,m3sq) - 2*m2**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq + m5sq)*B0del(0,0,m3sq) + 2*m1**4*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*(m3sq + m5sq)*B0del(0,0,m3sq) + m2sq*m3**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0del(0,0,m5sq) + 2*m2**4*m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0del(0,0,m5sq) + m2sq*(m1 + m3 - m5)**2*m5**4*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0del(0,0,m5sq) - m1sq*m3**4*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*B0del(0,0,m5sq) - 2*m1**4*m3sq*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*B0del(0,0,m5sq) - m1sq*(m2 + m3 - m5)**2*m5**4*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*B0del(0,0,m5sq) - m2sq*m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq - m5sq)*B0del(0,0,m5sq) + m1sq*m3sq*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*(m3sq - m5sq)*B0del(0,0,m5sq) + 2*m2sq*m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m5sq*B0del(0,0,m5sq) - 2*m1sq*m3sq*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*m5sq*B0del(0,0,m5sq) - m2sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq - m5sq)*m5sq*B0del(0,0,m5sq) + m1sq*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*(m3sq - m5sq)*m5sq*B0del(0,0,m5sq) - 2*m2**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq + m5sq)*B0del(0,0,m5sq) + 2*m1**4*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*(m3sq + m5sq)*B0del(0,0,m5sq) - 2*m1**6*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*B0fin(0,0,m1sq) + 6*m1**4*m3sq*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*B0fin(0,0,m1sq) - 4*m1sq*m3sq*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*(m3sq - m5sq)*B0fin(0,0,m1sq) + 6*m1**4*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*m5sq*B0fin(0,0,m1sq) + 4*m1sq*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*(m3sq - m5sq)*m5sq*B0fin(0,0,m1sq) + 2*m2**6*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0fin(0,0,m2sq) - 6*m2**4*m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0fin(0,0,m2sq) + 4*m2sq*m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq - m5sq)*B0fin(0,0,m2sq) - 6*m2**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m5sq*B0fin(0,0,m2sq) - 4*m2sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq - m5sq)*m5sq*B0fin(0,0,m2sq) - m2**6*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0fin(0,0,m3sq) - 4*m2sq*m3**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0fin(0,0,m3sq) - 4*m2**4*m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0fin(0,0,m3sq) - 4*m2sq*(m1 + m3 - m5)**2*m5**4*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0fin(0,0,m3sq) + m1**6*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*B0fin(0,0,m3sq) + 4*m1sq*m3**4*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*B0fin(0,0,m3sq) + 4*m1**4*m3sq*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*B0fin(0,0,m3sq) + 4*m1sq*(m2 + m3 - m5)**2*m5**4*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*B0fin(0,0,m3sq) + 3*m2sq*m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq - m5sq)*B0fin(0,0,m3sq) - 3*m1sq*m3sq*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*(m3sq - m5sq)*B0fin(0,0,m3sq) - 2*m2**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m5sq*B0fin(0,0,m3sq) + 4*m2sq*m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m5sq*B0fin(0,0,m3sq) + 2*m1**4*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*m5sq*B0fin(0,0,m3sq) - 4*m1sq*m3sq*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*m5sq*B0fin(0,0,m3sq) - m2sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq - m5sq)*m5sq*B0fin(0,0,m3sq) + m1sq*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*(m3sq - m5sq)*m5sq*B0fin(0,0,m3sq) + 5*m2**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq + m5sq)*B0fin(0,0,m3sq) - 5*m1**4*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*(m3sq + m5sq)*B0fin(0,0,m3sq) + (m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq - m5sq)**2*(m3sq + m5sq)*B0fin(0,0,m3sq) - (m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*(m3sq - m5sq)**2*(m3sq + m5sq)*B0fin(0,0,m3sq) + m1**6*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*B0fin(0,0,m1sq)*B0fin(0,0,m3sq) - m1sq*m3sq*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*(m3sq - m5sq)*B0fin(0,0,m1sq)*B0fin(0,0,m3sq) - 2*m1**4*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*m5sq*B0fin(0,0,m1sq)*B0fin(0,0,m3sq) - m1sq*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*(m3sq - m5sq)*m5sq*B0fin(0,0,m1sq)*B0fin(0,0,m3sq) - m2**6*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0fin(0,0,m2sq)*B0fin(0,0,m3sq) + m2sq*m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq - m5sq)*B0fin(0,0,m2sq)*B0fin(0,0,m3sq) + 2*m2**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m5sq*B0fin(0,0,m2sq)*B0fin(0,0,m3sq) + m2sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq - m5sq)*m5sq*B0fin(0,0,m2sq)*B0fin(0,0,m3sq) + m1**4*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*(m1 + m3 + m5 + 2*m1*B0fin(0,0,m1) + 2*m3*B0fin(0,0,m3) + 2*m5*B0fin(0,0,m5)) + (m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*(m3sq - m5sq)**2*(m1 + m3 + m5 + 2*m1*B0fin(0,0,m1) + 2*m3*B0fin(0,0,m3) + 2*m5*B0fin(0,0,m5)) - 2*m1sq*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*(m3sq + m5sq)*(m1 + m3 + m5 + 2*m1*B0fin(0,0,m1) + 2*m3*B0fin(0,0,m3) + 2*m5*B0fin(0,0,m5)) - m2**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m2 + m3 + m5 + 2*m2*B0fin(0,0,m2) + 2*m3*B0fin(0,0,m3) + 2*m5*B0fin(0,0,m5)) - (m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq - m5sq)**2*(m2 + m3 + m5 + 2*m2*B0fin(0,0,m2) + 2*m3*B0fin(0,0,m3) + 2*m5*B0fin(0,0,m5)) + 2*m2sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq + m5sq)*(m2 + m3 + m5 + 2*m2*B0fin(0,0,m2) + 2*m3*B0fin(0,0,m3) + 2*m5*B0fin(0,0,m5)) - m2**6*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0fin(0,0,m5sq) - 4*m2sq*m3**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0fin(0,0,m5sq) - 2*m2**4*m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0fin(0,0,m5sq) - 4*m2sq*(m1 + m3 - m5)**2*m5**4*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0fin(0,0,m5sq) + m1**6*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*B0fin(0,0,m5sq) + 4*m1sq*m3**4*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*B0fin(0,0,m5sq) + 2*m1**4*m3sq*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*B0fin(0,0,m5sq) + 4*m1sq*(m2 + m3 - m5)**2*m5**4*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*B0fin(0,0,m5sq) + m2sq*m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq - m5sq)*B0fin(0,0,m5sq) - m1sq*m3sq*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*(m3sq - m5sq)*B0fin(0,0,m5sq) - 4*m2**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m5sq*B0fin(0,0,m5sq) + 4*m2sq*m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m5sq*B0fin(0,0,m5sq) + 4*m1**4*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*m5sq*B0fin(0,0,m5sq) - 4*m1sq*m3sq*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*m5sq*B0fin(0,0,m5sq) - 3*m2sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq - m5sq)*m5sq*B0fin(0,0,m5sq) + 3*m1sq*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*(m3sq - m5sq)*m5sq*B0fin(0,0,m5sq) + 5*m2**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq + m5sq)*B0fin(0,0,m5sq) - 5*m1**4*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*(m3sq + m5sq)*B0fin(0,0,m5sq) + (m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq - m5sq)**2*(m3sq + m5sq)*B0fin(0,0,m5sq) - (m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*(m3sq - m5sq)**2*(m3sq + m5sq)*B0fin(0,0,m5sq) + m1**6*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*B0fin(0,0,m1sq)*B0fin(0,0,m5sq) - 2*m1**4*m3sq*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*B0fin(0,0,m1sq)*B0fin(0,0,m5sq) + m1sq*m3sq*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*(m3sq - m5sq)*B0fin(0,0,m1sq)*B0fin(0,0,m5sq) + m1sq*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*(m3sq - m5sq)*m5sq*B0fin(0,0,m1sq)*B0fin(0,0,m5sq) - m2**6*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0fin(0,0,m2sq)*B0fin(0,0,m5sq) + 2*m2**4*m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0fin(0,0,m2sq)*B0fin(0,0,m5sq) - m2sq*m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq - m5sq)*B0fin(0,0,m2sq)*B0fin(0,0,m5sq) - m2sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq - m5sq)*m5sq*B0fin(0,0,m2sq)*B0fin(0,0,m5sq) + m2**6*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0fin(0,0,m3sq)*B0fin(0,0,m5sq) + m2sq*m3**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0fin(0,0,m3sq)*B0fin(0,0,m5sq) + m2sq*(m1 + m3 - m5)**2*m5**4*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0fin(0,0,m3sq)*B0fin(0,0,m5sq) - m1**6*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*B0fin(0,0,m3sq)*B0fin(0,0,m5sq) - m1sq*m3**4*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*B0fin(0,0,m3sq)*B0fin(0,0,m5sq) - m1sq*(m2 + m3 - m5)**2*m5**4*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*B0fin(0,0,m3sq)*B0fin(0,0,m5sq) + 2*m2sq*m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m5sq*B0fin(0,0,m3sq)*B0fin(0,0,m5sq) - 2*m1sq*m3sq*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*m5sq*B0fin(0,0,m3sq)*B0fin(0,0,m5sq) - 2*m2**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq + m5sq)*B0fin(0,0,m3sq)*B0fin(0,0,m5sq) + 2*m1**4*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*(m3sq + m5sq)*B0fin(0,0,m3sq)*B0fin(0,0,m5sq) - 2*m1**4*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*T134fin(m5,m3,m1) + 2*m1sq*(m2 + m3 - m5)**2*(m2 - m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2*(m3sq + m5sq)*T134fin(m5,m3,m1) + 2*m2**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*T134fin(m5,m3,m2) - 2*m2sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq + m5sq)*T134fin(m5,m3,m2))/((m1sq - m2sq)*(m1 + m3 - m5)**2*(m2 + m3 - m5)**2*(m1 - m3 + m5)**2*(m2 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(-m2 + m3 + m5)**2*(m2 + m3 + m5)**2)
		def eval_51():
			return -(((2*m1sq*m6sq*B0del(0,0,m1sq))/((m1sq - m2sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) - (m1sq*(-3*m3**4 + m6**4 + m1sq*(3*m3sq - m6sq) - 6*m3sq*m6sq)*B0del(0,0,m1sq))/((m1sq - m2sq)*(m1sq - 4*m3sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) - (2*m2sq*m6sq*B0del(0,0,m2sq))/((m1sq - m2sq)*(m2**4 + (m3sq - m6sq)**2 - 2*m2sq*(m3sq + m6sq))) + (m2sq*(-3*m3**4 + m6**4 + m2sq*(3*m3sq - m6sq) - 6*m3sq*m6sq)*B0del(0,0,m2sq))/((m1sq - m2sq)*(m2sq - 4*m3sq)*(m2**4 + (m3sq - m6sq)**2 - 2*m2sq*(m3sq + m6sq))) + (2*m3sq*B0del(0,0,m3sq))/((m1sq - 4*m3sq)*(-m2sq + 4*m3sq)) - (m1sq*(-3*m3**4 + m6**4 + m1sq*(3*m3sq - m6sq) - 6*m3sq*m6sq)*B0del(0,0,m3sq))/((m1sq - m2sq)*(m1sq - 4*m3sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) + (m2sq*(-3*m3**4 + m6**4 + m2sq*(3*m3sq - m6sq) - 6*m3sq*m6sq)*B0del(0,0,m3sq))/((m1sq - m2sq)*(m2sq - 4*m3sq)*(m2**4 + (m3sq - m6sq)**2 - 2*m2sq*(m3sq + m6sq))) + (((m2sq - 3*m3sq - m6sq)*(m3sq - m6sq) + m1sq*(m2sq + m3sq - m6sq))*m6sq*B0del(0,0,m3sq))/((m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))*(m2**4 + (m3sq - m6sq)**2 - 2*m2sq*(m3sq + m6sq))) + (2*m1sq*m6sq*B0del(0,0,m6sq))/((m1sq - m2sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) - (2*m2sq*m6sq*B0del(0,0,m6sq))/((m1sq - m2sq)*(m2**4 + (m3sq - m6sq)**2 - 2*m2sq*(m3sq + m6sq))) + (((m2sq - 3*m3sq - m6sq)*(m3sq - m6sq) + m1sq*(m2sq + m3sq - m6sq))*m6sq*B0del(0,0,m6sq))/((m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))*(m2**4 + (m3sq - m6sq)**2 - 2*m2sq*(m3sq + m6sq))) - (2*m1sq*m6sq*B0fin(0,0,m1sq))/((m1sq - m2sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) + (m1sq*(-3*m3**4 + m6**4 + m1sq*(3*m3sq - m6sq) - 6*m3sq*m6sq)*B0fin(0,0,m1sq))/((m1sq - m2sq)*(m1sq - 4*m3sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) + (2*m2sq*m6sq*B0fin(0,0,m2sq))/((m1sq - m2sq)*(m2**4 + (m3sq - m6sq)**2 - 2*m2sq*(m3sq + m6sq))) - (m2sq*(-3*m3**4 + m6**4 + m2sq*(3*m3sq - m6sq) - 6*m3sq*m6sq)*B0fin(0,0,m2sq))/((m1sq - m2sq)*(m2sq - 4*m3sq)*(m2**4 + (m3sq - m6sq)**2 - 2*m2sq*(m3sq + m6sq))) - (m1 + 2*m3 + 2*m1*B0fin(0,0,m1) + 4*m3*B0fin(0,0,m3))/((m1sq - m2sq)*(m1sq - 4*m3sq)) + (m2 + 2*m3 + 2*m2*B0fin(0,0,m2) + 4*m3*B0fin(0,0,m3))/((m1sq - m2sq)*(m2sq - 4*m3sq)) - (2*m3sq*B0fin(0,0,m3sq))/((m1sq - 4*m3sq)*(-m2sq + 4*m3sq)) + (m1sq*(-3*m3**4 + m6**4 + m1sq*(3*m3sq - m6sq) - 6*m3sq*m6sq)*B0fin(0,0,m3sq))/((m1sq - m2sq)*(m1sq - 4*m3sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) - (m2sq*(-3*m3**4 + m6**4 + m2sq*(3*m3sq - m6sq) - 6*m3sq*m6sq)*B0fin(0,0,m3sq))/((m1sq - m2sq)*(m2sq - 4*m3sq)*(m2**4 + (m3sq - m6sq)**2 - 2*m2sq*(m3sq + m6sq))) - (((m2sq - 3*m3sq - m6sq)*(m3sq - m6sq) + m1sq*(m2sq + m3sq - m6sq))*m6sq*B0fin(0,0,m3sq))/((m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))*(m2**4 + (m3sq - m6sq)**2 - 2*m2sq*(m3sq + m6sq))) - (m1sq*(-3*m3**4 + m6**4 + m1sq*(3*m3sq - m6sq) - 6*m3sq*m6sq)*B0fin(0,0,m1sq)*B0fin(0,0,m3sq))/((m1sq - m2sq)*(m1sq - 4*m3sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) + (m2sq*(-3*m3**4 + m6**4 + m2sq*(3*m3sq - m6sq) - 6*m3sq*m6sq)*B0fin(0,0,m2sq)*B0fin(0,0,m3sq))/((m1sq - m2sq)*(m2sq - 4*m3sq)*(m2**4 + (m3sq - m6sq)**2 - 2*m2sq*(m3sq + m6sq))) + (m3sq*B0fin(0,0,m3sq)**2)/((m1sq - 4*m3sq)*(-m2sq + 4*m3sq)) + ((m1sq - m3sq + m6sq)*(m1 + m3 + m6 + 2*m1*B0fin(0,0,m1) + 2*m3*B0fin(0,0,m3) + 2*m6*B0fin(0,0,m6)))/((m1sq - m2sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) - ((m2sq - m3sq + m6sq)*(m2 + m3 + m6 + 2*m2*B0fin(0,0,m2) + 2*m3*B0fin(0,0,m3) + 2*m6*B0fin(0,0,m6)))/((m1sq - m2sq)*(m2**4 + (m3sq - m6sq)**2 - 2*m2sq*(m3sq + m6sq))) - (2*m1sq*m6sq*B0fin(0,0,m6sq))/((m1sq - m2sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) + (2*m2sq*m6sq*B0fin(0,0,m6sq))/((m1sq - m2sq)*(m2**4 + (m3sq - m6sq)**2 - 2*m2sq*(m3sq + m6sq))) - (((m2sq - 3*m3sq - m6sq)*(m3sq - m6sq) + m1sq*(m2sq + m3sq - m6sq))*m6sq*B0fin(0,0,m6sq))/((m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))*(m2**4 + (m3sq - m6sq)**2 - 2*m2sq*(m3sq + m6sq))) + (2*m1sq*m6sq*B0fin(0,0,m1sq)*B0fin(0,0,m6sq))/((m1sq - m2sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) - (2*m2sq*m6sq*B0fin(0,0,m2sq)*B0fin(0,0,m6sq))/((m1sq - m2sq)*(m2**4 + (m3sq - m6sq)**2 - 2*m2sq*(m3sq + m6sq))) + (((m2sq - 3*m3sq - m6sq)*(m3sq - m6sq) + m1sq*(m2sq + m3sq - m6sq))*m6sq*B0fin(0,0,m3sq)*B0fin(0,0,m6sq))/((m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))*(m2**4 + (m3sq - m6sq)**2 - 2*m2sq*(m3sq + m6sq))) + T134fin(m3,m3,m1)/((m1sq - m2sq)*(m1sq - 4*m3sq)) - T134fin(m3,m3,m2)/((m1sq - m2sq)*(m2sq - 4*m3sq)) - ((m1sq - m3sq + m6sq)*T134fin(m6,m3,m1))/((m1sq - m2sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) + ((m2sq - m3sq + m6sq)*T134fin(m6,m3,m2))/((m1sq - m2sq)*(m2**4 + (m3sq - m6sq)**2 - 2*m2sq*(m3sq + m6sq))))/(m3sq - m6sq))
		def eval_52():
			return -(((2*m1sq*m4sq*B0del(0,0,m1sq))/((m1sq - m2sq)*(m1**4 + (m3sq - m4sq)**2 - 2*m1sq*(m3sq + m4sq))) - (m1sq*(-3*m3**4 + m4**4 + m1sq*(3*m3sq - m4sq) - 6*m3sq*m4sq)*B0del(0,0,m1sq))/((m1sq - m2sq)*(m1sq - 4*m3sq)*(m1**4 + (m3sq - m4sq)**2 - 2*m1sq*(m3sq + m4sq))) - (2*m2sq*m4sq*B0del(0,0,m2sq))/((m1sq - m2sq)*(m2**4 + (m3sq - m4sq)**2 - 2*m2sq*(m3sq + m4sq))) + (m2sq*(-3*m3**4 + m4**4 + m2sq*(3*m3sq - m4sq) - 6*m3sq*m4sq)*B0del(0,0,m2sq))/((m1sq - m2sq)*(m2sq - 4*m3sq)*(m2**4 + (m3sq - m4sq)**2 - 2*m2sq*(m3sq + m4sq))) + (2*m3sq*B0del(0,0,m3sq))/((m1sq - 4*m3sq)*(-m2sq + 4*m3sq)) - (m1sq*(-3*m3**4 + m4**4 + m1sq*(3*m3sq - m4sq) - 6*m3sq*m4sq)*B0del(0,0,m3sq))/((m1sq - m2sq)*(m1sq - 4*m3sq)*(m1**4 + (m3sq - m4sq)**2 - 2*m1sq*(m3sq + m4sq))) + (m2sq*(-3*m3**4 + m4**4 + m2sq*(3*m3sq - m4sq) - 6*m3sq*m4sq)*B0del(0,0,m3sq))/((m1sq - m2sq)*(m2sq - 4*m3sq)*(m2**4 + (m3sq - m4sq)**2 - 2*m2sq*(m3sq + m4sq))) + (((m2sq - 3*m3sq - m4sq)*(m3sq - m4sq) + m1sq*(m2sq + m3sq - m4sq))*m4sq*B0del(0,0,m3sq))/((m1**4 + (m3sq - m4sq)**2 - 2*m1sq*(m3sq + m4sq))*(m2**4 + (m3sq - m4sq)**2 - 2*m2sq*(m3sq + m4sq))) + (2*m1sq*m4sq*B0del(0,0,m4sq))/((m1sq - m2sq)*(m1**4 + (m3sq - m4sq)**2 - 2*m1sq*(m3sq + m4sq))) - (2*m2sq*m4sq*B0del(0,0,m4sq))/((m1sq - m2sq)*(m2**4 + (m3sq - m4sq)**2 - 2*m2sq*(m3sq + m4sq))) + (((m2sq - 3*m3sq - m4sq)*(m3sq - m4sq) + m1sq*(m2sq + m3sq - m4sq))*m4sq*B0del(0,0,m4sq))/((m1**4 + (m3sq - m4sq)**2 - 2*m1sq*(m3sq + m4sq))*(m2**4 + (m3sq - m4sq)**2 - 2*m2sq*(m3sq + m4sq))) - (2*m1sq*m4sq*B0fin(0,0,m1sq))/((m1sq - m2sq)*(m1**4 + (m3sq - m4sq)**2 - 2*m1sq*(m3sq + m4sq))) + (m1sq*(-3*m3**4 + m4**4 + m1sq*(3*m3sq - m4sq) - 6*m3sq*m4sq)*B0fin(0,0,m1sq))/((m1sq - m2sq)*(m1sq - 4*m3sq)*(m1**4 + (m3sq - m4sq)**2 - 2*m1sq*(m3sq + m4sq))) + (2*m2sq*m4sq*B0fin(0,0,m2sq))/((m1sq - m2sq)*(m2**4 + (m3sq - m4sq)**2 - 2*m2sq*(m3sq + m4sq))) - (m2sq*(-3*m3**4 + m4**4 + m2sq*(3*m3sq - m4sq) - 6*m3sq*m4sq)*B0fin(0,0,m2sq))/((m1sq - m2sq)*(m2sq - 4*m3sq)*(m2**4 + (m3sq - m4sq)**2 - 2*m2sq*(m3sq + m4sq))) - (m1 + 2*m3 + 2*m1*B0fin(0,0,m1) + 4*m3*B0fin(0,0,m3))/((m1sq - m2sq)*(m1sq - 4*m3sq)) + (m2 + 2*m3 + 2*m2*B0fin(0,0,m2) + 4*m3*B0fin(0,0,m3))/((m1sq - m2sq)*(m2sq - 4*m3sq)) - (2*m3sq*B0fin(0,0,m3sq))/((m1sq - 4*m3sq)*(-m2sq + 4*m3sq)) + (m1sq*(-3*m3**4 + m4**4 + m1sq*(3*m3sq - m4sq) - 6*m3sq*m4sq)*B0fin(0,0,m3sq))/((m1sq - m2sq)*(m1sq - 4*m3sq)*(m1**4 + (m3sq - m4sq)**2 - 2*m1sq*(m3sq + m4sq))) - (m2sq*(-3*m3**4 + m4**4 + m2sq*(3*m3sq - m4sq) - 6*m3sq*m4sq)*B0fin(0,0,m3sq))/((m1sq - m2sq)*(m2sq - 4*m3sq)*(m2**4 + (m3sq - m4sq)**2 - 2*m2sq*(m3sq + m4sq))) - (((m2sq - 3*m3sq - m4sq)*(m3sq - m4sq) + m1sq*(m2sq + m3sq - m4sq))*m4sq*B0fin(0,0,m3sq))/((m1**4 + (m3sq - m4sq)**2 - 2*m1sq*(m3sq + m4sq))*(m2**4 + (m3sq - m4sq)**2 - 2*m2sq*(m3sq + m4sq))) - (m1sq*(-3*m3**4 + m4**4 + m1sq*(3*m3sq - m4sq) - 6*m3sq*m4sq)*B0fin(0,0,m1sq)*B0fin(0,0,m3sq))/((m1sq - m2sq)*(m1sq - 4*m3sq)*(m1**4 + (m3sq - m4sq)**2 - 2*m1sq*(m3sq + m4sq))) + (m2sq*(-3*m3**4 + m4**4 + m2sq*(3*m3sq - m4sq) - 6*m3sq*m4sq)*B0fin(0,0,m2sq)*B0fin(0,0,m3sq))/((m1sq - m2sq)*(m2sq - 4*m3sq)*(m2**4 + (m3sq - m4sq)**2 - 2*m2sq*(m3sq + m4sq))) + (m3sq*B0fin(0,0,m3sq)**2)/((m1sq - 4*m3sq)*(-m2sq + 4*m3sq)) + ((m1sq - m3sq + m4sq)*(m1 + m3 + m4 + 2*m1*B0fin(0,0,m1) + 2*m3*B0fin(0,0,m3) + 2*m4*B0fin(0,0,m4)))/((m1sq - m2sq)*(m1**4 + (m3sq - m4sq)**2 - 2*m1sq*(m3sq + m4sq))) - ((m2sq - m3sq + m4sq)*(m2 + m3 + m4 + 2*m2*B0fin(0,0,m2) + 2*m3*B0fin(0,0,m3) + 2*m4*B0fin(0,0,m4)))/((m1sq - m2sq)*(m2**4 + (m3sq - m4sq)**2 - 2*m2sq*(m3sq + m4sq))) - (2*m1sq*m4sq*B0fin(0,0,m4sq))/((m1sq - m2sq)*(m1**4 + (m3sq - m4sq)**2 - 2*m1sq*(m3sq + m4sq))) + (2*m2sq*m4sq*B0fin(0,0,m4sq))/((m1sq - m2sq)*(m2**4 + (m3sq - m4sq)**2 - 2*m2sq*(m3sq + m4sq))) - (((m2sq - 3*m3sq - m4sq)*(m3sq - m4sq) + m1sq*(m2sq + m3sq - m4sq))*m4sq*B0fin(0,0,m4sq))/((m1**4 + (m3sq - m4sq)**2 - 2*m1sq*(m3sq + m4sq))*(m2**4 + (m3sq - m4sq)**2 - 2*m2sq*(m3sq + m4sq))) + (2*m1sq*m4sq*B0fin(0,0,m1sq)*B0fin(0,0,m4sq))/((m1sq - m2sq)*(m1**4 + (m3sq - m4sq)**2 - 2*m1sq*(m3sq + m4sq))) - (2*m2sq*m4sq*B0fin(0,0,m2sq)*B0fin(0,0,m4sq))/((m1sq - m2sq)*(m2**4 + (m3sq - m4sq)**2 - 2*m2sq*(m3sq + m4sq))) + (((m2sq - 3*m3sq - m4sq)*(m3sq - m4sq) + m1sq*(m2sq + m3sq - m4sq))*m4sq*B0fin(0,0,m3sq)*B0fin(0,0,m4sq))/((m1**4 + (m3sq - m4sq)**2 - 2*m1sq*(m3sq + m4sq))*(m2**4 + (m3sq - m4sq)**2 - 2*m2sq*(m3sq + m4sq))) + T134fin(m3,m3,m1)/((m1sq - m2sq)*(m1sq - 4*m3sq)) - T134fin(m3,m3,m2)/((m1sq - m2sq)*(m2sq - 4*m3sq)) - ((m1sq - m3sq + m4sq)*T134fin(m4,m3,m1))/((m1sq - m2sq)*(m1**4 + (m3sq - m4sq)**2 - 2*m1sq*(m3sq + m4sq))) + ((m2sq - m3sq + m4sq)*T134fin(m4,m3,m2))/((m1sq - m2sq)*(m2**4 + (m3sq - m4sq)**2 - 2*m2sq*(m3sq + m4sq))))/(m3sq - m4sq))
		def eval_53():
			return (-2*m1sq*(4*m2sq - m5sq)*(m1**4 + (m2sq - m5sq)**2 - 2*m1sq*(m2sq + m5sq))*(4*m2sq - m6sq)*m6sq*B0del(0,0,m1sq) + 2*m1sq*(4*m2sq - m5sq)*m5sq*(4*m2sq - m6sq)*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))*B0del(0,0,m1sq) + m1sq*(4*m2sq - m5sq)*(4*m2sq - m6sq)*(m5sq - m6sq)*(m1**4 - 3*m2**4 + m1sq*(2*m2sq - m5sq - m6sq) + m5sq*m6sq + m2sq*(m5sq + m6sq))*B0del(0,0,m1sq) + m5sq*(m1**4 - 3*m2**4 + 3*m2sq*m5sq - m1sq*(6*m2sq + m5sq))*(4*m2sq - m6sq)*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))*B0del(0,0,m2sq) - 2*m2sq*(m1**4 + (m2sq - m5sq)**2 - 2*m1sq*(m2sq + m5sq))*(m5sq - m6sq)*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))*B0del(0,0,m2sq) - (4*m2sq - m5sq)*(m1**4 + (m2sq - m5sq)**2 - 2*m1sq*(m2sq + m5sq))*m6sq*(m1**4 - 3*m2**4 + 3*m2sq*m6sq - m1sq*(6*m2sq + m6sq))*B0del(0,0,m2sq) + m1sq*(4*m2sq - m5sq)*(4*m2sq - m6sq)*(m5sq - m6sq)*(m1**4 - 3*m2**4 + m1sq*(2*m2sq - m5sq - m6sq) + m5sq*m6sq + m2sq*(m5sq + m6sq))*B0del(0,0,m2sq) + 2*m1sq*(4*m2sq - m5sq)*m5sq*(4*m2sq - m6sq)*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))*B0del(0,0,m5sq) + m5sq*(m1**4 - 3*m2**4 + 3*m2sq*m5sq - m1sq*(6*m2sq + m5sq))*(4*m2sq - m6sq)*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))*B0del(0,0,m5sq) - 2*m1sq*(4*m2sq - m5sq)*(m1**4 + (m2sq - m5sq)**2 - 2*m1sq*(m2sq + m5sq))*(4*m2sq - m6sq)*m6sq*B0del(0,0,m6sq) - (4*m2sq - m5sq)*(m1**4 + (m2sq - m5sq)**2 - 2*m1sq*(m2sq + m5sq))*m6sq*(m1**4 - 3*m2**4 + 3*m2sq*m6sq - m1sq*(6*m2sq + m6sq))*B0del(0,0,m6sq) + 2*m1sq*(4*m2sq - m5sq)*(m1**4 + (m2sq - m5sq)**2 - 2*m1sq*(m2sq + m5sq))*(4*m2sq - m6sq)*m6sq*B0fin(0,0,m1sq) - 2*m1sq*(4*m2sq - m5sq)*m5sq*(4*m2sq - m6sq)*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))*B0fin(0,0,m1sq) - m1sq*(4*m2sq - m5sq)*(4*m2sq - m6sq)*(m5sq - m6sq)*(m1**4 - 3*m2**4 + m1sq*(2*m2sq - m5sq - m6sq) + m5sq*m6sq + m2sq*(m5sq + m6sq))*B0fin(0,0,m1sq) - m5sq*(m1**4 - 3*m2**4 + 3*m2sq*m5sq - m1sq*(6*m2sq + m5sq))*(4*m2sq - m6sq)*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))*B0fin(0,0,m2sq) + 2*m2sq*(m1**4 + (m2sq - m5sq)**2 - 2*m1sq*(m2sq + m5sq))*(m5sq - m6sq)*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))*B0fin(0,0,m2sq) + (4*m2sq - m5sq)*(m1**4 + (m2sq - m5sq)**2 - 2*m1sq*(m2sq + m5sq))*m6sq*(m1**4 - 3*m2**4 + 3*m2sq*m6sq - m1sq*(6*m2sq + m6sq))*B0fin(0,0,m2sq) - m1sq*(4*m2sq - m5sq)*(4*m2sq - m6sq)*(m5sq - m6sq)*(m1**4 - 3*m2**4 + m1sq*(2*m2sq - m5sq - m6sq) + m5sq*m6sq + m2sq*(m5sq + m6sq))*B0fin(0,0,m2sq) + m1sq*(4*m2sq - m5sq)*(4*m2sq - m6sq)*(m5sq - m6sq)*(m1**4 - 3*m2**4 + m1sq*(2*m2sq - m5sq - m6sq) + m5sq*m6sq + m2sq*(m5sq + m6sq))*B0fin(0,0,m1sq)*B0fin(0,0,m2sq) - m2sq*(m1**4 + (m2sq - m5sq)**2 - 2*m1sq*(m2sq + m5sq))*(m5sq - m6sq)*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))*B0fin(0,0,m2sq)**2 + 2*(4*m2sq - m5sq)*(m1sq - m2sq + m5sq)*(4*m2sq - m6sq)*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))*((m1 + m2 + m5)/2. + m1*B0fin(0,0,m1) + m2*B0fin(0,0,m2) + m5*B0fin(0,0,m5)) + 2*(m1**4 + (m2sq - m5sq)**2 - 2*m1sq*(m2sq + m5sq))*(4*m2sq - m6sq)*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))*(m2 + m5/2. + 2*m2*B0fin(0,0,m2) + m5*B0fin(0,0,m5)) - 2*m1sq*(4*m2sq - m5sq)*m5sq*(4*m2sq - m6sq)*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))*B0fin(0,0,m5sq) - m5sq*(m1**4 - 3*m2**4 + 3*m2sq*m5sq - m1sq*(6*m2sq + m5sq))*(4*m2sq - m6sq)*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))*B0fin(0,0,m5sq) + 2*m1sq*(4*m2sq - m5sq)*m5sq*(4*m2sq - m6sq)*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))*B0fin(0,0,m1sq)*B0fin(0,0,m5sq) + m5sq*(m1**4 - 3*m2**4 + 3*m2sq*m5sq - m1sq*(6*m2sq + m5sq))*(4*m2sq - m6sq)*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))*B0fin(0,0,m2sq)*B0fin(0,0,m5sq) - 2*(4*m2sq - m5sq)*(m1**4 + (m2sq - m5sq)**2 - 2*m1sq*(m2sq + m5sq))*(4*m2sq - m6sq)*(m1sq - m2sq + m6sq)*((m1 + m2 + m6)/2. + m1*B0fin(0,0,m1) + m2*B0fin(0,0,m2) + m6*B0fin(0,0,m6)) - 2*(4*m2sq - m5sq)*(m1**4 + (m2sq - m5sq)**2 - 2*m1sq*(m2sq + m5sq))*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))*(m2 + m6/2. + 2*m2*B0fin(0,0,m2) + m6*B0fin(0,0,m6)) + 2*m1sq*(4*m2sq - m5sq)*(m1**4 + (m2sq - m5sq)**2 - 2*m1sq*(m2sq + m5sq))*(4*m2sq - m6sq)*m6sq*B0fin(0,0,m6sq) + (4*m2sq - m5sq)*(m1**4 + (m2sq - m5sq)**2 - 2*m1sq*(m2sq + m5sq))*m6sq*(m1**4 - 3*m2**4 + 3*m2sq*m6sq - m1sq*(6*m2sq + m6sq))*B0fin(0,0,m6sq) - 2*m1sq*(4*m2sq - m5sq)*(m1**4 + (m2sq - m5sq)**2 - 2*m1sq*(m2sq + m5sq))*(4*m2sq - m6sq)*m6sq*B0fin(0,0,m1sq)*B0fin(0,0,m6sq) - (4*m2sq - m5sq)*(m1**4 + (m2sq - m5sq)**2 - 2*m1sq*(m2sq + m5sq))*m6sq*(m1**4 - 3*m2**4 + 3*m2sq*m6sq - m1sq*(6*m2sq + m6sq))*B0fin(0,0,m2sq)*B0fin(0,0,m6sq) - (4*m2sq - m5sq)*(m1sq - m2sq + m5sq)*(4*m2sq - m6sq)*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))*T134fin(m5,m2,m1) - (m1**4 + (m2sq - m5sq)**2 - 2*m1sq*(m2sq + m5sq))*(4*m2sq - m6sq)*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))*T134fin(m5,m2,m2) + (4*m2sq - m5sq)*(m1**4 + (m2sq - m5sq)**2 - 2*m1sq*(m2sq + m5sq))*(4*m2sq - m6sq)*(m1sq - m2sq + m6sq)*T134fin(m6,m2,m1) + (4*m2sq - m5sq)*(m1**4 + (m2sq - m5sq)**2 - 2*m1sq*(m2sq + m5sq))*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))*T134fin(m6,m2,m2))/((m1sq - m2sq)*(4*m2sq - m5sq)*(m1**4 + (m2sq - m5sq)**2 - 2*m1sq*(m2sq + m5sq))*(4*m2sq - m6sq)*(m5sq - m6sq)*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq)))
		def eval_54():
			return (-2*m1sq*(4*m2sq - m3sq)*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*(4*m2sq - m4sq)*m4sq*B0del(0,0,m1sq) + 2*m1sq*(4*m2sq - m3sq)*m3sq*(4*m2sq - m4sq)*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))*B0del(0,0,m1sq) + m1sq*(4*m2sq - m3sq)*(4*m2sq - m4sq)*(m3sq - m4sq)*(m1**4 - 3*m2**4 + m1sq*(2*m2sq - m3sq - m4sq) + m3sq*m4sq + m2sq*(m3sq + m4sq))*B0del(0,0,m1sq) + m3sq*(m1**4 - 3*m2**4 + 3*m2sq*m3sq - m1sq*(6*m2sq + m3sq))*(4*m2sq - m4sq)*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))*B0del(0,0,m2sq) - 2*m2sq*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*(m3sq - m4sq)*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))*B0del(0,0,m2sq) - (4*m2sq - m3sq)*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*m4sq*(m1**4 - 3*m2**4 + 3*m2sq*m4sq - m1sq*(6*m2sq + m4sq))*B0del(0,0,m2sq) + m1sq*(4*m2sq - m3sq)*(4*m2sq - m4sq)*(m3sq - m4sq)*(m1**4 - 3*m2**4 + m1sq*(2*m2sq - m3sq - m4sq) + m3sq*m4sq + m2sq*(m3sq + m4sq))*B0del(0,0,m2sq) + 2*m1sq*(4*m2sq - m3sq)*m3sq*(4*m2sq - m4sq)*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))*B0del(0,0,m3sq) + m3sq*(m1**4 - 3*m2**4 + 3*m2sq*m3sq - m1sq*(6*m2sq + m3sq))*(4*m2sq - m4sq)*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))*B0del(0,0,m3sq) - 2*m1sq*(4*m2sq - m3sq)*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*(4*m2sq - m4sq)*m4sq*B0del(0,0,m4sq) - (4*m2sq - m3sq)*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*m4sq*(m1**4 - 3*m2**4 + 3*m2sq*m4sq - m1sq*(6*m2sq + m4sq))*B0del(0,0,m4sq) + 2*m1sq*(4*m2sq - m3sq)*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*(4*m2sq - m4sq)*m4sq*B0fin(0,0,m1sq) - 2*m1sq*(4*m2sq - m3sq)*m3sq*(4*m2sq - m4sq)*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))*B0fin(0,0,m1sq) - m1sq*(4*m2sq - m3sq)*(4*m2sq - m4sq)*(m3sq - m4sq)*(m1**4 - 3*m2**4 + m1sq*(2*m2sq - m3sq - m4sq) + m3sq*m4sq + m2sq*(m3sq + m4sq))*B0fin(0,0,m1sq) - m3sq*(m1**4 - 3*m2**4 + 3*m2sq*m3sq - m1sq*(6*m2sq + m3sq))*(4*m2sq - m4sq)*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))*B0fin(0,0,m2sq) + 2*m2sq*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*(m3sq - m4sq)*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))*B0fin(0,0,m2sq) + (4*m2sq - m3sq)*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*m4sq*(m1**4 - 3*m2**4 + 3*m2sq*m4sq - m1sq*(6*m2sq + m4sq))*B0fin(0,0,m2sq) - m1sq*(4*m2sq - m3sq)*(4*m2sq - m4sq)*(m3sq - m4sq)*(m1**4 - 3*m2**4 + m1sq*(2*m2sq - m3sq - m4sq) + m3sq*m4sq + m2sq*(m3sq + m4sq))*B0fin(0,0,m2sq) + m1sq*(4*m2sq - m3sq)*(4*m2sq - m4sq)*(m3sq - m4sq)*(m1**4 - 3*m2**4 + m1sq*(2*m2sq - m3sq - m4sq) + m3sq*m4sq + m2sq*(m3sq + m4sq))*B0fin(0,0,m1sq)*B0fin(0,0,m2sq) - m2sq*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*(m3sq - m4sq)*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))*B0fin(0,0,m2sq)**2 + 2*(4*m2sq - m3sq)*(m1sq - m2sq + m3sq)*(4*m2sq - m4sq)*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))*((m1 + m2 + m3)/2. + m1*B0fin(0,0,m1) + m2*B0fin(0,0,m2) + m3*B0fin(0,0,m3)) + 2*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*(4*m2sq - m4sq)*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))*(m2 + m3/2. + 2*m2*B0fin(0,0,m2) + m3*B0fin(0,0,m3)) - 2*m1sq*(4*m2sq - m3sq)*m3sq*(4*m2sq - m4sq)*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))*B0fin(0,0,m3sq) - m3sq*(m1**4 - 3*m2**4 + 3*m2sq*m3sq - m1sq*(6*m2sq + m3sq))*(4*m2sq - m4sq)*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))*B0fin(0,0,m3sq) + 2*m1sq*(4*m2sq - m3sq)*m3sq*(4*m2sq - m4sq)*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))*B0fin(0,0,m1sq)*B0fin(0,0,m3sq) + m3sq*(m1**4 - 3*m2**4 + 3*m2sq*m3sq - m1sq*(6*m2sq + m3sq))*(4*m2sq - m4sq)*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))*B0fin(0,0,m2sq)*B0fin(0,0,m3sq) - 2*(4*m2sq - m3sq)*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*(4*m2sq - m4sq)*(m1sq - m2sq + m4sq)*((m1 + m2 + m4)/2. + m1*B0fin(0,0,m1) + m2*B0fin(0,0,m2) + m4*B0fin(0,0,m4)) - 2*(4*m2sq - m3sq)*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))*(m2 + m4/2. + 2*m2*B0fin(0,0,m2) + m4*B0fin(0,0,m4)) + 2*m1sq*(4*m2sq - m3sq)*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*(4*m2sq - m4sq)*m4sq*B0fin(0,0,m4sq) + (4*m2sq - m3sq)*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*m4sq*(m1**4 - 3*m2**4 + 3*m2sq*m4sq - m1sq*(6*m2sq + m4sq))*B0fin(0,0,m4sq) - 2*m1sq*(4*m2sq - m3sq)*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*(4*m2sq - m4sq)*m4sq*B0fin(0,0,m1sq)*B0fin(0,0,m4sq) - (4*m2sq - m3sq)*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*m4sq*(m1**4 - 3*m2**4 + 3*m2sq*m4sq - m1sq*(6*m2sq + m4sq))*B0fin(0,0,m2sq)*B0fin(0,0,m4sq) - (4*m2sq - m3sq)*(m1sq - m2sq + m3sq)*(4*m2sq - m4sq)*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))*T134fin(m3,m2,m1) - (m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*(4*m2sq - m4sq)*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))*T134fin(m3,m2,m2) + (4*m2sq - m3sq)*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*(4*m2sq - m4sq)*(m1sq - m2sq + m4sq)*T134fin(m4,m2,m1) + (4*m2sq - m3sq)*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))*T134fin(m4,m2,m2))/((m1sq - m2sq)*(4*m2sq - m3sq)*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*(4*m2sq - m4sq)*(m3sq - m4sq)*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq)))
		def eval_55():
			return (-(m1**6*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2) - 3*m1sq*m4**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2 - m1**4*m4sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2 + m1sq*(m1 + m3 - m5)**2*m5**4*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2 + 2*m1**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m1 + m4 + m5) - 2*m4**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m1 + m4 + m5) + 2*(m1 + m3 - m5)**2*m5**4*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m1 + m4 + m5) + m1**6*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2 + 3*m1sq*m3**4*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2 + m1**4*m3sq*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2 - m1sq*(m1 + m4 - m5)**2*m5**4*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2 - 2*m1**4*(m1 + m4 - m5)**2*(m1 + m3 + m5)*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2 + 2*m3**4*(m1 + m4 - m5)**2*(m1 + m3 + m5)*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2 - 2*(m1 + m4 - m5)**2*m5**4*(m1 + m3 + m5)*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2 - m3sq*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*(m3sq - m5sq)**2 + m4sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m4sq - m5sq)**2 + m1**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m5sq - 2*m1sq*m4sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m5sq - 4*m1sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m1 + m4 + m5)*m5sq - m1**4*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*m5sq + 2*m1sq*m3sq*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*m5sq + 4*m1sq*(m1 + m4 - m5)**2*(m1 + m3 + m5)*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*m5sq - 4*m3sq*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*(m3sq - m5sq)*m5sq + (m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*(m3sq - m5sq)**2*m5sq + 4*m4sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m4sq - m5sq)*m5sq - (m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m4sq - m5sq)**2*m5sq - 4*m1sq*m3sq*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*(m3sq + m5sq) + 4*m1sq*m4sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m4sq + m5sq) - 2*m1sq*m4**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0del(0,0,m1sq) + 2*m1**4*m4sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0del(0,0,m1sq) + 2*m1sq*m3**4*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*B0del(0,0,m1sq) - 2*m1**4*m3sq*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*B0del(0,0,m1sq) + 2*m1sq*m4sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m5sq*B0del(0,0,m1sq) - 2*m1sq*m3sq*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*m5sq*B0del(0,0,m1sq) - 2*m1sq*m3**4*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*B0del(0,0,m3sq) + m3**4*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*(m3sq - m5sq)*B0del(0,0,m3sq) + m3sq*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*(m3sq - m5sq)**2*B0del(0,0,m3sq) + m3sq*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*(m3sq - m5sq)*m5sq*B0del(0,0,m3sq) + 2*m1sq*m4**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0del(0,0,m4sq) - m4**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m4sq - m5sq)*B0del(0,0,m4sq) - m4sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m4sq - m5sq)**2*B0del(0,0,m4sq) - m4sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m4sq - m5sq)*m5sq*B0del(0,0,m4sq) + m3**4*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*(m3sq - m5sq)*B0del(0,0,m5sq) - m3sq*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*(m3sq - m5sq)**2*B0del(0,0,m5sq) - m4**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m4sq - m5sq)*B0del(0,0,m5sq) + m4sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m4sq - m5sq)**2*B0del(0,0,m5sq) + 2*m1sq*m4sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m5sq*B0del(0,0,m5sq) - 2*m1sq*m3sq*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*m5sq*B0del(0,0,m5sq) + m3sq*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*(m3sq - m5sq)*m5sq*B0del(0,0,m5sq) - m4sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m4sq - m5sq)*m5sq*B0del(0,0,m5sq) + m1**6*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0fin(0,0,m1sq) + 5*m1sq*m4**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0fin(0,0,m1sq) - m1**4*m4sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0fin(0,0,m1sq) - m1sq*(m1 + m3 - m5)**2*m5**4*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0fin(0,0,m1sq) - m1**6*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*B0fin(0,0,m1sq) - 5*m1sq*m3**4*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*B0fin(0,0,m1sq) + m1**4*m3sq*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*B0fin(0,0,m1sq) + m1sq*(m1 + m4 - m5)**2*m5**4*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*B0fin(0,0,m1sq) + m3sq*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*(m3sq - m5sq)**2*B0fin(0,0,m1sq) - m4sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m4sq - m5sq)**2*B0fin(0,0,m1sq) - m1**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m5sq*B0fin(0,0,m1sq) + 4*m1sq*m4sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m5sq*B0fin(0,0,m1sq) + m1**4*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*m5sq*B0fin(0,0,m1sq) - 4*m1sq*m3sq*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*m5sq*B0fin(0,0,m1sq) - (m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*(m3sq - m5sq)**2*m5sq*B0fin(0,0,m1sq) + (m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m4sq - m5sq)**2*m5sq*B0fin(0,0,m1sq) + 4*m1sq*m3sq*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*(m3sq + m5sq)*B0fin(0,0,m1sq) - 4*m1sq*m4sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m4sq + m5sq)*B0fin(0,0,m1sq) + 2*m1sq*m3**4*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*B0fin(0,0,m3sq) - 4*m1**4*m3sq*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*B0fin(0,0,m3sq) - m3**4*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*(m3sq - m5sq)*B0fin(0,0,m3sq) - m3sq*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*(m3sq - m5sq)**2*B0fin(0,0,m3sq) + 4*m1sq*m3sq*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*m5sq*B0fin(0,0,m3sq) + 3*m3sq*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*(m3sq - m5sq)*m5sq*B0fin(0,0,m3sq) + 4*m1sq*m3sq*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*(m3sq + m5sq)*B0fin(0,0,m3sq) - m1**4*m3sq*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*B0fin(0,0,m1sq)*B0fin(0,0,m3sq) + m3sq*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*(m3sq - m5sq)**2*B0fin(0,0,m1sq)*B0fin(0,0,m3sq) - 2*m1sq*m4**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0fin(0,0,m4sq) + 4*m1**4*m4sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0fin(0,0,m4sq) + m4**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m4sq - m5sq)*B0fin(0,0,m4sq) + m4sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m4sq - m5sq)**2*B0fin(0,0,m4sq) - 4*m1sq*m4sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m5sq*B0fin(0,0,m4sq) - 3*m4sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m4sq - m5sq)*m5sq*B0fin(0,0,m4sq) - 4*m1sq*m4sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m4sq + m5sq)*B0fin(0,0,m4sq) + m1**4*m4sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0fin(0,0,m1sq)*B0fin(0,0,m4sq) - m4sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m4sq - m5sq)**2*B0fin(0,0,m1sq)*B0fin(0,0,m4sq) + m1**4*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*(m1 + m3 + m5 + 2*m1*B0fin(0,0,m1) + 2*m3*B0fin(0,0,m3) + 2*m5*B0fin(0,0,m5)) + m3**4*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*(m1 + m3 + m5 + 2*m1*B0fin(0,0,m1) + 2*m3*B0fin(0,0,m3) + 2*m5*B0fin(0,0,m5)) - 2*m1sq*m3sq*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*(m1 + m3 + m5 + 2*m1*B0fin(0,0,m1) + 2*m3*B0fin(0,0,m3) + 2*m5*B0fin(0,0,m5)) + (m1 + m4 - m5)**2*m5**4*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*(m1 + m3 + m5 + 2*m1*B0fin(0,0,m1) + 2*m3*B0fin(0,0,m3) + 2*m5*B0fin(0,0,m5)) - 2*m1sq*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*m5sq*(m1 + m3 + m5 + 2*m1*B0fin(0,0,m1) + 2*m3*B0fin(0,0,m3) + 2*m5*B0fin(0,0,m5)) - 2*m3sq*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*m5sq*(m1 + m3 + m5 + 2*m1*B0fin(0,0,m1) + 2*m3*B0fin(0,0,m3) + 2*m5*B0fin(0,0,m5)) - m1**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m1 + m4 + m5 + 2*m1*B0fin(0,0,m1) + 2*m4*B0fin(0,0,m4) + 2*m5*B0fin(0,0,m5)) - m4**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m1 + m4 + m5 + 2*m1*B0fin(0,0,m1) + 2*m4*B0fin(0,0,m4) + 2*m5*B0fin(0,0,m5)) + 2*m1sq*m4sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m1 + m4 + m5 + 2*m1*B0fin(0,0,m1) + 2*m4*B0fin(0,0,m4) + 2*m5*B0fin(0,0,m5)) - (m1 + m3 - m5)**2*m5**4*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m1 + m4 + m5 + 2*m1*B0fin(0,0,m1) + 2*m4*B0fin(0,0,m4) + 2*m5*B0fin(0,0,m5)) + 2*m1sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m5sq*(m1 + m4 + m5 + 2*m1*B0fin(0,0,m1) + 2*m4*B0fin(0,0,m4) + 2*m5*B0fin(0,0,m5)) + 2*m4sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m5sq*(m1 + m4 + m5 + 2*m1*B0fin(0,0,m1) + 2*m4*B0fin(0,0,m4) + 2*m5*B0fin(0,0,m5)) + m1**6*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0fin(0,0,m5sq) + 3*m1sq*m4**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0fin(0,0,m5sq) - 3*m1**4*m4sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0fin(0,0,m5sq) - m1sq*(m1 + m3 - m5)**2*m5**4*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0fin(0,0,m5sq) - m1**6*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*B0fin(0,0,m5sq) - 3*m1sq*m3**4*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*B0fin(0,0,m5sq) + 3*m1**4*m3sq*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*B0fin(0,0,m5sq) + m1sq*(m1 + m4 - m5)**2*m5**4*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*B0fin(0,0,m5sq) - m3**4*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*(m3sq - m5sq)*B0fin(0,0,m5sq) + 2*m3sq*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*(m3sq - m5sq)**2*B0fin(0,0,m5sq) + m4**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m4sq - m5sq)*B0fin(0,0,m5sq) - 2*m4sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m4sq - m5sq)**2*B0fin(0,0,m5sq) - m1**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m5sq*B0fin(0,0,m5sq) + m1**4*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*m5sq*B0fin(0,0,m5sq) + 3*m3sq*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*(m3sq - m5sq)*m5sq*B0fin(0,0,m5sq) - (m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*(m3sq - m5sq)**2*m5sq*B0fin(0,0,m5sq) - 3*m4sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m4sq - m5sq)*m5sq*B0fin(0,0,m5sq) + (m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m4sq - m5sq)**2*m5sq*B0fin(0,0,m5sq) - 2*m1sq*m4**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0fin(0,0,m1sq)*B0fin(0,0,m5sq) + m1**4*m4sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0fin(0,0,m1sq)*B0fin(0,0,m5sq) + 2*m1sq*m3**4*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*B0fin(0,0,m1sq)*B0fin(0,0,m5sq) - m1**4*m3sq*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*B0fin(0,0,m1sq)*B0fin(0,0,m5sq) - m3sq*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*(m3sq - m5sq)**2*B0fin(0,0,m1sq)*B0fin(0,0,m5sq) + m4sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m4sq - m5sq)**2*B0fin(0,0,m1sq)*B0fin(0,0,m5sq) + 2*m1sq*m4sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m5sq*B0fin(0,0,m1sq)*B0fin(0,0,m5sq) - 2*m1sq*m3sq*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*m5sq*B0fin(0,0,m1sq)*B0fin(0,0,m5sq) - 2*m1sq*m3**4*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*B0fin(0,0,m3sq)*B0fin(0,0,m5sq) + m1**4*m3sq*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*B0fin(0,0,m3sq)*B0fin(0,0,m5sq) + m3**4*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*(m3sq - m5sq)*B0fin(0,0,m3sq)*B0fin(0,0,m5sq) + m3sq*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*(m3sq - m5sq)*m5sq*B0fin(0,0,m3sq)*B0fin(0,0,m5sq) + 2*m1sq*m4**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0fin(0,0,m4sq)*B0fin(0,0,m5sq) - m1**4*m4sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0fin(0,0,m4sq)*B0fin(0,0,m5sq) - m4**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m4sq - m5sq)*B0fin(0,0,m4sq)*B0fin(0,0,m5sq) - m4sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m4sq - m5sq)*m5sq*B0fin(0,0,m4sq)*B0fin(0,0,m5sq) - 2*m3**4*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*T134fin(m5,m3,m1) + 2*m1sq*m3sq*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*T134fin(m5,m3,m1) + 2*m3sq*(m1 + m4 - m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2*m5sq*T134fin(m5,m3,m1) + 2*m4**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*T134fin(m5,m4,m1) - 2*m1sq*m4sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*T134fin(m5,m4,m1) - 2*m4sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m5sq*T134fin(m5,m4,m1))/((m3sq - m4sq)*(m1 + m3 - m5)**2*(m1 + m4 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m1 - m4 + m5)**2*(-m1 + m4 + m5)**2*(m1 + m4 + m5)**2)
		def eval_56():
			return (-(m1**6*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2) + m1sq*m3**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2 + m1**4*m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2 - 3*m1sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m6**4 + 2*m1**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m1 + m3 + m6) + 2*m3**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m1 + m3 + m6) - 4*m1sq*m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m1 + m3 + m6) - 2*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m6**4*(m1 + m3 + m6) + m1**6*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2 - m1sq*m3**4*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2 - m1**4*m3sq*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2 + 3*m1sq*m5**4*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2 - 2*m1**4*(m1 + m3 + m5)*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2 - 2*m3**4*(m1 + m3 + m5)*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2 + 4*m1sq*m3sq*(m1 + m3 + m5)*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2 + 2*m5**4*(m1 + m3 + m5)*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2 + m3sq*(m3sq - m5sq)**2*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2 + m1**4*m5sq*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2 + 2*m1sq*m3sq*m5sq*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2 + 4*m3sq*(m3sq - m5sq)*m5sq*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2 - (m3sq - m5sq)**2*m5sq*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2 - 4*m1sq*m5sq*(m3sq + m5sq)*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2 - m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq - m6sq)**2 - m1**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m6sq - 2*m1sq*m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m6sq - 4*m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq - m6sq)*m6sq + (m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq - m6sq)**2*m6sq + 4*m1sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m6sq*(m3sq + m6sq) - 2*m1sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m6**4*B0del(0,0,m1sq) + 2*m1sq*m5**4*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0del(0,0,m1sq) - 2*m1**4*m5sq*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0del(0,0,m1sq) - 2*m1sq*m3sq*m5sq*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0del(0,0,m1sq) + 2*m1**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m6sq*B0del(0,0,m1sq) + 2*m1sq*m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m6sq*B0del(0,0,m1sq) - 2*m1sq*m3sq*m5sq*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0del(0,0,m3sq) - m3sq*(m3sq - m5sq)*m5sq*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0del(0,0,m3sq) - (m3sq - m5sq)**2*m5sq*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0del(0,0,m3sq) + m5**4*(-m3sq + m5sq)*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0del(0,0,m3sq) + (m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m6**4*(m3sq - m6sq)*B0del(0,0,m3sq) + 2*m1sq*m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m6sq*B0del(0,0,m3sq) + m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq - m6sq)*m6sq*B0del(0,0,m3sq) + (m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq - m6sq)**2*m6sq*B0del(0,0,m3sq) - 2*m1sq*m5**4*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0del(0,0,m5sq) - m3sq*(m3sq - m5sq)*m5sq*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0del(0,0,m5sq) + (m3sq - m5sq)**2*m5sq*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0del(0,0,m5sq) + m5**4*(-m3sq + m5sq)*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0del(0,0,m5sq) + 2*m1sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m6**4*B0del(0,0,m6sq) + (m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m6**4*(m3sq - m6sq)*B0del(0,0,m6sq) + m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq - m6sq)*m6sq*B0del(0,0,m6sq) - (m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq - m6sq)**2*m6sq*B0del(0,0,m6sq) + m1**6*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0fin(0,0,m1sq) - m1sq*m3**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0fin(0,0,m1sq) - m1**4*m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0fin(0,0,m1sq) + 5*m1sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m6**4*B0fin(0,0,m1sq) - m1**6*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0fin(0,0,m1sq) + m1sq*m3**4*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0fin(0,0,m1sq) + m1**4*m3sq*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0fin(0,0,m1sq) - 5*m1sq*m5**4*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0fin(0,0,m1sq) - m3sq*(m3sq - m5sq)**2*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0fin(0,0,m1sq) + m1**4*m5sq*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0fin(0,0,m1sq) - 4*m1sq*m3sq*m5sq*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0fin(0,0,m1sq) + (m3sq - m5sq)**2*m5sq*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0fin(0,0,m1sq) + 4*m1sq*m5sq*(m3sq + m5sq)*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0fin(0,0,m1sq) + m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq - m6sq)**2*B0fin(0,0,m1sq) - m1**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m6sq*B0fin(0,0,m1sq) + 4*m1sq*m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m6sq*B0fin(0,0,m1sq) - (m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq - m6sq)**2*m6sq*B0fin(0,0,m1sq) - 4*m1sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m6sq*(m3sq + m6sq)*B0fin(0,0,m1sq) + m1**6*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0fin(0,0,m3sq) - m1sq*m3**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0fin(0,0,m3sq) - m1**4*m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*B0fin(0,0,m3sq) + 3*m1sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m6**4*B0fin(0,0,m3sq) - m1**6*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0fin(0,0,m3sq) + m1sq*m3**4*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0fin(0,0,m3sq) + m1**4*m3sq*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0fin(0,0,m3sq) - 3*m1sq*m5**4*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0fin(0,0,m3sq) + m5**4*(m3sq - m5sq)*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0fin(0,0,m3sq) - m3sq*(m3sq - m5sq)**2*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0fin(0,0,m3sq) + 3*m1**4*m5sq*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0fin(0,0,m3sq) - 3*m3sq*(m3sq - m5sq)*m5sq*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0fin(0,0,m3sq) + 2*(m3sq - m5sq)**2*m5sq*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0fin(0,0,m3sq) - (m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m6**4*(m3sq - m6sq)*B0fin(0,0,m3sq) + m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq - m6sq)**2*B0fin(0,0,m3sq) - 3*m1**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m6sq*B0fin(0,0,m3sq) + 3*m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq - m6sq)*m6sq*B0fin(0,0,m3sq) - 2*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq - m6sq)**2*m6sq*B0fin(0,0,m3sq) - 2*m1sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m6**4*B0fin(0,0,m1sq)*B0fin(0,0,m3sq) + 2*m1sq*m5**4*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0fin(0,0,m1sq)*B0fin(0,0,m3sq) - m1**4*m5sq*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0fin(0,0,m1sq)*B0fin(0,0,m3sq) - 2*m1sq*m3sq*m5sq*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0fin(0,0,m1sq)*B0fin(0,0,m3sq) - (m3sq - m5sq)**2*m5sq*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0fin(0,0,m1sq)*B0fin(0,0,m3sq) + m1**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m6sq*B0fin(0,0,m1sq)*B0fin(0,0,m3sq) + 2*m1sq*m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m6sq*B0fin(0,0,m1sq)*B0fin(0,0,m3sq) + (m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq - m6sq)**2*m6sq*B0fin(0,0,m1sq)*B0fin(0,0,m3sq) + m1**4*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*(m1 + m3 + m5 + 2*m1*B0fin(0,0,m1) + 2*m3*B0fin(0,0,m3) + 2*m5*B0fin(0,0,m5)) + m3**4*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*(m1 + m3 + m5 + 2*m1*B0fin(0,0,m1) + 2*m3*B0fin(0,0,m3) + 2*m5*B0fin(0,0,m5)) - 2*m1sq*m3sq*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*(m1 + m3 + m5 + 2*m1*B0fin(0,0,m1) + 2*m3*B0fin(0,0,m3) + 2*m5*B0fin(0,0,m5)) + m5**4*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*(m1 + m3 + m5 + 2*m1*B0fin(0,0,m1) + 2*m3*B0fin(0,0,m3) + 2*m5*B0fin(0,0,m5)) - 2*m1sq*m5sq*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*(m1 + m3 + m5 + 2*m1*B0fin(0,0,m1) + 2*m3*B0fin(0,0,m3) + 2*m5*B0fin(0,0,m5)) - 2*m3sq*m5sq*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*(m1 + m3 + m5 + 2*m1*B0fin(0,0,m1) + 2*m3*B0fin(0,0,m3) + 2*m5*B0fin(0,0,m5)) + 2*m1sq*m5**4*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0fin(0,0,m5sq) + m5**4*(m3sq - m5sq)*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0fin(0,0,m5sq) - 4*m1**4*m5sq*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0fin(0,0,m5sq) + 4*m1sq*m3sq*m5sq*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0fin(0,0,m5sq) - 3*m3sq*(m3sq - m5sq)*m5sq*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0fin(0,0,m5sq) - (m3sq - m5sq)**2*m5sq*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0fin(0,0,m5sq) + 4*m1sq*m5sq*(m3sq + m5sq)*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0fin(0,0,m5sq) - m1**4*m5sq*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0fin(0,0,m1sq)*B0fin(0,0,m5sq) + (m3sq - m5sq)**2*m5sq*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0fin(0,0,m1sq)*B0fin(0,0,m5sq) - 2*m1sq*m5**4*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0fin(0,0,m3sq)*B0fin(0,0,m5sq) + m1**4*m5sq*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0fin(0,0,m3sq)*B0fin(0,0,m5sq) - m3sq*(m3sq - m5sq)*m5sq*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0fin(0,0,m3sq)*B0fin(0,0,m5sq) + m5**4*(-m3sq + m5sq)*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*B0fin(0,0,m3sq)*B0fin(0,0,m5sq) - m1**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m1 + m3 + m6 + 2*m1*B0fin(0,0,m1) + 2*m3*B0fin(0,0,m3) + 2*m6*B0fin(0,0,m6)) - m3**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m1 + m3 + m6 + 2*m1*B0fin(0,0,m1) + 2*m3*B0fin(0,0,m3) + 2*m6*B0fin(0,0,m6)) + 2*m1sq*m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m1 + m3 + m6 + 2*m1*B0fin(0,0,m1) + 2*m3*B0fin(0,0,m3) + 2*m6*B0fin(0,0,m6)) - (m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m6**4*(m1 + m3 + m6 + 2*m1*B0fin(0,0,m1) + 2*m3*B0fin(0,0,m3) + 2*m6*B0fin(0,0,m6)) + 2*m1sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m6sq*(m1 + m3 + m6 + 2*m1*B0fin(0,0,m1) + 2*m3*B0fin(0,0,m3) + 2*m6*B0fin(0,0,m6)) + 2*m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m6sq*(m1 + m3 + m6 + 2*m1*B0fin(0,0,m1) + 2*m3*B0fin(0,0,m3) + 2*m6*B0fin(0,0,m6)) - 2*m1sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m6**4*B0fin(0,0,m6sq) - (m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m6**4*(m3sq - m6sq)*B0fin(0,0,m6sq) + 4*m1**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m6sq*B0fin(0,0,m6sq) - 4*m1sq*m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m6sq*B0fin(0,0,m6sq) + 3*m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq - m6sq)*m6sq*B0fin(0,0,m6sq) + (m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq - m6sq)**2*m6sq*B0fin(0,0,m6sq) - 4*m1sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m6sq*(m3sq + m6sq)*B0fin(0,0,m6sq) + m1**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m6sq*B0fin(0,0,m1sq)*B0fin(0,0,m6sq) - (m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq - m6sq)**2*m6sq*B0fin(0,0,m1sq)*B0fin(0,0,m6sq) + 2*m1sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m6**4*B0fin(0,0,m3sq)*B0fin(0,0,m6sq) + (m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m6**4*(m3sq - m6sq)*B0fin(0,0,m3sq)*B0fin(0,0,m6sq) - m1**4*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m6sq*B0fin(0,0,m3sq)*B0fin(0,0,m6sq) + m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m3sq - m6sq)*m6sq*B0fin(0,0,m3sq)*B0fin(0,0,m6sq) - 2*m5**4*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*T134fin(m5,m3,m1) + 2*m1sq*m5sq*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*T134fin(m5,m3,m1) + 2*m3sq*m5sq*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*T134fin(m5,m3,m1) + 2*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m6**4*T134fin(m6,m3,m1) - 2*m1sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m6sq*T134fin(m6,m3,m1) - 2*m3sq*(m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*m6sq*T134fin(m6,m3,m1))/((m1 + m3 - m5)**2*(m1 - m3 + m5)**2*(-m1 + m3 + m5)**2*(m1 + m3 + m5)**2*(m1 + m3 - m6)**2*(m1 - m3 + m6)**2*(-m1 + m3 + m6)**2*(m1 + m3 + m6)**2*(m5sq - m6sq))
		def eval_57():
			return ((2*m1sq*B0del(0,0,m1sq))/((4*m1sq - m5sq)*(4*m1sq - m6sq)) + (m5sq*(3*m1**4 - m4**4 + m1sq*(6*m4sq - 3*m5sq) + m4sq*m5sq)*B0del(0,0,m1sq))/((4*m1sq - m5sq)*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))*(m5sq - m6sq)) + (m6sq*(3*m1**4 - m4**4 + m1sq*(6*m4sq - 3*m6sq) + m4sq*m6sq)*B0del(0,0,m1sq))/((4*m1sq - m6sq)*(-m5sq + m6sq)*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) - (m4sq*(-3*m1**4 + (m4sq - m5sq)*(m4sq - m6sq) + m1sq*(2*m4sq + m5sq + m6sq))*B0del(0,0,m1sq))/((m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) - (2*m4sq*m5sq*B0del(0,0,m4sq))/((m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))*(m5sq - m6sq)) + (2*m4sq*m6sq*B0del(0,0,m4sq))/((m5sq - m6sq)*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) - (m4sq*(-3*m1**4 + (m4sq - m5sq)*(m4sq - m6sq) + m1sq*(2*m4sq + m5sq + m6sq))*B0del(0,0,m4sq))/((m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) - (2*m4sq*m5sq*B0del(0,0,m5sq))/((m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))*(m5sq - m6sq)) + (m5sq*(3*m1**4 - m4**4 + m1sq*(6*m4sq - 3*m5sq) + m4sq*m5sq)*B0del(0,0,m5sq))/((4*m1sq - m5sq)*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))*(m5sq - m6sq)) + (2*m4sq*m6sq*B0del(0,0,m6sq))/((m5sq - m6sq)*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) + (m6sq*(3*m1**4 - m4**4 + m1sq*(6*m4sq - 3*m6sq) + m4sq*m6sq)*B0del(0,0,m6sq))/((4*m1sq - m6sq)*(-m5sq + m6sq)*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) - (2*m1sq*B0fin(0,0,m1sq))/((4*m1sq - m5sq)*(4*m1sq - m6sq)) + (m5sq*(-3*m1**4 + m4**4 - m4sq*m5sq + m1sq*(-6*m4sq + 3*m5sq))*B0fin(0,0,m1sq))/((4*m1sq - m5sq)*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))*(m5sq - m6sq)) + (m4sq*(-3*m1**4 + (m4sq - m5sq)*(m4sq - m6sq) + m1sq*(2*m4sq + m5sq + m6sq))*B0fin(0,0,m1sq))/((m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) + (m6sq*(-3*m1**4 + m4**4 - m4sq*m6sq + m1sq*(-6*m4sq + 3*m6sq))*B0fin(0,0,m1sq))/((4*m1sq - m6sq)*(-m5sq + m6sq)*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) + (m1sq*B0fin(0,0,m1sq)**2)/((4*m1sq - m5sq)*(4*m1sq - m6sq)) + (2*m4sq*m5sq*B0fin(0,0,m4sq))/((m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))*(m5sq - m6sq)) - (2*m4sq*m6sq*B0fin(0,0,m4sq))/((m5sq - m6sq)*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) + (m4sq*(-3*m1**4 + (m4sq - m5sq)*(m4sq - m6sq) + m1sq*(2*m4sq + m5sq + m6sq))*B0fin(0,0,m4sq))/((m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) - (m4sq*(-3*m1**4 + (m4sq - m5sq)*(m4sq - m6sq) + m1sq*(2*m4sq + m5sq + m6sq))*B0fin(0,0,m1sq)*B0fin(0,0,m4sq))/((m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) - (2*m1 + m5 + 4*m1*B0fin(0,0,m1) + 2*m5*B0fin(0,0,m5))/((4*m1sq - m5sq)*(m5sq - m6sq)) + ((m1sq - m4sq - m5sq)*(m1 + m4 + m5 + 2*m1*B0fin(0,0,m1) + 2*m4*B0fin(0,0,m4) + 2*m5*B0fin(0,0,m5)))/((m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))*(m5sq - m6sq)) + (2*m4sq*m5sq*B0fin(0,0,m5sq))/((m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))*(m5sq - m6sq)) + (m5sq*(-3*m1**4 + m4**4 - m4sq*m5sq + m1sq*(-6*m4sq + 3*m5sq))*B0fin(0,0,m5sq))/((4*m1sq - m5sq)*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))*(m5sq - m6sq)) + (m5sq*(3*m1**4 - m4**4 + m1sq*(6*m4sq - 3*m5sq) + m4sq*m5sq)*B0fin(0,0,m1sq)*B0fin(0,0,m5sq))/((4*m1sq - m5sq)*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))*(m5sq - m6sq)) - (2*m4sq*m5sq*B0fin(0,0,m4sq)*B0fin(0,0,m5sq))/((m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))*(m5sq - m6sq)) - (2*m1 + m6 + 4*m1*B0fin(0,0,m1) + 2*m6*B0fin(0,0,m6))/((4*m1sq - m6sq)*(-m5sq + m6sq)) - ((m1sq - m4sq - m6sq)*(m1 + m4 + m6 + 2*m1*B0fin(0,0,m1) + 2*m4*B0fin(0,0,m4) + 2*m6*B0fin(0,0,m6)))/((m5sq - m6sq)*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) - (2*m4sq*m6sq*B0fin(0,0,m6sq))/((m5sq - m6sq)*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) + (m6sq*(-3*m1**4 + m4**4 - m4sq*m6sq + m1sq*(-6*m4sq + 3*m6sq))*B0fin(0,0,m6sq))/((4*m1sq - m6sq)*(-m5sq + m6sq)*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) + (m6sq*(3*m1**4 - m4**4 + m1sq*(6*m4sq - 3*m6sq) + m4sq*m6sq)*B0fin(0,0,m1sq)*B0fin(0,0,m6sq))/((4*m1sq - m6sq)*(-m5sq + m6sq)*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) + (2*m4sq*m6sq*B0fin(0,0,m4sq)*B0fin(0,0,m6sq))/((m5sq - m6sq)*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) + T134fin(m5,m1,m1)/((4*m1sq - m5sq)*(m5sq - m6sq)) + ((m1sq - m4sq - m5sq)*T134fin(m5,m4,m1))/((4*m4sq*m5sq - (-m1sq + m4sq + m5sq)**2)*(m5sq - m6sq)) + T134fin(m6,m1,m1)/((4*m1sq - m6sq)*(-m5sq + m6sq)) + ((m1sq - m4sq - m6sq)*T134fin(m6,m4,m1))/((m5sq - m6sq)*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))))/(m1sq - m4sq)
		def eval_58():
			return -(((-2*m1sq*B0del(0,0,m1sq))/((4*m1sq - m3sq)*(4*m1sq - m4sq)) + (m3sq*(-3*m1**4 + m6**4 + 3*m1sq*(m3sq - 2*m6sq) - m3sq*m6sq)*B0del(0,0,m1sq))/((4*m1sq - m3sq)*(m3sq - m4sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) + (m4sq*(-3*m1**4 + m6**4 + 3*m1sq*(m4sq - 2*m6sq) - m4sq*m6sq)*B0del(0,0,m1sq))/((4*m1sq - m4sq)*(-m3sq + m4sq)*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) + (m6sq*(-3*m1**4 + (m3sq - m6sq)*(m4sq - m6sq) + m1sq*(m3sq + m4sq + 2*m6sq))*B0del(0,0,m1sq))/((m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) + (2*m3sq*m6sq*B0del(0,0,m3sq))/((m3sq - m4sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) + (m3sq*(-3*m1**4 + m6**4 + 3*m1sq*(m3sq - 2*m6sq) - m3sq*m6sq)*B0del(0,0,m3sq))/((4*m1sq - m3sq)*(m3sq - m4sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) - (2*m4sq*m6sq*B0del(0,0,m4sq))/((m3sq - m4sq)*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) + (m4sq*(-3*m1**4 + m6**4 + 3*m1sq*(m4sq - 2*m6sq) - m4sq*m6sq)*B0del(0,0,m4sq))/((4*m1sq - m4sq)*(-m3sq + m4sq)*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) + (2*m3sq*m6sq*B0del(0,0,m6sq))/((m3sq - m4sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) - (2*m4sq*m6sq*B0del(0,0,m6sq))/((m3sq - m4sq)*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) + (m6sq*(-3*m1**4 + (m3sq - m6sq)*(m4sq - m6sq) + m1sq*(m3sq + m4sq + 2*m6sq))*B0del(0,0,m6sq))/((m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) + (2*m1sq*B0fin(0,0,m1sq))/((4*m1sq - m3sq)*(4*m1sq - m4sq)) - (m3sq*(-3*m1**4 + m6**4 + 3*m1sq*(m3sq - 2*m6sq) - m3sq*m6sq)*B0fin(0,0,m1sq))/((4*m1sq - m3sq)*(m3sq - m4sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) - (m4sq*(-3*m1**4 + m6**4 + 3*m1sq*(m4sq - 2*m6sq) - m4sq*m6sq)*B0fin(0,0,m1sq))/((4*m1sq - m4sq)*(-m3sq + m4sq)*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) - (m6sq*(-3*m1**4 + (m3sq - m6sq)*(m4sq - m6sq) + m1sq*(m3sq + m4sq + 2*m6sq))*B0fin(0,0,m1sq))/((m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) - (m1sq*B0fin(0,0,m1sq)**2)/((4*m1sq - m3sq)*(4*m1sq - m4sq)) + (2*m1 + m3 + 4*m1*B0fin(0,0,m1) + 2*m3*B0fin(0,0,m3))/((4*m1sq - m3sq)*(m3sq - m4sq)) - (2*m3sq*m6sq*B0fin(0,0,m3sq))/((m3sq - m4sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) - (m3sq*(-3*m1**4 + m6**4 + 3*m1sq*(m3sq - 2*m6sq) - m3sq*m6sq)*B0fin(0,0,m3sq))/((4*m1sq - m3sq)*(m3sq - m4sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) + (m3sq*(-3*m1**4 + m6**4 + 3*m1sq*(m3sq - 2*m6sq) - m3sq*m6sq)*B0fin(0,0,m1sq)*B0fin(0,0,m3sq))/((4*m1sq - m3sq)*(m3sq - m4sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) + (2*m1 + m4 + 4*m1*B0fin(0,0,m1) + 2*m4*B0fin(0,0,m4))/((4*m1sq - m4sq)*(-m3sq + m4sq)) + (2*m4sq*m6sq*B0fin(0,0,m4sq))/((m3sq - m4sq)*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) - (m4sq*(-3*m1**4 + m6**4 + 3*m1sq*(m4sq - 2*m6sq) - m4sq*m6sq)*B0fin(0,0,m4sq))/((4*m1sq - m4sq)*(-m3sq + m4sq)*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) + (m4sq*(-3*m1**4 + m6**4 + 3*m1sq*(m4sq - 2*m6sq) - m4sq*m6sq)*B0fin(0,0,m1sq)*B0fin(0,0,m4sq))/((4*m1sq - m4sq)*(-m3sq + m4sq)*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) + ((-m1sq + m3sq + m6sq)*(m1 + m3 + m6 + 2*m1*B0fin(0,0,m1) + 2*m3*B0fin(0,0,m3) + 2*m6*B0fin(0,0,m6)))/((m3sq - m4sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) - ((-m1sq + m4sq + m6sq)*(m1 + m4 + m6 + 2*m1*B0fin(0,0,m1) + 2*m4*B0fin(0,0,m4) + 2*m6*B0fin(0,0,m6)))/((m3sq - m4sq)*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) - (2*m3sq*m6sq*B0fin(0,0,m6sq))/((m3sq - m4sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) + (2*m4sq*m6sq*B0fin(0,0,m6sq))/((m3sq - m4sq)*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) - (m6sq*(-3*m1**4 + (m3sq - m6sq)*(m4sq - m6sq) + m1sq*(m3sq + m4sq + 2*m6sq))*B0fin(0,0,m6sq))/((m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) + (m6sq*(-3*m1**4 + (m3sq - m6sq)*(m4sq - m6sq) + m1sq*(m3sq + m4sq + 2*m6sq))*B0fin(0,0,m1sq)*B0fin(0,0,m6sq))/((m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) + (2*m3sq*m6sq*B0fin(0,0,m3sq)*B0fin(0,0,m6sq))/((m3sq - m4sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) - (2*m4sq*m6sq*B0fin(0,0,m4sq)*B0fin(0,0,m6sq))/((m3sq - m4sq)*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) - T134fin(m3,m1,m1)/((4*m1sq - m3sq)*(m3sq - m4sq)) - T134fin(m4,m1,m1)/((4*m1sq - m4sq)*(-m3sq + m4sq)) - ((-m1sq + m3sq + m6sq)*T134fin(m6,m3,m1))/((m3sq - m4sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) + ((-m1sq + m4sq + m6sq)*T134fin(m6,m4,m1))/((m3sq - m4sq)*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))))/(m1sq - m6sq))
		def eval_59():
			return ((2*m1sq*B0del(0,0,m1sq))/((4*m1sq - m5sq)*(4*m1sq - m6sq)) + (m5sq*(3*m1**4 - m2**4 + m1sq*(6*m2sq - 3*m5sq) + m2sq*m5sq)*B0del(0,0,m1sq))/((4*m1sq - m5sq)*(m1**4 + (m2sq - m5sq)**2 - 2*m1sq*(m2sq + m5sq))*(m5sq - m6sq)) + (m6sq*(3*m1**4 - m2**4 + m1sq*(6*m2sq - 3*m6sq) + m2sq*m6sq)*B0del(0,0,m1sq))/((4*m1sq - m6sq)*(-m5sq + m6sq)*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))) - (m2sq*(-3*m1**4 + (m2sq - m5sq)*(m2sq - m6sq) + m1sq*(2*m2sq + m5sq + m6sq))*B0del(0,0,m1sq))/((m1**4 + (m2sq - m5sq)**2 - 2*m1sq*(m2sq + m5sq))*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))) - (2*m2sq*m5sq*B0del(0,0,m2sq))/((m1**4 + (m2sq - m5sq)**2 - 2*m1sq*(m2sq + m5sq))*(m5sq - m6sq)) + (2*m2sq*m6sq*B0del(0,0,m2sq))/((m5sq - m6sq)*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))) - (m2sq*(-3*m1**4 + (m2sq - m5sq)*(m2sq - m6sq) + m1sq*(2*m2sq + m5sq + m6sq))*B0del(0,0,m2sq))/((m1**4 + (m2sq - m5sq)**2 - 2*m1sq*(m2sq + m5sq))*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))) - (2*m2sq*m5sq*B0del(0,0,m5sq))/((m1**4 + (m2sq - m5sq)**2 - 2*m1sq*(m2sq + m5sq))*(m5sq - m6sq)) + (m5sq*(3*m1**4 - m2**4 + m1sq*(6*m2sq - 3*m5sq) + m2sq*m5sq)*B0del(0,0,m5sq))/((4*m1sq - m5sq)*(m1**4 + (m2sq - m5sq)**2 - 2*m1sq*(m2sq + m5sq))*(m5sq - m6sq)) + (2*m2sq*m6sq*B0del(0,0,m6sq))/((m5sq - m6sq)*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))) + (m6sq*(3*m1**4 - m2**4 + m1sq*(6*m2sq - 3*m6sq) + m2sq*m6sq)*B0del(0,0,m6sq))/((4*m1sq - m6sq)*(-m5sq + m6sq)*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))) - (2*m1sq*B0fin(0,0,m1sq))/((4*m1sq - m5sq)*(4*m1sq - m6sq)) + (m5sq*(-3*m1**4 + m2**4 - m2sq*m5sq + m1sq*(-6*m2sq + 3*m5sq))*B0fin(0,0,m1sq))/((4*m1sq - m5sq)*(m1**4 + (m2sq - m5sq)**2 - 2*m1sq*(m2sq + m5sq))*(m5sq - m6sq)) + (m2sq*(-3*m1**4 + (m2sq - m5sq)*(m2sq - m6sq) + m1sq*(2*m2sq + m5sq + m6sq))*B0fin(0,0,m1sq))/((m1**4 + (m2sq - m5sq)**2 - 2*m1sq*(m2sq + m5sq))*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))) + (m6sq*(-3*m1**4 + m2**4 - m2sq*m6sq + m1sq*(-6*m2sq + 3*m6sq))*B0fin(0,0,m1sq))/((4*m1sq - m6sq)*(-m5sq + m6sq)*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))) + (m1sq*B0fin(0,0,m1sq)**2)/((4*m1sq - m5sq)*(4*m1sq - m6sq)) + (2*m2sq*m5sq*B0fin(0,0,m2sq))/((m1**4 + (m2sq - m5sq)**2 - 2*m1sq*(m2sq + m5sq))*(m5sq - m6sq)) - (2*m2sq*m6sq*B0fin(0,0,m2sq))/((m5sq - m6sq)*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))) + (m2sq*(-3*m1**4 + (m2sq - m5sq)*(m2sq - m6sq) + m1sq*(2*m2sq + m5sq + m6sq))*B0fin(0,0,m2sq))/((m1**4 + (m2sq - m5sq)**2 - 2*m1sq*(m2sq + m5sq))*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))) - (m2sq*(-3*m1**4 + (m2sq - m5sq)*(m2sq - m6sq) + m1sq*(2*m2sq + m5sq + m6sq))*B0fin(0,0,m1sq)*B0fin(0,0,m2sq))/((m1**4 + (m2sq - m5sq)**2 - 2*m1sq*(m2sq + m5sq))*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))) - (2*m1 + m5 + 4*m1*B0fin(0,0,m1) + 2*m5*B0fin(0,0,m5))/((4*m1sq - m5sq)*(m5sq - m6sq)) + ((m1sq - m2sq - m5sq)*(m1 + m2 + m5 + 2*m1*B0fin(0,0,m1) + 2*m2*B0fin(0,0,m2) + 2*m5*B0fin(0,0,m5)))/((m1**4 + (m2sq - m5sq)**2 - 2*m1sq*(m2sq + m5sq))*(m5sq - m6sq)) + (2*m2sq*m5sq*B0fin(0,0,m5sq))/((m1**4 + (m2sq - m5sq)**2 - 2*m1sq*(m2sq + m5sq))*(m5sq - m6sq)) + (m5sq*(-3*m1**4 + m2**4 - m2sq*m5sq + m1sq*(-6*m2sq + 3*m5sq))*B0fin(0,0,m5sq))/((4*m1sq - m5sq)*(m1**4 + (m2sq - m5sq)**2 - 2*m1sq*(m2sq + m5sq))*(m5sq - m6sq)) + (m5sq*(3*m1**4 - m2**4 + m1sq*(6*m2sq - 3*m5sq) + m2sq*m5sq)*B0fin(0,0,m1sq)*B0fin(0,0,m5sq))/((4*m1sq - m5sq)*(m1**4 + (m2sq - m5sq)**2 - 2*m1sq*(m2sq + m5sq))*(m5sq - m6sq)) - (2*m2sq*m5sq*B0fin(0,0,m2sq)*B0fin(0,0,m5sq))/((m1**4 + (m2sq - m5sq)**2 - 2*m1sq*(m2sq + m5sq))*(m5sq - m6sq)) - (2*m1 + m6 + 4*m1*B0fin(0,0,m1) + 2*m6*B0fin(0,0,m6))/((4*m1sq - m6sq)*(-m5sq + m6sq)) - ((m1sq - m2sq - m6sq)*(m1 + m2 + m6 + 2*m1*B0fin(0,0,m1) + 2*m2*B0fin(0,0,m2) + 2*m6*B0fin(0,0,m6)))/((m5sq - m6sq)*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))) - (2*m2sq*m6sq*B0fin(0,0,m6sq))/((m5sq - m6sq)*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))) + (m6sq*(-3*m1**4 + m2**4 - m2sq*m6sq + m1sq*(-6*m2sq + 3*m6sq))*B0fin(0,0,m6sq))/((4*m1sq - m6sq)*(-m5sq + m6sq)*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))) + (m6sq*(3*m1**4 - m2**4 + m1sq*(6*m2sq - 3*m6sq) + m2sq*m6sq)*B0fin(0,0,m1sq)*B0fin(0,0,m6sq))/((4*m1sq - m6sq)*(-m5sq + m6sq)*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))) + (2*m2sq*m6sq*B0fin(0,0,m2sq)*B0fin(0,0,m6sq))/((m5sq - m6sq)*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))) + T134fin(m5,m1,m1)/((4*m1sq - m5sq)*(m5sq - m6sq)) + ((m1sq - m2sq - m5sq)*T134fin(m5,m2,m1))/((4*m2sq*m5sq - (-m1sq + m2sq + m5sq)**2)*(m5sq - m6sq)) + T134fin(m6,m1,m1)/((4*m1sq - m6sq)*(-m5sq + m6sq)) + ((m1sq - m2sq - m6sq)*T134fin(m6,m2,m1))/((m5sq - m6sq)*(m1**4 + (m2sq - m6sq)**2 - 2*m1sq*(m2sq + m6sq))))/(m1sq - m2sq)
		def eval_60():
			return ((2*m1sq*B0del(0,0,m1sq))/((4*m1sq - m3sq)*(4*m1sq - m4sq)) + (m3sq*(3*m1**4 - m2**4 + m1sq*(6*m2sq - 3*m3sq) + m2sq*m3sq)*B0del(0,0,m1sq))/((4*m1sq - m3sq)*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*(m3sq - m4sq)) + (m4sq*(3*m1**4 - m2**4 + m1sq*(6*m2sq - 3*m4sq) + m2sq*m4sq)*B0del(0,0,m1sq))/((4*m1sq - m4sq)*(-m3sq + m4sq)*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))) - (m2sq*(-3*m1**4 + (m2sq - m3sq)*(m2sq - m4sq) + m1sq*(2*m2sq + m3sq + m4sq))*B0del(0,0,m1sq))/((m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))) - (2*m2sq*m3sq*B0del(0,0,m2sq))/((m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*(m3sq - m4sq)) + (2*m2sq*m4sq*B0del(0,0,m2sq))/((m3sq - m4sq)*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))) - (m2sq*(-3*m1**4 + (m2sq - m3sq)*(m2sq - m4sq) + m1sq*(2*m2sq + m3sq + m4sq))*B0del(0,0,m2sq))/((m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))) - (2*m2sq*m3sq*B0del(0,0,m3sq))/((m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*(m3sq - m4sq)) + (m3sq*(3*m1**4 - m2**4 + m1sq*(6*m2sq - 3*m3sq) + m2sq*m3sq)*B0del(0,0,m3sq))/((4*m1sq - m3sq)*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*(m3sq - m4sq)) + (2*m2sq*m4sq*B0del(0,0,m4sq))/((m3sq - m4sq)*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))) + (m4sq*(3*m1**4 - m2**4 + m1sq*(6*m2sq - 3*m4sq) + m2sq*m4sq)*B0del(0,0,m4sq))/((4*m1sq - m4sq)*(-m3sq + m4sq)*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))) - (2*m1sq*B0fin(0,0,m1sq))/((4*m1sq - m3sq)*(4*m1sq - m4sq)) + (m3sq*(-3*m1**4 + m2**4 - m2sq*m3sq + m1sq*(-6*m2sq + 3*m3sq))*B0fin(0,0,m1sq))/((4*m1sq - m3sq)*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*(m3sq - m4sq)) + (m2sq*(-3*m1**4 + (m2sq - m3sq)*(m2sq - m4sq) + m1sq*(2*m2sq + m3sq + m4sq))*B0fin(0,0,m1sq))/((m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))) + (m4sq*(-3*m1**4 + m2**4 - m2sq*m4sq + m1sq*(-6*m2sq + 3*m4sq))*B0fin(0,0,m1sq))/((4*m1sq - m4sq)*(-m3sq + m4sq)*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))) + (m1sq*B0fin(0,0,m1sq)**2)/((4*m1sq - m3sq)*(4*m1sq - m4sq)) + (2*m2sq*m3sq*B0fin(0,0,m2sq))/((m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*(m3sq - m4sq)) - (2*m2sq*m4sq*B0fin(0,0,m2sq))/((m3sq - m4sq)*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))) + (m2sq*(-3*m1**4 + (m2sq - m3sq)*(m2sq - m4sq) + m1sq*(2*m2sq + m3sq + m4sq))*B0fin(0,0,m2sq))/((m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))) - (m2sq*(-3*m1**4 + (m2sq - m3sq)*(m2sq - m4sq) + m1sq*(2*m2sq + m3sq + m4sq))*B0fin(0,0,m1sq)*B0fin(0,0,m2sq))/((m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))) - (2*m1 + m3 + 4*m1*B0fin(0,0,m1) + 2*m3*B0fin(0,0,m3))/((4*m1sq - m3sq)*(m3sq - m4sq)) + ((m1sq - m2sq - m3sq)*(m1 + m2 + m3 + 2*m1*B0fin(0,0,m1) + 2*m2*B0fin(0,0,m2) + 2*m3*B0fin(0,0,m3)))/((m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*(m3sq - m4sq)) + (2*m2sq*m3sq*B0fin(0,0,m3sq))/((m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*(m3sq - m4sq)) + (m3sq*(-3*m1**4 + m2**4 - m2sq*m3sq + m1sq*(-6*m2sq + 3*m3sq))*B0fin(0,0,m3sq))/((4*m1sq - m3sq)*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*(m3sq - m4sq)) + (m3sq*(3*m1**4 - m2**4 + m1sq*(6*m2sq - 3*m3sq) + m2sq*m3sq)*B0fin(0,0,m1sq)*B0fin(0,0,m3sq))/((4*m1sq - m3sq)*(m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*(m3sq - m4sq)) - (2*m2sq*m3sq*B0fin(0,0,m2sq)*B0fin(0,0,m3sq))/((m1**4 + (m2sq - m3sq)**2 - 2*m1sq*(m2sq + m3sq))*(m3sq - m4sq)) - (2*m1 + m4 + 4*m1*B0fin(0,0,m1) + 2*m4*B0fin(0,0,m4))/((4*m1sq - m4sq)*(-m3sq + m4sq)) - ((m1sq - m2sq - m4sq)*(m1 + m2 + m4 + 2*m1*B0fin(0,0,m1) + 2*m2*B0fin(0,0,m2) + 2*m4*B0fin(0,0,m4)))/((m3sq - m4sq)*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))) - (2*m2sq*m4sq*B0fin(0,0,m4sq))/((m3sq - m4sq)*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))) + (m4sq*(-3*m1**4 + m2**4 - m2sq*m4sq + m1sq*(-6*m2sq + 3*m4sq))*B0fin(0,0,m4sq))/((4*m1sq - m4sq)*(-m3sq + m4sq)*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))) + (m4sq*(3*m1**4 - m2**4 + m1sq*(6*m2sq - 3*m4sq) + m2sq*m4sq)*B0fin(0,0,m1sq)*B0fin(0,0,m4sq))/((4*m1sq - m4sq)*(-m3sq + m4sq)*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))) + (2*m2sq*m4sq*B0fin(0,0,m2sq)*B0fin(0,0,m4sq))/((m3sq - m4sq)*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))) + T134fin(m3,m1,m1)/((4*m1sq - m3sq)*(m3sq - m4sq)) + ((m1sq - m2sq - m3sq)*T134fin(m3,m2,m1))/((4*m2sq*m3sq - (-m1sq + m2sq + m3sq)**2)*(m3sq - m4sq)) + T134fin(m4,m1,m1)/((4*m1sq - m4sq)*(-m3sq + m4sq)) + ((m1sq - m2sq - m4sq)*T134fin(m4,m2,m1))/((m3sq - m4sq)*(m1**4 + (m2sq - m4sq)**2 - 2*m1sq*(m2sq + m4sq))))/(m1sq - m2sq)
		def eval_61():
			return (2*m1sq*m3sq*B0del(0,0,m1sq))/((m1sq - m2sq)*(m3sq - m4sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))) - (2*m1sq*m4sq*B0del(0,0,m1sq))/((m1sq - m2sq)*(m3sq - m4sq)*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))) + (m1sq*(m1**4 - m1sq*(m3sq + m4sq - 2*m5sq) + (m4sq - 3*m5sq)*m5sq + m3sq*(m4sq + m5sq))*B0del(0,0,m1sq))/((m1sq - m2sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))) - (2*m2sq*m3sq*B0del(0,0,m2sq))/((m1sq - m2sq)*(m3sq - m4sq)*(m2**4 + (m3sq - m5sq)**2 - 2*m2sq*(m3sq + m5sq))) + (2*m2sq*m4sq*B0del(0,0,m2sq))/((m1sq - m2sq)*(m3sq - m4sq)*(m2**4 + (m4sq - m5sq)**2 - 2*m2sq*(m4sq + m5sq))) - (m2sq*(m2**4 - m2sq*(m3sq + m4sq - 2*m5sq) + (m4sq - 3*m5sq)*m5sq + m3sq*(m4sq + m5sq))*B0del(0,0,m2sq))/((m1sq - m2sq)*(m2**4 + (m3sq - m5sq)**2 - 2*m2sq*(m3sq + m5sq))*(m2**4 + (m4sq - m5sq)**2 - 2*m2sq*(m4sq + m5sq))) + (2*m1sq*m3sq*B0del(0,0,m3sq))/((m1sq - m2sq)*(m3sq - m4sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))) - (2*m2sq*m3sq*B0del(0,0,m3sq))/((m1sq - m2sq)*(m3sq - m4sq)*(m2**4 + (m3sq - m5sq)**2 - 2*m2sq*(m3sq + m5sq))) + (m3sq*(-((m2sq - m3sq - 3*m5sq)*(m3sq - m5sq)) + m1sq*(m2sq - m3sq + m5sq))*B0del(0,0,m3sq))/((m3sq - m4sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m2**4 + (m3sq - m5sq)**2 - 2*m2sq*(m3sq + m5sq))) - (2*m1sq*m4sq*B0del(0,0,m4sq))/((m1sq - m2sq)*(m3sq - m4sq)*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))) + (2*m2sq*m4sq*B0del(0,0,m4sq))/((m1sq - m2sq)*(m3sq - m4sq)*(m2**4 + (m4sq - m5sq)**2 - 2*m2sq*(m4sq + m5sq))) - (m4sq*(-((m2sq - m4sq - 3*m5sq)*(m4sq - m5sq)) + m1sq*(m2sq - m4sq + m5sq))*B0del(0,0,m4sq))/((m3sq - m4sq)*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))*(m2**4 + (m4sq - m5sq)**2 - 2*m2sq*(m4sq + m5sq))) + (m3sq*(-((m2sq - m3sq - 3*m5sq)*(m3sq - m5sq)) + m1sq*(m2sq - m3sq + m5sq))*B0del(0,0,m5sq))/((m3sq - m4sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m2**4 + (m3sq - m5sq)**2 - 2*m2sq*(m3sq + m5sq))) - (m4sq*(-((m2sq - m4sq - 3*m5sq)*(m4sq - m5sq)) + m1sq*(m2sq - m4sq + m5sq))*B0del(0,0,m5sq))/((m3sq - m4sq)*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))*(m2**4 + (m4sq - m5sq)**2 - 2*m2sq*(m4sq + m5sq))) + (m1sq*(m1**4 - m1sq*(m3sq + m4sq - 2*m5sq) + (m4sq - 3*m5sq)*m5sq + m3sq*(m4sq + m5sq))*B0del(0,0,m5sq))/((m1sq - m2sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))) - (m2sq*(m2**4 - m2sq*(m3sq + m4sq - 2*m5sq) + (m4sq - 3*m5sq)*m5sq + m3sq*(m4sq + m5sq))*B0del(0,0,m5sq))/((m1sq - m2sq)*(m2**4 + (m3sq - m5sq)**2 - 2*m2sq*(m3sq + m5sq))*(m2**4 + (m4sq - m5sq)**2 - 2*m2sq*(m4sq + m5sq))) - (2*m1sq*m3sq*B0fin(0,0,m1sq))/((m1sq - m2sq)*(m3sq - m4sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))) + (2*m1sq*m4sq*B0fin(0,0,m1sq))/((m1sq - m2sq)*(m3sq - m4sq)*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))) - (m1sq*(m1**4 - m1sq*(m3sq + m4sq - 2*m5sq) + (m4sq - 3*m5sq)*m5sq + m3sq*(m4sq + m5sq))*B0fin(0,0,m1sq))/((m1sq - m2sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))) + (2*m2sq*m3sq*B0fin(0,0,m2sq))/((m1sq - m2sq)*(m3sq - m4sq)*(m2**4 + (m3sq - m5sq)**2 - 2*m2sq*(m3sq + m5sq))) - (2*m2sq*m4sq*B0fin(0,0,m2sq))/((m1sq - m2sq)*(m3sq - m4sq)*(m2**4 + (m4sq - m5sq)**2 - 2*m2sq*(m4sq + m5sq))) + (m2sq*(m2**4 - m2sq*(m3sq + m4sq - 2*m5sq) + (m4sq - 3*m5sq)*m5sq + m3sq*(m4sq + m5sq))*B0fin(0,0,m2sq))/((m1sq - m2sq)*(m2**4 + (m3sq - m5sq)**2 - 2*m2sq*(m3sq + m5sq))*(m2**4 + (m4sq - m5sq)**2 - 2*m2sq*(m4sq + m5sq))) - (2*m1sq*m3sq*B0fin(0,0,m3sq))/((m1sq - m2sq)*(m3sq - m4sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))) + (2*m2sq*m3sq*B0fin(0,0,m3sq))/((m1sq - m2sq)*(m3sq - m4sq)*(m2**4 + (m3sq - m5sq)**2 - 2*m2sq*(m3sq + m5sq))) - (m3sq*(-((m2sq - m3sq - 3*m5sq)*(m3sq - m5sq)) + m1sq*(m2sq - m3sq + m5sq))*B0fin(0,0,m3sq))/((m3sq - m4sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m2**4 + (m3sq - m5sq)**2 - 2*m2sq*(m3sq + m5sq))) + (2*m1sq*m3sq*B0fin(0,0,m1sq)*B0fin(0,0,m3sq))/((m1sq - m2sq)*(m3sq - m4sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))) - (2*m2sq*m3sq*B0fin(0,0,m2sq)*B0fin(0,0,m3sq))/((m1sq - m2sq)*(m3sq - m4sq)*(m2**4 + (m3sq - m5sq)**2 - 2*m2sq*(m3sq + m5sq))) + (2*m1sq*m4sq*B0fin(0,0,m4sq))/((m1sq - m2sq)*(m3sq - m4sq)*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))) - (2*m2sq*m4sq*B0fin(0,0,m4sq))/((m1sq - m2sq)*(m3sq - m4sq)*(m2**4 + (m4sq - m5sq)**2 - 2*m2sq*(m4sq + m5sq))) + (m4sq*(-((m2sq - m4sq - 3*m5sq)*(m4sq - m5sq)) + m1sq*(m2sq - m4sq + m5sq))*B0fin(0,0,m4sq))/((m3sq - m4sq)*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))*(m2**4 + (m4sq - m5sq)**2 - 2*m2sq*(m4sq + m5sq))) - (2*m1sq*m4sq*B0fin(0,0,m1sq)*B0fin(0,0,m4sq))/((m1sq - m2sq)*(m3sq - m4sq)*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))) + (2*m2sq*m4sq*B0fin(0,0,m2sq)*B0fin(0,0,m4sq))/((m1sq - m2sq)*(m3sq - m4sq)*(m2**4 + (m4sq - m5sq)**2 - 2*m2sq*(m4sq + m5sq))) + ((m1sq + m3sq - m5sq)*(m1 + m3 + m5 + 2*m1*B0fin(0,0,m1) + 2*m3*B0fin(0,0,m3) + 2*m5*B0fin(0,0,m5)))/((m1sq - m2sq)*(m3sq - m4sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))) - ((m2sq + m3sq - m5sq)*(m2 + m3 + m5 + 2*m2*B0fin(0,0,m2) + 2*m3*B0fin(0,0,m3) + 2*m5*B0fin(0,0,m5)))/((m1sq - m2sq)*(m3sq - m4sq)*(m2**4 + (m3sq - m5sq)**2 - 2*m2sq*(m3sq + m5sq))) - ((m1sq + m4sq - m5sq)*(m1 + m4 + m5 + 2*m1*B0fin(0,0,m1) + 2*m4*B0fin(0,0,m4) + 2*m5*B0fin(0,0,m5)))/((m1sq - m2sq)*(m3sq - m4sq)*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))) + ((m2sq + m4sq - m5sq)*(m2 + m4 + m5 + 2*m2*B0fin(0,0,m2) + 2*m4*B0fin(0,0,m4) + 2*m5*B0fin(0,0,m5)))/((m1sq - m2sq)*(m3sq - m4sq)*(m2**4 + (m4sq - m5sq)**2 - 2*m2sq*(m4sq + m5sq))) - (m3sq*(-((m2sq - m3sq - 3*m5sq)*(m3sq - m5sq)) + m1sq*(m2sq - m3sq + m5sq))*B0fin(0,0,m5sq))/((m3sq - m4sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m2**4 + (m3sq - m5sq)**2 - 2*m2sq*(m3sq + m5sq))) + (m4sq*(-((m2sq - m4sq - 3*m5sq)*(m4sq - m5sq)) + m1sq*(m2sq - m4sq + m5sq))*B0fin(0,0,m5sq))/((m3sq - m4sq)*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))*(m2**4 + (m4sq - m5sq)**2 - 2*m2sq*(m4sq + m5sq))) - (m1sq*(m1**4 - m1sq*(m3sq + m4sq - 2*m5sq) + (m4sq - 3*m5sq)*m5sq + m3sq*(m4sq + m5sq))*B0fin(0,0,m5sq))/((m1sq - m2sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))) + (m2sq*(m2**4 - m2sq*(m3sq + m4sq - 2*m5sq) + (m4sq - 3*m5sq)*m5sq + m3sq*(m4sq + m5sq))*B0fin(0,0,m5sq))/((m1sq - m2sq)*(m2**4 + (m3sq - m5sq)**2 - 2*m2sq*(m3sq + m5sq))*(m2**4 + (m4sq - m5sq)**2 - 2*m2sq*(m4sq + m5sq))) + (m1sq*(m1**4 - m1sq*(m3sq + m4sq - 2*m5sq) + (m4sq - 3*m5sq)*m5sq + m3sq*(m4sq + m5sq))*B0fin(0,0,m1sq)*B0fin(0,0,m5sq))/((m1sq - m2sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))) - (m2sq*(m2**4 - m2sq*(m3sq + m4sq - 2*m5sq) + (m4sq - 3*m5sq)*m5sq + m3sq*(m4sq + m5sq))*B0fin(0,0,m2sq)*B0fin(0,0,m5sq))/((m1sq - m2sq)*(m2**4 + (m3sq - m5sq)**2 - 2*m2sq*(m3sq + m5sq))*(m2**4 + (m4sq - m5sq)**2 - 2*m2sq*(m4sq + m5sq))) + (m3sq*(-((m2sq - m3sq - 3*m5sq)*(m3sq - m5sq)) + m1sq*(m2sq - m3sq + m5sq))*B0fin(0,0,m3sq)*B0fin(0,0,m5sq))/((m3sq - m4sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m2**4 + (m3sq - m5sq)**2 - 2*m2sq*(m3sq + m5sq))) - (m4sq*(-((m2sq - m4sq - 3*m5sq)*(m4sq - m5sq)) + m1sq*(m2sq - m4sq + m5sq))*B0fin(0,0,m4sq)*B0fin(0,0,m5sq))/((m3sq - m4sq)*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))*(m2**4 + (m4sq - m5sq)**2 - 2*m2sq*(m4sq + m5sq))) - ((m1sq + m3sq - m5sq)*T134fin(m5,m3,m1))/((m1sq - m2sq)*(m3sq - m4sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))) + ((m2sq + m3sq - m5sq)*T134fin(m5,m3,m2))/((m1sq - m2sq)*(m3sq - m4sq)*(m2**4 + (m3sq - m5sq)**2 - 2*m2sq*(m3sq + m5sq))) + ((m1sq + m4sq - m5sq)*T134fin(m5,m4,m1))/((m1sq - m2sq)*(m3sq - m4sq)*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))) - ((m2sq + m4sq - m5sq)*T134fin(m5,m4,m2))/((m1sq - m2sq)*(m3sq - m4sq)*(m2**4 + (m4sq - m5sq)**2 - 2*m2sq*(m4sq + m5sq)))
		def eval_62():
			return (2*m1sq*m5sq*B0del(0,0,m1sq))/((m1sq - m2sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m5sq - m6sq)) - (2*m1sq*m6sq*B0del(0,0,m1sq))/((m1sq - m2sq)*(m5sq - m6sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) + (m1sq*(m1**4 - 3*m3**4 + m1sq*(2*m3sq - m5sq - m6sq) + m5sq*m6sq + m3sq*(m5sq + m6sq))*B0del(0,0,m1sq))/((m1sq - m2sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) - (2*m2sq*m5sq*B0del(0,0,m2sq))/((m1sq - m2sq)*(m2**4 + (m3sq - m5sq)**2 - 2*m2sq*(m3sq + m5sq))*(m5sq - m6sq)) + (2*m2sq*m6sq*B0del(0,0,m2sq))/((m1sq - m2sq)*(m5sq - m6sq)*(m2**4 + (m3sq - m6sq)**2 - 2*m2sq*(m3sq + m6sq))) - (m2sq*(m2**4 - 3*m3**4 + m2sq*(2*m3sq - m5sq - m6sq) + m5sq*m6sq + m3sq*(m5sq + m6sq))*B0del(0,0,m2sq))/((m1sq - m2sq)*(m2**4 + (m3sq - m5sq)**2 - 2*m2sq*(m3sq + m5sq))*(m2**4 + (m3sq - m6sq)**2 - 2*m2sq*(m3sq + m6sq))) + (((m2sq - 3*m3sq - m5sq)*(m3sq - m5sq) + m1sq*(m2sq + m3sq - m5sq))*m5sq*B0del(0,0,m3sq))/((m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m2**4 + (m3sq - m5sq)**2 - 2*m2sq*(m3sq + m5sq))*(m5sq - m6sq)) - (((m2sq - 3*m3sq - m6sq)*(m3sq - m6sq) + m1sq*(m2sq + m3sq - m6sq))*m6sq*B0del(0,0,m3sq))/((m5sq - m6sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))*(m2**4 + (m3sq - m6sq)**2 - 2*m2sq*(m3sq + m6sq))) + (m1sq*(m1**4 - 3*m3**4 + m1sq*(2*m3sq - m5sq - m6sq) + m5sq*m6sq + m3sq*(m5sq + m6sq))*B0del(0,0,m3sq))/((m1sq - m2sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) - (m2sq*(m2**4 - 3*m3**4 + m2sq*(2*m3sq - m5sq - m6sq) + m5sq*m6sq + m3sq*(m5sq + m6sq))*B0del(0,0,m3sq))/((m1sq - m2sq)*(m2**4 + (m3sq - m5sq)**2 - 2*m2sq*(m3sq + m5sq))*(m2**4 + (m3sq - m6sq)**2 - 2*m2sq*(m3sq + m6sq))) + (2*m1sq*m5sq*B0del(0,0,m5sq))/((m1sq - m2sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m5sq - m6sq)) - (2*m2sq*m5sq*B0del(0,0,m5sq))/((m1sq - m2sq)*(m2**4 + (m3sq - m5sq)**2 - 2*m2sq*(m3sq + m5sq))*(m5sq - m6sq)) + (((m2sq - 3*m3sq - m5sq)*(m3sq - m5sq) + m1sq*(m2sq + m3sq - m5sq))*m5sq*B0del(0,0,m5sq))/((m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m2**4 + (m3sq - m5sq)**2 - 2*m2sq*(m3sq + m5sq))*(m5sq - m6sq)) - (2*m1sq*m6sq*B0del(0,0,m6sq))/((m1sq - m2sq)*(m5sq - m6sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) + (2*m2sq*m6sq*B0del(0,0,m6sq))/((m1sq - m2sq)*(m5sq - m6sq)*(m2**4 + (m3sq - m6sq)**2 - 2*m2sq*(m3sq + m6sq))) - (((m2sq - 3*m3sq - m6sq)*(m3sq - m6sq) + m1sq*(m2sq + m3sq - m6sq))*m6sq*B0del(0,0,m6sq))/((m5sq - m6sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))*(m2**4 + (m3sq - m6sq)**2 - 2*m2sq*(m3sq + m6sq))) - (2*m1sq*m5sq*B0fin(0,0,m1sq))/((m1sq - m2sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m5sq - m6sq)) + (2*m1sq*m6sq*B0fin(0,0,m1sq))/((m1sq - m2sq)*(m5sq - m6sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) - (m1sq*(m1**4 - 3*m3**4 + m1sq*(2*m3sq - m5sq - m6sq) + m5sq*m6sq + m3sq*(m5sq + m6sq))*B0fin(0,0,m1sq))/((m1sq - m2sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) + (2*m2sq*m5sq*B0fin(0,0,m2sq))/((m1sq - m2sq)*(m2**4 + (m3sq - m5sq)**2 - 2*m2sq*(m3sq + m5sq))*(m5sq - m6sq)) - (2*m2sq*m6sq*B0fin(0,0,m2sq))/((m1sq - m2sq)*(m5sq - m6sq)*(m2**4 + (m3sq - m6sq)**2 - 2*m2sq*(m3sq + m6sq))) + (m2sq*(m2**4 - 3*m3**4 + m2sq*(2*m3sq - m5sq - m6sq) + m5sq*m6sq + m3sq*(m5sq + m6sq))*B0fin(0,0,m2sq))/((m1sq - m2sq)*(m2**4 + (m3sq - m5sq)**2 - 2*m2sq*(m3sq + m5sq))*(m2**4 + (m3sq - m6sq)**2 - 2*m2sq*(m3sq + m6sq))) - (((m2sq - 3*m3sq - m5sq)*(m3sq - m5sq) + m1sq*(m2sq + m3sq - m5sq))*m5sq*B0fin(0,0,m3sq))/((m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m2**4 + (m3sq - m5sq)**2 - 2*m2sq*(m3sq + m5sq))*(m5sq - m6sq)) + (((m2sq - 3*m3sq - m6sq)*(m3sq - m6sq) + m1sq*(m2sq + m3sq - m6sq))*m6sq*B0fin(0,0,m3sq))/((m5sq - m6sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))*(m2**4 + (m3sq - m6sq)**2 - 2*m2sq*(m3sq + m6sq))) - (m1sq*(m1**4 - 3*m3**4 + m1sq*(2*m3sq - m5sq - m6sq) + m5sq*m6sq + m3sq*(m5sq + m6sq))*B0fin(0,0,m3sq))/((m1sq - m2sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) + (m2sq*(m2**4 - 3*m3**4 + m2sq*(2*m3sq - m5sq - m6sq) + m5sq*m6sq + m3sq*(m5sq + m6sq))*B0fin(0,0,m3sq))/((m1sq - m2sq)*(m2**4 + (m3sq - m5sq)**2 - 2*m2sq*(m3sq + m5sq))*(m2**4 + (m3sq - m6sq)**2 - 2*m2sq*(m3sq + m6sq))) + (m1sq*(m1**4 - 3*m3**4 + m1sq*(2*m3sq - m5sq - m6sq) + m5sq*m6sq + m3sq*(m5sq + m6sq))*B0fin(0,0,m1sq)*B0fin(0,0,m3sq))/((m1sq - m2sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) - (m2sq*(m2**4 - 3*m3**4 + m2sq*(2*m3sq - m5sq - m6sq) + m5sq*m6sq + m3sq*(m5sq + m6sq))*B0fin(0,0,m2sq)*B0fin(0,0,m3sq))/((m1sq - m2sq)*(m2**4 + (m3sq - m5sq)**2 - 2*m2sq*(m3sq + m5sq))*(m2**4 + (m3sq - m6sq)**2 - 2*m2sq*(m3sq + m6sq))) + ((m1sq - m3sq + m5sq)*(m1 + m3 + m5 + 2*m1*B0fin(0,0,m1) + 2*m3*B0fin(0,0,m3) + 2*m5*B0fin(0,0,m5)))/((m1sq - m2sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m5sq - m6sq)) - ((m2sq - m3sq + m5sq)*(m2 + m3 + m5 + 2*m2*B0fin(0,0,m2) + 2*m3*B0fin(0,0,m3) + 2*m5*B0fin(0,0,m5)))/((m1sq - m2sq)*(m2**4 + (m3sq - m5sq)**2 - 2*m2sq*(m3sq + m5sq))*(m5sq - m6sq)) - (2*m1sq*m5sq*B0fin(0,0,m5sq))/((m1sq - m2sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m5sq - m6sq)) + (2*m2sq*m5sq*B0fin(0,0,m5sq))/((m1sq - m2sq)*(m2**4 + (m3sq - m5sq)**2 - 2*m2sq*(m3sq + m5sq))*(m5sq - m6sq)) - (((m2sq - 3*m3sq - m5sq)*(m3sq - m5sq) + m1sq*(m2sq + m3sq - m5sq))*m5sq*B0fin(0,0,m5sq))/((m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m2**4 + (m3sq - m5sq)**2 - 2*m2sq*(m3sq + m5sq))*(m5sq - m6sq)) + (2*m1sq*m5sq*B0fin(0,0,m1sq)*B0fin(0,0,m5sq))/((m1sq - m2sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m5sq - m6sq)) - (2*m2sq*m5sq*B0fin(0,0,m2sq)*B0fin(0,0,m5sq))/((m1sq - m2sq)*(m2**4 + (m3sq - m5sq)**2 - 2*m2sq*(m3sq + m5sq))*(m5sq - m6sq)) + (((m2sq - 3*m3sq - m5sq)*(m3sq - m5sq) + m1sq*(m2sq + m3sq - m5sq))*m5sq*B0fin(0,0,m3sq)*B0fin(0,0,m5sq))/((m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m2**4 + (m3sq - m5sq)**2 - 2*m2sq*(m3sq + m5sq))*(m5sq - m6sq)) - ((m1sq - m3sq + m6sq)*(m1 + m3 + m6 + 2*m1*B0fin(0,0,m1) + 2*m3*B0fin(0,0,m3) + 2*m6*B0fin(0,0,m6)))/((m1sq - m2sq)*(m5sq - m6sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) + ((m2sq - m3sq + m6sq)*(m2 + m3 + m6 + 2*m2*B0fin(0,0,m2) + 2*m3*B0fin(0,0,m3) + 2*m6*B0fin(0,0,m6)))/((m1sq - m2sq)*(m5sq - m6sq)*(m2**4 + (m3sq - m6sq)**2 - 2*m2sq*(m3sq + m6sq))) + (2*m1sq*m6sq*B0fin(0,0,m6sq))/((m1sq - m2sq)*(m5sq - m6sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) - (2*m2sq*m6sq*B0fin(0,0,m6sq))/((m1sq - m2sq)*(m5sq - m6sq)*(m2**4 + (m3sq - m6sq)**2 - 2*m2sq*(m3sq + m6sq))) + (((m2sq - 3*m3sq - m6sq)*(m3sq - m6sq) + m1sq*(m2sq + m3sq - m6sq))*m6sq*B0fin(0,0,m6sq))/((m5sq - m6sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))*(m2**4 + (m3sq - m6sq)**2 - 2*m2sq*(m3sq + m6sq))) - (2*m1sq*m6sq*B0fin(0,0,m1sq)*B0fin(0,0,m6sq))/((m1sq - m2sq)*(m5sq - m6sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) + (2*m2sq*m6sq*B0fin(0,0,m2sq)*B0fin(0,0,m6sq))/((m1sq - m2sq)*(m5sq - m6sq)*(m2**4 + (m3sq - m6sq)**2 - 2*m2sq*(m3sq + m6sq))) - (((m2sq - 3*m3sq - m6sq)*(m3sq - m6sq) + m1sq*(m2sq + m3sq - m6sq))*m6sq*B0fin(0,0,m3sq)*B0fin(0,0,m6sq))/((m5sq - m6sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))*(m2**4 + (m3sq - m6sq)**2 - 2*m2sq*(m3sq + m6sq))) - ((m1sq - m3sq + m5sq)*T134fin(m5,m3,m1))/((m1sq - m2sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m5sq - m6sq)) + ((m2sq - m3sq + m5sq)*T134fin(m5,m3,m2))/((m1sq - m2sq)*(m2**4 + (m3sq - m5sq)**2 - 2*m2sq*(m3sq + m5sq))*(m5sq - m6sq)) + ((m1sq - m3sq + m6sq)*T134fin(m6,m3,m1))/((m1sq - m2sq)*(m5sq - m6sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) - ((m2sq - m3sq + m6sq)*T134fin(m6,m3,m2))/((m1sq - m2sq)*(m5sq - m6sq)*(m2**4 + (m3sq - m6sq)**2 - 2*m2sq*(m3sq + m6sq)))
		def eval_63():
			return (m5sq*(-3*m1**4 + (m3sq - m5sq)*(m4sq - m5sq) + m1sq*(m3sq + m4sq + 2*m5sq))*B0del(0,0,m1sq))/((m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))*(m5sq - m6sq)) + (m3sq*(-3*m1**4 + (m3sq - m5sq)*(m3sq - m6sq) + m1sq*(2*m3sq + m5sq + m6sq))*B0del(0,0,m1sq))/((m3sq - m4sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) - (m4sq*(-3*m1**4 + (m4sq - m5sq)*(m4sq - m6sq) + m1sq*(2*m4sq + m5sq + m6sq))*B0del(0,0,m1sq))/((m3sq - m4sq)*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) - (m6sq*(-3*m1**4 + (m3sq - m6sq)*(m4sq - m6sq) + m1sq*(m3sq + m4sq + 2*m6sq))*B0del(0,0,m1sq))/((m5sq - m6sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) + (2*m3sq*m5sq*B0del(0,0,m3sq))/((m3sq - m4sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m5sq - m6sq)) - (2*m3sq*m6sq*B0del(0,0,m3sq))/((m3sq - m4sq)*(m5sq - m6sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) + (m3sq*(-3*m1**4 + (m3sq - m5sq)*(m3sq - m6sq) + m1sq*(2*m3sq + m5sq + m6sq))*B0del(0,0,m3sq))/((m3sq - m4sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) - (2*m4sq*m5sq*B0del(0,0,m4sq))/((m3sq - m4sq)*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))*(m5sq - m6sq)) + (2*m4sq*m6sq*B0del(0,0,m4sq))/((m3sq - m4sq)*(m5sq - m6sq)*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) - (m4sq*(-3*m1**4 + (m4sq - m5sq)*(m4sq - m6sq) + m1sq*(2*m4sq + m5sq + m6sq))*B0del(0,0,m4sq))/((m3sq - m4sq)*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) + (2*m3sq*m5sq*B0del(0,0,m5sq))/((m3sq - m4sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m5sq - m6sq)) - (2*m4sq*m5sq*B0del(0,0,m5sq))/((m3sq - m4sq)*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))*(m5sq - m6sq)) + (m5sq*(-3*m1**4 + (m3sq - m5sq)*(m4sq - m5sq) + m1sq*(m3sq + m4sq + 2*m5sq))*B0del(0,0,m5sq))/((m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))*(m5sq - m6sq)) - (2*m3sq*m6sq*B0del(0,0,m6sq))/((m3sq - m4sq)*(m5sq - m6sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) + (2*m4sq*m6sq*B0del(0,0,m6sq))/((m3sq - m4sq)*(m5sq - m6sq)*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) - (m6sq*(-3*m1**4 + (m3sq - m6sq)*(m4sq - m6sq) + m1sq*(m3sq + m4sq + 2*m6sq))*B0del(0,0,m6sq))/((m5sq - m6sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) - (m5sq*(-3*m1**4 + (m3sq - m5sq)*(m4sq - m5sq) + m1sq*(m3sq + m4sq + 2*m5sq))*B0fin(0,0,m1sq))/((m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))*(m5sq - m6sq)) - (m3sq*(-3*m1**4 + (m3sq - m5sq)*(m3sq - m6sq) + m1sq*(2*m3sq + m5sq + m6sq))*B0fin(0,0,m1sq))/((m3sq - m4sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) + (m4sq*(-3*m1**4 + (m4sq - m5sq)*(m4sq - m6sq) + m1sq*(2*m4sq + m5sq + m6sq))*B0fin(0,0,m1sq))/((m3sq - m4sq)*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) + (m6sq*(-3*m1**4 + (m3sq - m6sq)*(m4sq - m6sq) + m1sq*(m3sq + m4sq + 2*m6sq))*B0fin(0,0,m1sq))/((m5sq - m6sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) - (2*m3sq*m5sq*B0fin(0,0,m3sq))/((m3sq - m4sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m5sq - m6sq)) + (2*m3sq*m6sq*B0fin(0,0,m3sq))/((m3sq - m4sq)*(m5sq - m6sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) - (m3sq*(-3*m1**4 + (m3sq - m5sq)*(m3sq - m6sq) + m1sq*(2*m3sq + m5sq + m6sq))*B0fin(0,0,m3sq))/((m3sq - m4sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) + (m3sq*(-3*m1**4 + (m3sq - m5sq)*(m3sq - m6sq) + m1sq*(2*m3sq + m5sq + m6sq))*B0fin(0,0,m1sq)*B0fin(0,0,m3sq))/((m3sq - m4sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) + (2*m4sq*m5sq*B0fin(0,0,m4sq))/((m3sq - m4sq)*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))*(m5sq - m6sq)) - (2*m4sq*m6sq*B0fin(0,0,m4sq))/((m3sq - m4sq)*(m5sq - m6sq)*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) + (m4sq*(-3*m1**4 + (m4sq - m5sq)*(m4sq - m6sq) + m1sq*(2*m4sq + m5sq + m6sq))*B0fin(0,0,m4sq))/((m3sq - m4sq)*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) - (m4sq*(-3*m1**4 + (m4sq - m5sq)*(m4sq - m6sq) + m1sq*(2*m4sq + m5sq + m6sq))*B0fin(0,0,m1sq)*B0fin(0,0,m4sq))/((m3sq - m4sq)*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) + ((-m1sq + m3sq + m5sq)*(m1 + m3 + m5 + 2*m1*B0fin(0,0,m1) + 2*m3*B0fin(0,0,m3) + 2*m5*B0fin(0,0,m5)))/((m3sq - m4sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m5sq - m6sq)) - ((-m1sq + m4sq + m5sq)*(m1 + m4 + m5 + 2*m1*B0fin(0,0,m1) + 2*m4*B0fin(0,0,m4) + 2*m5*B0fin(0,0,m5)))/((m3sq - m4sq)*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))*(m5sq - m6sq)) - (2*m3sq*m5sq*B0fin(0,0,m5sq))/((m3sq - m4sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m5sq - m6sq)) + (2*m4sq*m5sq*B0fin(0,0,m5sq))/((m3sq - m4sq)*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))*(m5sq - m6sq)) - (m5sq*(-3*m1**4 + (m3sq - m5sq)*(m4sq - m5sq) + m1sq*(m3sq + m4sq + 2*m5sq))*B0fin(0,0,m5sq))/((m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))*(m5sq - m6sq)) + (m5sq*(-3*m1**4 + (m3sq - m5sq)*(m4sq - m5sq) + m1sq*(m3sq + m4sq + 2*m5sq))*B0fin(0,0,m1sq)*B0fin(0,0,m5sq))/((m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))*(m5sq - m6sq)) + (2*m3sq*m5sq*B0fin(0,0,m3sq)*B0fin(0,0,m5sq))/((m3sq - m4sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m5sq - m6sq)) - (2*m4sq*m5sq*B0fin(0,0,m4sq)*B0fin(0,0,m5sq))/((m3sq - m4sq)*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))*(m5sq - m6sq)) - ((-m1sq + m3sq + m6sq)*(m1 + m3 + m6 + 2*m1*B0fin(0,0,m1) + 2*m3*B0fin(0,0,m3) + 2*m6*B0fin(0,0,m6)))/((m3sq - m4sq)*(m5sq - m6sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) + ((-m1sq + m4sq + m6sq)*(m1 + m4 + m6 + 2*m1*B0fin(0,0,m1) + 2*m4*B0fin(0,0,m4) + 2*m6*B0fin(0,0,m6)))/((m3sq - m4sq)*(m5sq - m6sq)*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) + (2*m3sq*m6sq*B0fin(0,0,m6sq))/((m3sq - m4sq)*(m5sq - m6sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) - (2*m4sq*m6sq*B0fin(0,0,m6sq))/((m3sq - m4sq)*(m5sq - m6sq)*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) + (m6sq*(-3*m1**4 + (m3sq - m6sq)*(m4sq - m6sq) + m1sq*(m3sq + m4sq + 2*m6sq))*B0fin(0,0,m6sq))/((m5sq - m6sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) - (m6sq*(-3*m1**4 + (m3sq - m6sq)*(m4sq - m6sq) + m1sq*(m3sq + m4sq + 2*m6sq))*B0fin(0,0,m1sq)*B0fin(0,0,m6sq))/((m5sq - m6sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) - (2*m3sq*m6sq*B0fin(0,0,m3sq)*B0fin(0,0,m6sq))/((m3sq - m4sq)*(m5sq - m6sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) + (2*m4sq*m6sq*B0fin(0,0,m4sq)*B0fin(0,0,m6sq))/((m3sq - m4sq)*(m5sq - m6sq)*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq))) - ((-m1sq + m3sq + m5sq)*T134fin(m5,m3,m1))/((m3sq - m4sq)*(m1**4 + (m3sq - m5sq)**2 - 2*m1sq*(m3sq + m5sq))*(m5sq - m6sq)) + ((-m1sq + m4sq + m5sq)*T134fin(m5,m4,m1))/((m3sq - m4sq)*(m1**4 + (m4sq - m5sq)**2 - 2*m1sq*(m4sq + m5sq))*(m5sq - m6sq)) + ((-m1sq + m3sq + m6sq)*T134fin(m6,m3,m1))/((m3sq - m4sq)*(m5sq - m6sq)*(m1**4 + (m3sq - m6sq)**2 - 2*m1sq*(m3sq + m6sq))) - ((-m1sq + m4sq + m6sq)*T134fin(m6,m4,m1))/((m3sq - m4sq)*(m5sq - m6sq)*(m1**4 + (m4sq - m6sq)**2 - 2*m1sq*(m4sq + m6sq)))
		def eval_64():
			return (T134fin(m5,m3,m1) - T134fin(m5,m3,m2) - T134fin(m5,m4,m1) + T134fin(m5,m4,m2) - T134fin(m6,m3,m1) + T134fin(m6,m3,m2) + T134fin(m6,m4,m1) - T134fin(m6,m4,m2))/((m1sq - m2sq)*(m3sq - m4sq)*(m5sq - m6sq))

		cond_m1_0 = cond(m1, 0)
		cond_m2_0 = cond(m2, 0)
		cond_m3_0 = cond(m3, 0)
		cond_m4_0 = cond(m4, 0)
		cond_m5_0 = cond(m5, 0)
		cond_m6_0 = cond(m6, 0)
		cond_m6_m5 = cond(m6, m5)
		cond_m6_m4 = cond(m6, m4)
		cond_m5_m4 = cond(m5, m4)
		cond_m6_m3 = cond(m6, m3)
		cond_m5_m3 = cond(m5, m3)
		cond_m4_m3 = cond(m4, m3)
		cond_m6_m2 = cond(m6, m2)
		cond_m5_m2 = cond(m5, m2)
		cond_m4_m2 = cond(m4, m2)
		cond_m3_m2 = cond(m3, m2)
		cond_m6_m1 = cond(m6, m1)
		cond_m5_m1 = cond(m5, m1)
		cond_m4_m1 = cond(m4, m1)
		cond_m3_m1 = cond(m3, m1)
		cond_m2_m1 = cond(m2, m1)

		conditions = [
			(cond_m1_0 and cond_m2_0 and cond_m3_0 and cond_m4_0 and cond_m5_0 and cond_m6_0, lambda: eval_1()),
			(cond_m1_0 and cond_m2_0 and cond_m3_0 and cond_m4_0 and cond_m5_0, lambda: eval_2()),
			(cond_m1_0 and cond_m2_0 and cond_m3_0 and cond_m4_0 and cond_m6_0, lambda: eval_2()),
			(cond_m1_0 and cond_m2_0 and cond_m3_0 and cond_m5_0 and cond_m6_0, lambda: eval_3()),
			(cond_m1_0 and cond_m2_0 and cond_m4_0 and cond_m5_0 and cond_m6_0, lambda: eval_3()),
			(cond_m1_0 and cond_m3_0 and cond_m4_0 and cond_m5_0 and cond_m6_0, lambda: eval_4()),
			(cond_m2_0 and cond_m3_0 and cond_m4_0 and cond_m5_0 and cond_m6_0, lambda: eval_4()),
			(cond_m1_0 and cond_m2_0 and cond_m3_0 and cond_m4_0 and cond_m6_m5, lambda: eval_48()),
			(cond_m1_0 and cond_m2_0 and cond_m3_0 and cond_m5_0 and cond_m6_m4, lambda: eval_19()),
			(cond_m1_0 and cond_m2_0 and cond_m3_0 and cond_m5_m4 and cond_m6_0, lambda: eval_19()),
			(cond_m1_0 and cond_m2_0 and cond_m4_0 and cond_m5_0 and cond_m6_m3, lambda: eval_19()),
			(cond_m1_0 and cond_m2_0 and cond_m4_0 and cond_m5_m3 and cond_m6_0, lambda: eval_19()),
			(cond_m1_0 and cond_m2_0 and cond_m4_m3 and cond_m5_0 and cond_m6_0, lambda: eval_48()),
			(cond_m1_0 and cond_m3_0 and cond_m4_0 and cond_m5_0 and cond_m6_m2, lambda: eval_24()),
			(cond_m1_0 and cond_m3_0 and cond_m4_0 and cond_m5_m2 and cond_m6_0, lambda: eval_24()),
			(cond_m1_0 and cond_m3_0 and cond_m4_m2 and cond_m5_0 and cond_m6_0, lambda: eval_25()),
			(cond_m1_0 and cond_m3_m2 and cond_m4_0 and cond_m5_0 and cond_m6_0, lambda: eval_25()),
			(cond_m2_0 and cond_m3_0 and cond_m4_0 and cond_m5_0 and cond_m6_m1, lambda: eval_24()),
			(cond_m2_0 and cond_m3_0 and cond_m4_0 and cond_m5_m1 and cond_m6_0, lambda: eval_24()),
			(cond_m2_0 and cond_m3_0 and cond_m4_m1 and cond_m5_0 and cond_m6_0, lambda: eval_25()),
			(cond_m2_0 and cond_m3_m1 and cond_m4_0 and cond_m5_0 and cond_m6_0, lambda: eval_25()),
			(cond_m2_m1 and cond_m3_0 and cond_m4_0 and cond_m5_0 and cond_m6_0, lambda: eval_48()),
			(cond_m1_0 and cond_m2_0 and cond_m3_0 and cond_m4_0, lambda: eval_56()),
			(cond_m1_0 and cond_m2_0 and cond_m3_0 and cond_m5_0, lambda: eval_40()),
			(cond_m1_0 and cond_m2_0 and cond_m3_0 and cond_m6_0, lambda: eval_40()),
			(cond_m1_0 and cond_m2_0 and cond_m4_0 and cond_m5_0, lambda: eval_40()),
			(cond_m1_0 and cond_m2_0 and cond_m4_0 and cond_m6_0, lambda: eval_40()),
			(cond_m1_0 and cond_m2_0 and cond_m5_0 and cond_m6_0, lambda: eval_55()),
			(cond_m1_0 and cond_m3_0 and cond_m4_0 and cond_m5_0, lambda: eval_42()),
			(cond_m1_0 and cond_m3_0 and cond_m4_0 and cond_m6_0, lambda: eval_42()),
			(cond_m1_0 and cond_m3_0 and cond_m5_0 and cond_m6_0, lambda: eval_43()),
			(cond_m1_0 and cond_m4_0 and cond_m5_0 and cond_m6_0, lambda: eval_43()),
			(cond_m2_0 and cond_m3_0 and cond_m4_0 and cond_m5_0, lambda: eval_42()),
			(cond_m2_0 and cond_m3_0 and cond_m4_0 and cond_m6_0, lambda: eval_42()),
			(cond_m2_0 and cond_m3_0 and cond_m5_0 and cond_m6_0, lambda: eval_43()),
			(cond_m2_0 and cond_m4_0 and cond_m5_0 and cond_m6_0, lambda: eval_43()),
			(cond_m3_0 and cond_m4_0 and cond_m5_0 and cond_m6_0, lambda: eval_50()),
			(cond_m1_0 and cond_m2_0 and cond_m3_0 and cond_m5_m4 and cond_m6_m4, lambda: eval_18()),
			(cond_m1_0 and cond_m2_0 and cond_m4_0 and cond_m5_m3 and cond_m6_m3, lambda: eval_18()),
			(cond_m1_0 and cond_m2_0 and cond_m4_m3 and cond_m5_0 and cond_m6_m3, lambda: eval_5()),
			(cond_m1_0 and cond_m2_0 and cond_m4_m3 and cond_m5_m3 and cond_m6_0, lambda: eval_5()),
			(cond_m1_0 and cond_m3_0 and cond_m4_0 and cond_m5_m2 and cond_m6_m2, lambda: eval_22()),
			(cond_m1_0 and cond_m3_0 and cond_m4_m2 and cond_m5_0 and cond_m6_m2, lambda: eval_64()),
			(cond_m1_0 and cond_m3_0 and cond_m4_m2 and cond_m5_m2 and cond_m6_0, lambda: eval_64()),
			(cond_m1_0 and cond_m3_m2 and cond_m4_0 and cond_m5_0 and cond_m6_m2, lambda: eval_64()),
			(cond_m1_0 and cond_m3_m2 and cond_m4_0 and cond_m5_m2 and cond_m6_0, lambda: eval_64()),
			(cond_m1_0 and cond_m3_m2 and cond_m4_m2 and cond_m5_0 and cond_m6_0, lambda: eval_23()),
			(cond_m2_0 and cond_m3_0 and cond_m4_0 and cond_m5_m1 and cond_m6_m1, lambda: eval_22()),
			(cond_m2_0 and cond_m3_0 and cond_m4_m1 and cond_m5_0 and cond_m6_m1, lambda: eval_64()),
			(cond_m2_0 and cond_m3_0 and cond_m4_m1 and cond_m5_m1 and cond_m6_0, lambda: eval_64()),
			(cond_m2_0 and cond_m3_m1 and cond_m4_0 and cond_m5_0 and cond_m6_m1, lambda: eval_64()),
			(cond_m2_0 and cond_m3_m1 and cond_m4_0 and cond_m5_m1 and cond_m6_0, lambda: eval_64()),
			(cond_m2_0 and cond_m3_m1 and cond_m4_m1 and cond_m5_0 and cond_m6_0, lambda: eval_23()),
			(cond_m2_m1 and cond_m3_0 and cond_m4_0 and cond_m5_0 and cond_m6_m1, lambda: eval_6()),
			(cond_m2_m1 and cond_m3_0 and cond_m4_0 and cond_m5_m1 and cond_m6_0, lambda: eval_6()),
			(cond_m2_m1 and cond_m3_0 and cond_m4_m1 and cond_m5_0 and cond_m6_0, lambda: eval_7()),
			(cond_m2_m1 and cond_m3_m1 and cond_m4_0 and cond_m5_0 and cond_m6_0, lambda: eval_7()),
			(cond_m1_0 and cond_m2_0 and cond_m3_0 and cond_m6_m5, lambda: eval_55()),
			(cond_m1_0 and cond_m2_0 and cond_m4_0 and cond_m6_m5, lambda: eval_55()),
			(cond_m1_0 and cond_m2_0 and cond_m5_0 and cond_m6_m4, lambda: eval_8()),
			(cond_m1_0 and cond_m2_0 and cond_m5_m4 and cond_m6_0, lambda: eval_8()),
			(cond_m1_0 and cond_m3_0 and cond_m4_0 and cond_m6_m5, lambda: eval_50()),
			(cond_m1_0 and cond_m3_0 and cond_m5_0 and cond_m6_m4, lambda: eval_64()),
			(cond_m1_0 and cond_m3_0 and cond_m5_m4 and cond_m6_0, lambda: eval_64()),
			(cond_m1_0 and cond_m4_0 and cond_m5_0 and cond_m6_m3, lambda: eval_64()),
			(cond_m1_0 and cond_m4_0 and cond_m5_m3 and cond_m6_0, lambda: eval_64()),
			(cond_m1_0 and cond_m4_m3 and cond_m5_0 and cond_m6_0, lambda: eval_50()),
			(cond_m1_0 and cond_m2_0 and cond_m3_0 and cond_m5_m4, lambda: eval_30()),
			(cond_m1_0 and cond_m2_0 and cond_m3_0 and cond_m6_m4, lambda: eval_30()),
			(cond_m1_0 and cond_m2_0 and cond_m4_0 and cond_m5_m3, lambda: eval_30()),
			(cond_m1_0 and cond_m2_0 and cond_m4_0 and cond_m6_m3, lambda: eval_30()),
			(cond_m1_0 and cond_m2_0 and cond_m4_m3 and cond_m5_0, lambda: eval_56()),
			(cond_m1_0 and cond_m2_0 and cond_m4_m3 and cond_m6_0, lambda: eval_56()),
			(cond_m1_0 and cond_m2_0 and cond_m5_0 and cond_m6_m3, lambda: eval_9()),
			(cond_m1_0 and cond_m2_0 and cond_m5_m3 and cond_m6_0, lambda: eval_9()),
			(cond_m1_0 and cond_m3_0 and cond_m4_0 and cond_m5_m2, lambda: eval_32()),
			(cond_m1_0 and cond_m3_0 and cond_m4_0 and cond_m6_m2, lambda: eval_32()),
			(cond_m1_0 and cond_m3_0 and cond_m4_m2 and cond_m5_0, lambda: eval_64()),
			(cond_m1_0 and cond_m3_0 and cond_m4_m2 and cond_m6_0, lambda: eval_64()),
			(cond_m1_0 and cond_m3_0 and cond_m5_0 and cond_m6_m2, lambda: eval_64()),
			(cond_m1_0 and cond_m3_0 and cond_m5_m2 and cond_m6_0, lambda: eval_64()),
			(cond_m1_0 and cond_m3_m2 and cond_m4_0 and cond_m5_0, lambda: eval_64()),
			(cond_m1_0 and cond_m3_m2 and cond_m4_0 and cond_m6_0, lambda: eval_64()),
			(cond_m1_0 and cond_m3_m2 and cond_m5_0 and cond_m6_0, lambda: eval_33()),
			(cond_m1_0 and cond_m4_0 and cond_m5_0 and cond_m6_m2, lambda: eval_64()),
			(cond_m1_0 and cond_m4_0 and cond_m5_m2 and cond_m6_0, lambda: eval_64()),
			(cond_m1_0 and cond_m4_m2 and cond_m5_0 and cond_m6_0, lambda: eval_33()),
			(cond_m2_0 and cond_m3_0 and cond_m4_0 and cond_m6_m5, lambda: eval_50()),
			(cond_m2_0 and cond_m3_0 and cond_m5_0 and cond_m6_m4, lambda: eval_64()),
			(cond_m2_0 and cond_m3_0 and cond_m5_m4 and cond_m6_0, lambda: eval_64()),
			(cond_m2_0 and cond_m4_0 and cond_m5_0 and cond_m6_m3, lambda: eval_64()),
			(cond_m2_0 and cond_m4_0 and cond_m5_m3 and cond_m6_0, lambda: eval_64()),
			(cond_m2_0 and cond_m4_m3 and cond_m5_0 and cond_m6_0, lambda: eval_50()),
			(cond_m3_0 and cond_m4_0 and cond_m5_0 and cond_m6_m2, lambda: eval_10()),
			(cond_m3_0 and cond_m4_0 and cond_m5_m2 and cond_m6_0, lambda: eval_10()),
			(cond_m3_0 and cond_m4_m2 and cond_m5_0 and cond_m6_0, lambda: eval_11()),
			(cond_m3_m2 and cond_m4_0 and cond_m5_0 and cond_m6_0, lambda: eval_11()),
			(cond_m2_0 and cond_m3_0 and cond_m4_0 and cond_m5_m1, lambda: eval_32()),
			(cond_m2_0 and cond_m3_0 and cond_m4_0 and cond_m6_m1, lambda: eval_32()),
			(cond_m2_0 and cond_m3_0 and cond_m4_m1 and cond_m5_0, lambda: eval_64()),
			(cond_m2_0 and cond_m3_0 and cond_m4_m1 and cond_m6_0, lambda: eval_64()),
			(cond_m2_0 and cond_m3_0 and cond_m5_0 and cond_m6_m1, lambda: eval_64()),
			(cond_m2_0 and cond_m3_0 and cond_m5_m1 and cond_m6_0, lambda: eval_64()),
			(cond_m2_0 and cond_m3_m1 and cond_m4_0 and cond_m5_0, lambda: eval_64()),
			(cond_m2_0 and cond_m3_m1 and cond_m4_0 and cond_m6_0, lambda: eval_64()),
			(cond_m2_0 and cond_m3_m1 and cond_m5_0 and cond_m6_0, lambda: eval_33()),
			(cond_m2_0 and cond_m4_0 and cond_m5_0 and cond_m6_m1, lambda: eval_64()),
			(cond_m2_0 and cond_m4_0 and cond_m5_m1 and cond_m6_0, lambda: eval_64()),
			(cond_m2_0 and cond_m4_m1 and cond_m5_0 and cond_m6_0, lambda: eval_33()),
			(cond_m2_m1 and cond_m3_0 and cond_m4_0 and cond_m5_0, lambda: eval_56()),
			(cond_m2_m1 and cond_m3_0 and cond_m4_0 and cond_m6_0, lambda: eval_56()),
			(cond_m2_m1 and cond_m3_0 and cond_m5_0 and cond_m6_0, lambda: eval_55()),
			(cond_m2_m1 and cond_m4_0 and cond_m5_0 and cond_m6_0, lambda: eval_55()),
			(cond_m3_0 and cond_m4_0 and cond_m5_0 and cond_m6_m1, lambda: eval_12()),
			(cond_m3_0 and cond_m4_0 and cond_m5_m1 and cond_m6_0, lambda: eval_12()),
			(cond_m3_0 and cond_m4_m1 and cond_m5_0 and cond_m6_0, lambda: eval_13()),
			(cond_m3_m1 and cond_m4_0 and cond_m5_0 and cond_m6_0, lambda: eval_13()),
			(cond_m1_0 and cond_m2_0 and cond_m3_0, lambda: eval_63()),
			(cond_m1_0 and cond_m2_0 and cond_m4_0, lambda: eval_63()),
			(cond_m1_0 and cond_m2_0 and cond_m5_0, lambda: eval_63()),
			(cond_m1_0 and cond_m2_0 and cond_m6_0, lambda: eval_63()),
			(cond_m1_0 and cond_m3_0 and cond_m4_0, lambda: eval_62()),
			(cond_m1_0 and cond_m3_0 and cond_m5_0, lambda: eval_64()),
			(cond_m1_0 and cond_m3_0 and cond_m6_0, lambda: eval_64()),
			(cond_m1_0 and cond_m4_0 and cond_m5_0, lambda: eval_64()),
			(cond_m1_0 and cond_m4_0 and cond_m6_0, lambda: eval_64()),
			(cond_m1_0 and cond_m5_0 and cond_m6_0, lambda: eval_61()),
			(cond_m2_0 and cond_m3_0 and cond_m4_0, lambda: eval_62()),
			(cond_m2_0 and cond_m3_0 and cond_m5_0, lambda: eval_64()),
			(cond_m2_0 and cond_m3_0 and cond_m6_0, lambda: eval_64()),
			(cond_m2_0 and cond_m4_0 and cond_m5_0, lambda: eval_64()),
			(cond_m2_0 and cond_m4_0 and cond_m6_0, lambda: eval_64()),
			(cond_m2_0 and cond_m5_0 and cond_m6_0, lambda: eval_61()),
			(cond_m3_0 and cond_m4_0 and cond_m5_0, lambda: eval_62()),
			(cond_m3_0 and cond_m4_0 and cond_m6_0, lambda: eval_62()),
			(cond_m3_0 and cond_m5_0 and cond_m6_0, lambda: eval_61()),
			(cond_m4_0 and cond_m5_0 and cond_m6_0, lambda: eval_61()),
			(cond_m1_0 and cond_m2_0 and cond_m4_m3 and cond_m5_m3 and cond_m6_m3, lambda: eval_14()),
			(cond_m1_0 and cond_m3_0 and cond_m4_m2 and cond_m5_m2 and cond_m6_m2, lambda: eval_44()),
			(cond_m1_0 and cond_m3_m2 and cond_m4_0 and cond_m5_m2 and cond_m6_m2, lambda: eval_44()),
			(cond_m1_0 and cond_m3_m2 and cond_m4_m2 and cond_m5_0 and cond_m6_m2, lambda: eval_45()),
			(cond_m1_0 and cond_m3_m2 and cond_m4_m2 and cond_m5_m2 and cond_m6_0, lambda: eval_45()),
			(cond_m2_0 and cond_m3_0 and cond_m4_m1 and cond_m5_m1 and cond_m6_m1, lambda: eval_44()),
			(cond_m2_0 and cond_m3_m1 and cond_m4_0 and cond_m5_m1 and cond_m6_m1, lambda: eval_44()),
			(cond_m2_0 and cond_m3_m1 and cond_m4_m1 and cond_m5_0 and cond_m6_m1, lambda: eval_45()),
			(cond_m2_0 and cond_m3_m1 and cond_m4_m1 and cond_m5_m1 and cond_m6_0, lambda: eval_45()),
			(cond_m2_m1 and cond_m3_0 and cond_m4_0 and cond_m5_m1 and cond_m6_m1, lambda: eval_15()),
			(cond_m2_m1 and cond_m3_0 and cond_m4_m1 and cond_m5_0 and cond_m6_m1, lambda: eval_16()),
			(cond_m2_m1 and cond_m3_0 and cond_m4_m1 and cond_m5_m1 and cond_m6_0, lambda: eval_16()),
			(cond_m2_m1 and cond_m3_m1 and cond_m4_0 and cond_m5_0 and cond_m6_m1, lambda: eval_16()),
			(cond_m2_m1 and cond_m3_m1 and cond_m4_0 and cond_m5_m1 and cond_m6_0, lambda: eval_16()),
			(cond_m2_m1 and cond_m3_m1 and cond_m4_m1 and cond_m5_0 and cond_m6_0, lambda: eval_17()),
			(cond_m1_0 and cond_m2_0 and cond_m5_m4 and cond_m6_m4, lambda: eval_18()),
			(cond_m1_0 and cond_m3_0 and cond_m5_m4 and cond_m6_m4, lambda: eval_49()),
			(cond_m1_0 and cond_m4_0 and cond_m5_m3 and cond_m6_m3, lambda: eval_49()),
			(cond_m1_0 and cond_m4_m3 and cond_m5_0 and cond_m6_m3, lambda: eval_47()),
			(cond_m1_0 and cond_m4_m3 and cond_m5_m3 and cond_m6_0, lambda: eval_47()),
			(cond_m1_0 and cond_m2_0 and cond_m4_m3 and cond_m6_m5, lambda: eval_48()),
			(cond_m1_0 and cond_m2_0 and cond_m5_m3 and cond_m6_m4, lambda: eval_19()),
			(cond_m1_0 and cond_m2_0 and cond_m5_m4 and cond_m6_m3, lambda: eval_19()),
			(cond_m1_0 and cond_m3_0 and cond_m4_m2 and cond_m6_m5, lambda: eval_61()),
			(cond_m1_0 and cond_m3_0 and cond_m5_m2 and cond_m6_m4, lambda: eval_64()),
			(cond_m1_0 and cond_m3_0 and cond_m5_m4 and cond_m6_m2, lambda: eval_64()),
			(cond_m1_0 and cond_m3_m2 and cond_m4_0 and cond_m6_m5, lambda: eval_61()),
			(cond_m1_0 and cond_m3_m2 and cond_m5_0 and cond_m6_m4, lambda: eval_64()),
			(cond_m1_0 and cond_m3_m2 and cond_m5_m4 and cond_m6_0, lambda: eval_64()),
			(cond_m1_0 and cond_m4_0 and cond_m5_m2 and cond_m6_m3, lambda: eval_64()),
			(cond_m1_0 and cond_m4_0 and cond_m5_m3 and cond_m6_m2, lambda: eval_64()),
			(cond_m1_0 and cond_m4_m2 and cond_m5_0 and cond_m6_m3, lambda: eval_64()),
			(cond_m1_0 and cond_m4_m2 and cond_m5_m3 and cond_m6_0, lambda: eval_64()),
			(cond_m1_0 and cond_m4_m3 and cond_m5_0 and cond_m6_m2, lambda: eval_62()),
			(cond_m1_0 and cond_m4_m3 and cond_m5_m2 and cond_m6_0, lambda: eval_62()),
			(cond_m1_0 and cond_m2_0 and cond_m4_m3 and cond_m5_m3, lambda: eval_20()),
			(cond_m1_0 and cond_m2_0 and cond_m4_m3 and cond_m6_m3, lambda: eval_20()),
			(cond_m1_0 and cond_m2_0 and cond_m5_m3 and cond_m6_m3, lambda: eval_21()),
			(cond_m1_0 and cond_m3_0 and cond_m4_m2 and cond_m5_m2, lambda: eval_64()),
			(cond_m1_0 and cond_m3_0 and cond_m4_m2 and cond_m6_m2, lambda: eval_64()),
			(cond_m1_0 and cond_m3_0 and cond_m5_m2 and cond_m6_m2, lambda: eval_54()),
			(cond_m1_0 and cond_m3_m2 and cond_m4_0 and cond_m5_m2, lambda: eval_64()),
			(cond_m1_0 and cond_m3_m2 and cond_m4_0 and cond_m6_m2, lambda: eval_64()),
			(cond_m1_0 and cond_m3_m2 and cond_m4_m2 and cond_m5_0, lambda: eval_53()),
			(cond_m1_0 and cond_m3_m2 and cond_m4_m2 and cond_m6_0, lambda: eval_53()),
			(cond_m1_0 and cond_m3_m2 and cond_m5_0 and cond_m6_m2, lambda: eval_64()),
			(cond_m1_0 and cond_m3_m2 and cond_m5_m2 and cond_m6_0, lambda: eval_64()),
			(cond_m1_0 and cond_m4_0 and cond_m5_m2 and cond_m6_m2, lambda: eval_54()),
			(cond_m1_0 and cond_m4_m2 and cond_m5_0 and cond_m6_m2, lambda: eval_64()),
			(cond_m1_0 and cond_m4_m2 and cond_m5_m2 and cond_m6_0, lambda: eval_64()),
			(cond_m2_0 and cond_m3_0 and cond_m5_m4 and cond_m6_m4, lambda: eval_49()),
			(cond_m2_0 and cond_m4_0 and cond_m5_m3 and cond_m6_m3, lambda: eval_49()),
			(cond_m2_0 and cond_m4_m3 and cond_m5_0 and cond_m6_m3, lambda: eval_47()),
			(cond_m2_0 and cond_m4_m3 and cond_m5_m3 and cond_m6_0, lambda: eval_47()),
			(cond_m3_0 and cond_m4_0 and cond_m5_m2 and cond_m6_m2, lambda: eval_22()),
			(cond_m3_0 and cond_m4_m2 and cond_m5_0 and cond_m6_m2, lambda: eval_64()),
			(cond_m3_0 and cond_m4_m2 and cond_m5_m2 and cond_m6_0, lambda: eval_64()),
			(cond_m3_m2 and cond_m4_0 and cond_m5_0 and cond_m6_m2, lambda: eval_64()),
			(cond_m3_m2 and cond_m4_0 and cond_m5_m2 and cond_m6_0, lambda: eval_64()),
			(cond_m3_m2 and cond_m4_m2 and cond_m5_0 and cond_m6_0, lambda: eval_23()),
			(cond_m2_0 and cond_m3_0 and cond_m4_m1 and cond_m6_m5, lambda: eval_61()),
			(cond_m2_0 and cond_m3_0 and cond_m5_m1 and cond_m6_m4, lambda: eval_64()),
			(cond_m2_0 and cond_m3_0 and cond_m5_m4 and cond_m6_m1, lambda: eval_64()),
			(cond_m2_0 and cond_m3_m1 and cond_m4_0 and cond_m6_m5, lambda: eval_61()),
			(cond_m2_0 and cond_m3_m1 and cond_m5_0 and cond_m6_m4, lambda: eval_64()),
			(cond_m2_0 and cond_m3_m1 and cond_m5_m4 and cond_m6_0, lambda: eval_64()),
			(cond_m2_0 and cond_m4_0 and cond_m5_m1 and cond_m6_m3, lambda: eval_64()),
			(cond_m2_0 and cond_m4_0 and cond_m5_m3 and cond_m6_m1, lambda: eval_64()),
			(cond_m2_0 and cond_m4_m1 and cond_m5_0 and cond_m6_m3, lambda: eval_64()),
			(cond_m2_0 and cond_m4_m1 and cond_m5_m3 and cond_m6_0, lambda: eval_64()),
			(cond_m2_0 and cond_m4_m3 and cond_m5_0 and cond_m6_m1, lambda: eval_62()),
			(cond_m2_0 and cond_m4_m3 and cond_m5_m1 and cond_m6_0, lambda: eval_62()),
			(cond_m2_m1 and cond_m3_0 and cond_m4_0 and cond_m6_m5, lambda: eval_48()),
			(cond_m2_m1 and cond_m3_0 and cond_m5_0 and cond_m6_m4, lambda: eval_63()),
			(cond_m2_m1 and cond_m3_0 and cond_m5_m4 and cond_m6_0, lambda: eval_63()),
			(cond_m2_m1 and cond_m4_0 and cond_m5_0 and cond_m6_m3, lambda: eval_63()),
			(cond_m2_m1 and cond_m4_0 and cond_m5_m3 and cond_m6_0, lambda: eval_63()),
			(cond_m2_m1 and cond_m4_m3 and cond_m5_0 and cond_m6_0, lambda: eval_48()),
			(cond_m3_0 and cond_m4_0 and cond_m5_m1 and cond_m6_m2, lambda: eval_24()),
			(cond_m3_0 and cond_m4_0 and cond_m5_m2 and cond_m6_m1, lambda: eval_24()),
			(cond_m3_0 and cond_m4_m1 and cond_m5_0 and cond_m6_m2, lambda: eval_64()),
			(cond_m3_0 and cond_m4_m1 and cond_m5_m2 and cond_m6_0, lambda: eval_64()),
			(cond_m3_0 and cond_m4_m2 and cond_m5_0 and cond_m6_m1, lambda: eval_64()),
			(cond_m3_0 and cond_m4_m2 and cond_m5_m1 and cond_m6_0, lambda: eval_64()),
			(cond_m3_m1 and cond_m4_0 and cond_m5_0 and cond_m6_m2, lambda: eval_64()),
			(cond_m3_m1 and cond_m4_0 and cond_m5_m2 and cond_m6_0, lambda: eval_64()),
			(cond_m3_m1 and cond_m4_m2 and cond_m5_0 and cond_m6_0, lambda: eval_25()),
			(cond_m3_m2 and cond_m4_0 and cond_m5_0 and cond_m6_m1, lambda: eval_64()),
			(cond_m3_m2 and cond_m4_0 and cond_m5_m1 and cond_m6_0, lambda: eval_64()),
			(cond_m3_m2 and cond_m4_m1 and cond_m5_0 and cond_m6_0, lambda: eval_25()),
			(cond_m2_0 and cond_m3_0 and cond_m4_m1 and cond_m5_m1, lambda: eval_64()),
			(cond_m2_0 and cond_m3_0 and cond_m4_m1 and cond_m6_m1, lambda: eval_64()),
			(cond_m2_0 and cond_m3_0 and cond_m5_m1 and cond_m6_m1, lambda: eval_54()),
			(cond_m2_0 and cond_m3_m1 and cond_m4_0 and cond_m5_m1, lambda: eval_64()),
			(cond_m2_0 and cond_m3_m1 and cond_m4_0 and cond_m6_m1, lambda: eval_64()),
			(cond_m2_0 and cond_m3_m1 and cond_m4_m1 and cond_m5_0, lambda: eval_53()),
			(cond_m2_0 and cond_m3_m1 and cond_m4_m1 and cond_m6_0, lambda: eval_53()),
			(cond_m2_0 and cond_m3_m1 and cond_m5_0 and cond_m6_m1, lambda: eval_64()),
			(cond_m2_0 and cond_m3_m1 and cond_m5_m1 and cond_m6_0, lambda: eval_64()),
			(cond_m2_0 and cond_m4_0 and cond_m5_m1 and cond_m6_m1, lambda: eval_54()),
			(cond_m2_0 and cond_m4_m1 and cond_m5_0 and cond_m6_m1, lambda: eval_64()),
			(cond_m2_0 and cond_m4_m1 and cond_m5_m1 and cond_m6_0, lambda: eval_64()),
			(cond_m2_m1 and cond_m3_0 and cond_m4_0 and cond_m5_m1, lambda: eval_26()),
			(cond_m2_m1 and cond_m3_0 and cond_m4_0 and cond_m6_m1, lambda: eval_26()),
			(cond_m2_m1 and cond_m3_0 and cond_m4_m1 and cond_m5_0, lambda: eval_39()),
			(cond_m2_m1 and cond_m3_0 and cond_m4_m1 and cond_m6_0, lambda: eval_39()),
			(cond_m2_m1 and cond_m3_0 and cond_m5_0 and cond_m6_m1, lambda: eval_41()),
			(cond_m2_m1 and cond_m3_0 and cond_m5_m1 and cond_m6_0, lambda: eval_41()),
			(cond_m2_m1 and cond_m3_m1 and cond_m4_0 and cond_m5_0, lambda: eval_39()),
			(cond_m2_m1 and cond_m3_m1 and cond_m4_0 and cond_m6_0, lambda: eval_39()),
			(cond_m2_m1 and cond_m3_m1 and cond_m5_0 and cond_m6_0, lambda: eval_27()),
			(cond_m2_m1 and cond_m4_0 and cond_m5_0 and cond_m6_m1, lambda: eval_41()),
			(cond_m2_m1 and cond_m4_0 and cond_m5_m1 and cond_m6_0, lambda: eval_41()),
			(cond_m2_m1 and cond_m4_m1 and cond_m5_0 and cond_m6_0, lambda: eval_27()),
			(cond_m3_0 and cond_m4_0 and cond_m5_m1 and cond_m6_m1, lambda: eval_28()),
			(cond_m3_0 and cond_m4_m1 and cond_m5_0 and cond_m6_m1, lambda: eval_64()),
			(cond_m3_0 and cond_m4_m1 and cond_m5_m1 and cond_m6_0, lambda: eval_64()),
			(cond_m3_m1 and cond_m4_0 and cond_m5_0 and cond_m6_m1, lambda: eval_64()),
			(cond_m3_m1 and cond_m4_0 and cond_m5_m1 and cond_m6_0, lambda: eval_64()),
			(cond_m3_m1 and cond_m4_m1 and cond_m5_0 and cond_m6_0, lambda: eval_29()),
			(cond_m1_0 and cond_m2_0 and cond_m6_m5, lambda: eval_55()),
			(cond_m1_0 and cond_m3_0 and cond_m6_m5, lambda: eval_61()),
			(cond_m1_0 and cond_m4_0 and cond_m6_m5, lambda: eval_61()),
			(cond_m1_0 and cond_m5_0 and cond_m6_m4, lambda: eval_64()),
			(cond_m1_0 and cond_m5_m4 and cond_m6_0, lambda: eval_64()),
			(cond_m1_0 and cond_m2_0 and cond_m5_m4, lambda: eval_30()),
			(cond_m1_0 and cond_m2_0 and cond_m6_m4, lambda: eval_30()),
			(cond_m1_0 and cond_m3_0 and cond_m5_m4, lambda: eval_64()),
			(cond_m1_0 and cond_m3_0 and cond_m6_m4, lambda: eval_64()),
			(cond_m1_0 and cond_m4_0 and cond_m5_m3, lambda: eval_64()),
			(cond_m1_0 and cond_m4_0 and cond_m6_m3, lambda: eval_64()),
			(cond_m1_0 and cond_m4_m3 and cond_m5_0, lambda: eval_62()),
			(cond_m1_0 and cond_m4_m3 and cond_m6_0, lambda: eval_62()),
			(cond_m1_0 and cond_m5_0 and cond_m6_m3, lambda: eval_64()),
			(cond_m1_0 and cond_m5_m3 and cond_m6_0, lambda: eval_64()),
			(cond_m1_0 and cond_m2_0 and cond_m4_m3, lambda: eval_56()),
			(cond_m1_0 and cond_m2_0 and cond_m5_m3, lambda: eval_31()),
			(cond_m1_0 and cond_m2_0 and cond_m6_m3, lambda: eval_31()),
			(cond_m1_0 and cond_m3_0 and cond_m4_m2, lambda: eval_64()),
			(cond_m1_0 and cond_m3_0 and cond_m5_m2, lambda: eval_64()),
			(cond_m1_0 and cond_m3_0 and cond_m6_m2, lambda: eval_64()),
			(cond_m1_0 and cond_m3_m2 and cond_m4_0, lambda: eval_64()),
			(cond_m1_0 and cond_m3_m2 and cond_m5_0, lambda: eval_64()),
			(cond_m1_0 and cond_m3_m2 and cond_m6_0, lambda: eval_64()),
			(cond_m1_0 and cond_m4_0 and cond_m5_m2, lambda: eval_64()),
			(cond_m1_0 and cond_m4_0 and cond_m6_m2, lambda: eval_64()),
			(cond_m1_0 and cond_m4_m2 and cond_m5_0, lambda: eval_64()),
			(cond_m1_0 and cond_m4_m2 and cond_m6_0, lambda: eval_64()),
			(cond_m1_0 and cond_m5_0 and cond_m6_m2, lambda: eval_64()),
			(cond_m1_0 and cond_m5_m2 and cond_m6_0, lambda: eval_64()),
			(cond_m2_0 and cond_m3_0 and cond_m6_m5, lambda: eval_61()),
			(cond_m2_0 and cond_m4_0 and cond_m6_m5, lambda: eval_61()),
			(cond_m2_0 and cond_m5_0 and cond_m6_m4, lambda: eval_64()),
			(cond_m2_0 and cond_m5_m4 and cond_m6_0, lambda: eval_64()),
			(cond_m2_0 and cond_m3_0 and cond_m5_m4, lambda: eval_64()),
			(cond_m2_0 and cond_m3_0 and cond_m6_m4, lambda: eval_64()),
			(cond_m2_0 and cond_m4_0 and cond_m5_m3, lambda: eval_64()),
			(cond_m2_0 and cond_m4_0 and cond_m6_m3, lambda: eval_64()),
			(cond_m2_0 and cond_m4_m3 and cond_m5_0, lambda: eval_62()),
			(cond_m2_0 and cond_m4_m3 and cond_m6_0, lambda: eval_62()),
			(cond_m2_0 and cond_m5_0 and cond_m6_m3, lambda: eval_64()),
			(cond_m2_0 and cond_m5_m3 and cond_m6_0, lambda: eval_64()),
			(cond_m3_0 and cond_m4_0 and cond_m6_m5, lambda: eval_50()),
			(cond_m3_0 and cond_m5_0 and cond_m6_m4, lambda: eval_64()),
			(cond_m3_0 and cond_m5_m4 and cond_m6_0, lambda: eval_64()),
			(cond_m4_0 and cond_m5_0 and cond_m6_m3, lambda: eval_64()),
			(cond_m4_0 and cond_m5_m3 and cond_m6_0, lambda: eval_64()),
			(cond_m4_m3 and cond_m5_0 and cond_m6_0, lambda: eval_50()),
			(cond_m3_0 and cond_m4_0 and cond_m5_m2, lambda: eval_32()),
			(cond_m3_0 and cond_m4_0 and cond_m6_m2, lambda: eval_32()),
			(cond_m3_0 and cond_m4_m2 and cond_m5_0, lambda: eval_64()),
			(cond_m3_0 and cond_m4_m2 and cond_m6_0, lambda: eval_64()),
			(cond_m3_0 and cond_m5_0 and cond_m6_m2, lambda: eval_64()),
			(cond_m3_0 and cond_m5_m2 and cond_m6_0, lambda: eval_64()),
			(cond_m3_m2 and cond_m4_0 and cond_m5_0, lambda: eval_64()),
			(cond_m3_m2 and cond_m4_0 and cond_m6_0, lambda: eval_64()),
			(cond_m3_m2 and cond_m5_0 and cond_m6_0, lambda: eval_33()),
			(cond_m4_0 and cond_m5_0 and cond_m6_m2, lambda: eval_64()),
			(cond_m4_0 and cond_m5_m2 and cond_m6_0, lambda: eval_64()),
			(cond_m4_m2 and cond_m5_0 and cond_m6_0, lambda: eval_33()),
			(cond_m2_0 and cond_m3_0 and cond_m4_m1, lambda: eval_64()),
			(cond_m2_0 and cond_m3_0 and cond_m5_m1, lambda: eval_64()),
			(cond_m2_0 and cond_m3_0 and cond_m6_m1, lambda: eval_64()),
			(cond_m2_0 and cond_m3_m1 and cond_m4_0, lambda: eval_64()),
			(cond_m2_0 and cond_m3_m1 and cond_m5_0, lambda: eval_64()),
			(cond_m2_0 and cond_m3_m1 and cond_m6_0, lambda: eval_64()),
			(cond_m2_0 and cond_m4_0 and cond_m5_m1, lambda: eval_64()),
			(cond_m2_0 and cond_m4_0 and cond_m6_m1, lambda: eval_64()),
			(cond_m2_0 and cond_m4_m1 and cond_m5_0, lambda: eval_64()),
			(cond_m2_0 and cond_m4_m1 and cond_m6_0, lambda: eval_64()),
			(cond_m2_0 and cond_m5_0 and cond_m6_m1, lambda: eval_64()),
			(cond_m2_0 and cond_m5_m1 and cond_m6_0, lambda: eval_64()),
			(cond_m2_m1 and cond_m3_0 and cond_m4_0, lambda: eval_56()),
			(cond_m2_m1 and cond_m3_0 and cond_m5_0, lambda: eval_63()),
			(cond_m2_m1 and cond_m3_0 and cond_m6_0, lambda: eval_63()),
			(cond_m2_m1 and cond_m4_0 and cond_m5_0, lambda: eval_63()),
			(cond_m2_m1 and cond_m4_0 and cond_m6_0, lambda: eval_63()),
			(cond_m3_0 and cond_m4_0 and cond_m5_m1, lambda: eval_34()),
			(cond_m3_0 and cond_m4_0 and cond_m6_m1, lambda: eval_34()),
			(cond_m3_0 and cond_m4_m1 and cond_m5_0, lambda: eval_64()),
			(cond_m3_0 and cond_m4_m1 and cond_m6_0, lambda: eval_64()),
			(cond_m3_0 and cond_m5_0 and cond_m6_m1, lambda: eval_64()),
			(cond_m3_0 and cond_m5_m1 and cond_m6_0, lambda: eval_64()),
			(cond_m3_m1 and cond_m4_0 and cond_m5_0, lambda: eval_64()),
			(cond_m3_m1 and cond_m4_0 and cond_m6_0, lambda: eval_64()),
			(cond_m2_m1 and cond_m5_0 and cond_m6_0, lambda: eval_55()),
			(cond_m3_m1 and cond_m5_0 and cond_m6_0, lambda: eval_35()),
			(cond_m4_0 and cond_m5_0 and cond_m6_m1, lambda: eval_64()),
			(cond_m4_0 and cond_m5_m1 and cond_m6_0, lambda: eval_64()),
			(cond_m4_m1 and cond_m5_0 and cond_m6_0, lambda: eval_35()),
			(cond_m1_0 and cond_m2_0, lambda: eval_63()),
			(cond_m1_0 and cond_m3_0, lambda: eval_64()),
			(cond_m1_0 and cond_m4_0, lambda: eval_64()),
			(cond_m1_0 and cond_m5_0, lambda: eval_64()),
			(cond_m1_0 and cond_m6_0, lambda: eval_64()),
			(cond_m2_0 and cond_m3_0, lambda: eval_64()),
			(cond_m2_0 and cond_m4_0, lambda: eval_64()),
			(cond_m2_0 and cond_m5_0, lambda: eval_64()),
			(cond_m2_0 and cond_m6_0, lambda: eval_64()),
			(cond_m3_0 and cond_m4_0, lambda: eval_62()),
			(cond_m3_0 and cond_m5_0, lambda: eval_64()),
			(cond_m3_0 and cond_m6_0, lambda: eval_64()),
			(cond_m4_0 and cond_m5_0, lambda: eval_64()),
			(cond_m4_0 and cond_m6_0, lambda: eval_64()),
			(cond_m5_0 and cond_m6_0, lambda: eval_61()),
			(cond_m1_0 and cond_m3_m2 and cond_m4_m2 and cond_m5_m2 and cond_m6_m2, lambda: eval_36()),
			(cond_m2_0 and cond_m3_m1 and cond_m4_m1 and cond_m5_m1 and cond_m6_m1, lambda: eval_36()),
			(cond_m2_m1 and cond_m3_0 and cond_m4_m1 and cond_m5_m1 and cond_m6_m1, lambda: eval_38()),
			(cond_m2_m1 and cond_m3_m1 and cond_m4_0 and cond_m5_m1 and cond_m6_m1, lambda: eval_38()),
			(cond_m2_m1 and cond_m3_m1 and cond_m4_m1 and cond_m5_0 and cond_m6_m1, lambda: eval_37()),
			(cond_m2_m1 and cond_m3_m1 and cond_m4_m1 and cond_m5_m1 and cond_m6_0, lambda: eval_37()),
			(cond_m1_0 and cond_m4_m3 and cond_m5_m3 and cond_m6_m3, lambda: eval_36()),
			(cond_m1_0 and cond_m3_m2 and cond_m5_m4 and cond_m6_m4, lambda: eval_49()),
			(cond_m1_0 and cond_m4_m2 and cond_m5_m3 and cond_m6_m3, lambda: eval_49()),
			(cond_m1_0 and cond_m4_m3 and cond_m5_m2 and cond_m6_m3, lambda: eval_46()),
			(cond_m1_0 and cond_m4_m3 and cond_m5_m3 and cond_m6_m2, lambda: eval_46()),
			(cond_m1_0 and cond_m3_m2 and cond_m4_m2 and cond_m6_m5, lambda: eval_50()),
			(cond_m1_0 and cond_m3_m2 and cond_m5_m2 and cond_m6_m4, lambda: eval_64()),
			(cond_m1_0 and cond_m3_m2 and cond_m5_m4 and cond_m6_m2, lambda: eval_64()),
			(cond_m1_0 and cond_m4_m2 and cond_m5_m2 and cond_m6_m3, lambda: eval_64()),
			(cond_m1_0 and cond_m4_m2 and cond_m5_m3 and cond_m6_m2, lambda: eval_64()),
			(cond_m1_0 and cond_m4_m3 and cond_m5_m2 and cond_m6_m2, lambda: eval_50()),
			(cond_m1_0 and cond_m3_m2 and cond_m4_m2 and cond_m5_m2, lambda: eval_51()),
			(cond_m1_0 and cond_m3_m2 and cond_m4_m2 and cond_m6_m2, lambda: eval_51()),
			(cond_m1_0 and cond_m3_m2 and cond_m5_m2 and cond_m6_m2, lambda: eval_52()),
			(cond_m1_0 and cond_m4_m2 and cond_m5_m2 and cond_m6_m2, lambda: eval_52()),
			(cond_m2_0 and cond_m4_m3 and cond_m5_m3 and cond_m6_m3, lambda: eval_36()),
			(cond_m3_0 and cond_m4_m2 and cond_m5_m2 and cond_m6_m2, lambda: eval_54()),
			(cond_m3_m2 and cond_m4_0 and cond_m5_m2 and cond_m6_m2, lambda: eval_54()),
			(cond_m3_m2 and cond_m4_m2 and cond_m5_0 and cond_m6_m2, lambda: eval_53()),
			(cond_m3_m2 and cond_m4_m2 and cond_m5_m2 and cond_m6_0, lambda: eval_53()),
			(cond_m2_0 and cond_m3_m1 and cond_m5_m4 and cond_m6_m4, lambda: eval_49()),
			(cond_m2_0 and cond_m4_m1 and cond_m5_m3 and cond_m6_m3, lambda: eval_49()),
			(cond_m2_0 and cond_m4_m3 and cond_m5_m1 and cond_m6_m3, lambda: eval_46()),
			(cond_m2_0 and cond_m4_m3 and cond_m5_m3 and cond_m6_m1, lambda: eval_46()),
			(cond_m2_m1 and cond_m3_0 and cond_m5_m4 and cond_m6_m4, lambda: eval_55()),
			(cond_m2_m1 and cond_m4_0 and cond_m5_m3 and cond_m6_m3, lambda: eval_55()),
			(cond_m2_m1 and cond_m4_m3 and cond_m5_0 and cond_m6_m3, lambda: eval_56()),
			(cond_m2_m1 and cond_m4_m3 and cond_m5_m3 and cond_m6_0, lambda: eval_56()),
			(cond_m3_0 and cond_m4_m1 and cond_m5_m2 and cond_m6_m2, lambda: eval_54()),
			(cond_m3_0 and cond_m4_m2 and cond_m5_m1 and cond_m6_m2, lambda: eval_64()),
			(cond_m3_0 and cond_m4_m2 and cond_m5_m2 and cond_m6_m1, lambda: eval_64()),
			(cond_m3_m1 and cond_m4_0 and cond_m5_m2 and cond_m6_m2, lambda: eval_54()),
			(cond_m3_m1 and cond_m4_m2 and cond_m5_0 and cond_m6_m2, lambda: eval_64()),
			(cond_m3_m1 and cond_m4_m2 and cond_m5_m2 and cond_m6_0, lambda: eval_64()),
			(cond_m3_m2 and cond_m4_0 and cond_m5_m1 and cond_m6_m2, lambda: eval_64()),
			(cond_m3_m2 and cond_m4_0 and cond_m5_m2 and cond_m6_m1, lambda: eval_64()),
			(cond_m3_m2 and cond_m4_m1 and cond_m5_0 and cond_m6_m2, lambda: eval_64()),
			(cond_m3_m2 and cond_m4_m1 and cond_m5_m2 and cond_m6_0, lambda: eval_64()),
			(cond_m3_m2 and cond_m4_m2 and cond_m5_0 and cond_m6_m1, lambda: eval_53()),
			(cond_m3_m2 and cond_m4_m2 and cond_m5_m1 and cond_m6_0, lambda: eval_53()),
			(cond_m2_0 and cond_m3_m1 and cond_m4_m1 and cond_m6_m5, lambda: eval_50()),
			(cond_m2_0 and cond_m3_m1 and cond_m5_m1 and cond_m6_m4, lambda: eval_64()),
			(cond_m2_0 and cond_m3_m1 and cond_m5_m4 and cond_m6_m1, lambda: eval_64()),
			(cond_m2_0 and cond_m4_m1 and cond_m5_m1 and cond_m6_m3, lambda: eval_64()),
			(cond_m2_0 and cond_m4_m1 and cond_m5_m3 and cond_m6_m1, lambda: eval_64()),
			(cond_m2_0 and cond_m4_m3 and cond_m5_m1 and cond_m6_m1, lambda: eval_50()),
			(cond_m2_m1 and cond_m3_0 and cond_m4_m1 and cond_m6_m5, lambda: eval_55()),
			(cond_m2_m1 and cond_m3_0 and cond_m5_m1 and cond_m6_m4, lambda: eval_58()),
			(cond_m2_m1 and cond_m3_0 and cond_m5_m4 and cond_m6_m1, lambda: eval_58()),
			(cond_m2_m1 and cond_m3_m1 and cond_m4_0 and cond_m6_m5, lambda: eval_55()),
			(cond_m2_m1 and cond_m3_m1 and cond_m5_0 and cond_m6_m4, lambda: eval_57()),
			(cond_m2_m1 and cond_m3_m1 and cond_m5_m4 and cond_m6_0, lambda: eval_57()),
			(cond_m2_m1 and cond_m4_0 and cond_m5_m1 and cond_m6_m3, lambda: eval_58()),
			(cond_m2_m1 and cond_m4_0 and cond_m5_m3 and cond_m6_m1, lambda: eval_58()),
			(cond_m2_m1 and cond_m4_m1 and cond_m5_0 and cond_m6_m3, lambda: eval_57()),
			(cond_m2_m1 and cond_m4_m1 and cond_m5_m3 and cond_m6_0, lambda: eval_57()),
			(cond_m2_m1 and cond_m4_m3 and cond_m5_0 and cond_m6_m1, lambda: eval_56()),
			(cond_m2_m1 and cond_m4_m3 and cond_m5_m1 and cond_m6_0, lambda: eval_56()),
			(cond_m3_0 and cond_m4_m1 and cond_m5_m1 and cond_m6_m2, lambda: eval_64()),
			(cond_m3_0 and cond_m4_m1 and cond_m5_m2 and cond_m6_m1, lambda: eval_64()),
			(cond_m3_0 and cond_m4_m2 and cond_m5_m1 and cond_m6_m1, lambda: eval_60()),
			(cond_m3_m1 and cond_m4_0 and cond_m5_m1 and cond_m6_m2, lambda: eval_64()),
			(cond_m3_m1 and cond_m4_0 and cond_m5_m2 and cond_m6_m1, lambda: eval_64()),
			(cond_m3_m1 and cond_m4_m1 and cond_m5_0 and cond_m6_m2, lambda: eval_59()),
			(cond_m3_m1 and cond_m4_m1 and cond_m5_m2 and cond_m6_0, lambda: eval_59()),
			(cond_m3_m1 and cond_m4_m2 and cond_m5_0 and cond_m6_m1, lambda: eval_64()),
			(cond_m3_m1 and cond_m4_m2 and cond_m5_m1 and cond_m6_0, lambda: eval_64()),
			(cond_m3_m2 and cond_m4_0 and cond_m5_m1 and cond_m6_m1, lambda: eval_60()),
			(cond_m3_m2 and cond_m4_m1 and cond_m5_0 and cond_m6_m1, lambda: eval_64()),
			(cond_m3_m2 and cond_m4_m1 and cond_m5_m1 and cond_m6_0, lambda: eval_64()),
			(cond_m2_0 and cond_m3_m1 and cond_m4_m1 and cond_m5_m1, lambda: eval_51()),
			(cond_m2_0 and cond_m3_m1 and cond_m4_m1 and cond_m6_m1, lambda: eval_51()),
			(cond_m2_0 and cond_m3_m1 and cond_m5_m1 and cond_m6_m1, lambda: eval_52()),
			(cond_m2_0 and cond_m4_m1 and cond_m5_m1 and cond_m6_m1, lambda: eval_52()),
			(cond_m2_m1 and cond_m3_0 and cond_m4_m1 and cond_m5_m1, lambda: eval_58()),
			(cond_m2_m1 and cond_m3_0 and cond_m4_m1 and cond_m6_m1, lambda: eval_58()),
			(cond_m2_m1 and cond_m3_0 and cond_m5_m1 and cond_m6_m1, lambda: eval_38()),
			(cond_m2_m1 and cond_m3_m1 and cond_m4_0 and cond_m5_m1, lambda: eval_58()),
			(cond_m2_m1 and cond_m3_m1 and cond_m4_0 and cond_m6_m1, lambda: eval_58()),
			(cond_m2_m1 and cond_m3_m1 and cond_m4_m1 and cond_m5_0, lambda: eval_37()),
			(cond_m2_m1 and cond_m3_m1 and cond_m4_m1 and cond_m6_0, lambda: eval_37()),
			(cond_m2_m1 and cond_m3_m1 and cond_m5_0 and cond_m6_m1, lambda: eval_57()),
			(cond_m2_m1 and cond_m3_m1 and cond_m5_m1 and cond_m6_0, lambda: eval_57()),
			(cond_m2_m1 and cond_m4_0 and cond_m5_m1 and cond_m6_m1, lambda: eval_38()),
			(cond_m2_m1 and cond_m4_m1 and cond_m5_0 and cond_m6_m1, lambda: eval_57()),
			(cond_m2_m1 and cond_m4_m1 and cond_m5_m1 and cond_m6_0, lambda: eval_57()),
			(cond_m3_0 and cond_m4_m1 and cond_m5_m1 and cond_m6_m1, lambda: eval_60()),
			(cond_m3_m1 and cond_m4_0 and cond_m5_m1 and cond_m6_m1, lambda: eval_60()),
			(cond_m3_m1 and cond_m4_m1 and cond_m5_0 and cond_m6_m1, lambda: eval_59()),
			(cond_m3_m1 and cond_m4_m1 and cond_m5_m1 and cond_m6_0, lambda: eval_59()),
			(cond_m1_0 and cond_m5_m4 and cond_m6_m4, lambda: eval_49()),
			(cond_m1_0 and cond_m4_m3 and cond_m6_m5, lambda: eval_50()),
			(cond_m1_0 and cond_m5_m3 and cond_m6_m4, lambda: eval_64()),
			(cond_m1_0 and cond_m5_m4 and cond_m6_m3, lambda: eval_64()),
			(cond_m1_0 and cond_m4_m3 and cond_m5_m3, lambda: eval_51()),
			(cond_m1_0 and cond_m4_m3 and cond_m6_m3, lambda: eval_51()),
			(cond_m1_0 and cond_m5_m3 and cond_m6_m3, lambda: eval_52()),
			(cond_m1_0 and cond_m3_m2 and cond_m6_m5, lambda: eval_61()),
			(cond_m1_0 and cond_m4_m2 and cond_m6_m5, lambda: eval_61()),
			(cond_m1_0 and cond_m5_m2 and cond_m6_m4, lambda: eval_64()),
			(cond_m1_0 and cond_m5_m4 and cond_m6_m2, lambda: eval_64()),
			(cond_m1_0 and cond_m3_m2 and cond_m5_m4, lambda: eval_64()),
			(cond_m1_0 and cond_m3_m2 and cond_m6_m4, lambda: eval_64()),
			(cond_m1_0 and cond_m4_m2 and cond_m5_m3, lambda: eval_64()),
			(cond_m1_0 and cond_m4_m2 and cond_m6_m3, lambda: eval_64()),
			(cond_m1_0 and cond_m4_m3 and cond_m5_m2, lambda: eval_62()),
			(cond_m1_0 and cond_m4_m3 and cond_m6_m2, lambda: eval_62()),
			(cond_m1_0 and cond_m5_m2 and cond_m6_m3, lambda: eval_64()),
			(cond_m1_0 and cond_m5_m3 and cond_m6_m2, lambda: eval_64()),
			(cond_m1_0 and cond_m3_m2 and cond_m4_m2, lambda: eval_62()),
			(cond_m1_0 and cond_m3_m2 and cond_m5_m2, lambda: eval_64()),
			(cond_m1_0 and cond_m3_m2 and cond_m6_m2, lambda: eval_64()),
			(cond_m1_0 and cond_m4_m2 and cond_m5_m2, lambda: eval_64()),
			(cond_m1_0 and cond_m4_m2 and cond_m6_m2, lambda: eval_64()),
			(cond_m1_0 and cond_m5_m2 and cond_m6_m2, lambda: eval_61()),
			(cond_m2_0 and cond_m5_m4 and cond_m6_m4, lambda: eval_49()),
			(cond_m2_0 and cond_m4_m3 and cond_m6_m5, lambda: eval_50()),
			(cond_m2_0 and cond_m5_m3 and cond_m6_m4, lambda: eval_64()),
			(cond_m2_0 and cond_m5_m4 and cond_m6_m3, lambda: eval_64()),
			(cond_m2_0 and cond_m4_m3 and cond_m5_m3, lambda: eval_51()),
			(cond_m2_0 and cond_m4_m3 and cond_m6_m3, lambda: eval_51()),
			(cond_m2_0 and cond_m5_m3 and cond_m6_m3, lambda: eval_52()),
			(cond_m3_0 and cond_m5_m4 and cond_m6_m4, lambda: eval_61()),
			(cond_m4_0 and cond_m5_m3 and cond_m6_m3, lambda: eval_61()),
			(cond_m4_m3 and cond_m5_0 and cond_m6_m3, lambda: eval_62()),
			(cond_m4_m3 and cond_m5_m3 and cond_m6_0, lambda: eval_62()),
			(cond_m3_0 and cond_m4_m2 and cond_m6_m5, lambda: eval_61()),
			(cond_m3_0 and cond_m5_m2 and cond_m6_m4, lambda: eval_64()),
			(cond_m3_0 and cond_m5_m4 and cond_m6_m2, lambda: eval_64()),
			(cond_m3_m2 and cond_m4_0 and cond_m6_m5, lambda: eval_61()),
			(cond_m3_m2 and cond_m5_0 and cond_m6_m4, lambda: eval_64()),
			(cond_m3_m2 and cond_m5_m4 and cond_m6_0, lambda: eval_64()),
			(cond_m4_0 and cond_m5_m2 and cond_m6_m3, lambda: eval_64()),
			(cond_m4_0 and cond_m5_m3 and cond_m6_m2, lambda: eval_64()),
			(cond_m4_m2 and cond_m5_0 and cond_m6_m3, lambda: eval_64()),
			(cond_m4_m2 and cond_m5_m3 and cond_m6_0, lambda: eval_64()),
			(cond_m4_m3 and cond_m5_0 and cond_m6_m2, lambda: eval_62()),
			(cond_m4_m3 and cond_m5_m2 and cond_m6_0, lambda: eval_62()),
			(cond_m3_0 and cond_m4_m2 and cond_m5_m2, lambda: eval_64()),
			(cond_m3_0 and cond_m4_m2 and cond_m6_m2, lambda: eval_64()),
			(cond_m3_0 and cond_m5_m2 and cond_m6_m2, lambda: eval_54()),
			(cond_m3_m2 and cond_m4_0 and cond_m5_m2, lambda: eval_64()),
			(cond_m3_m2 and cond_m4_0 and cond_m6_m2, lambda: eval_64()),
			(cond_m3_m2 and cond_m4_m2 and cond_m5_0, lambda: eval_53()),
			(cond_m3_m2 and cond_m4_m2 and cond_m6_0, lambda: eval_53()),
			(cond_m3_m2 and cond_m5_0 and cond_m6_m2, lambda: eval_64()),
			(cond_m3_m2 and cond_m5_m2 and cond_m6_0, lambda: eval_64()),
			(cond_m4_0 and cond_m5_m2 and cond_m6_m2, lambda: eval_54()),
			(cond_m4_m2 and cond_m5_0 and cond_m6_m2, lambda: eval_64()),
			(cond_m4_m2 and cond_m5_m2 and cond_m6_0, lambda: eval_64()),
			(cond_m2_0 and cond_m3_m1 and cond_m6_m5, lambda: eval_61()),
			(cond_m2_0 and cond_m4_m1 and cond_m6_m5, lambda: eval_61()),
			(cond_m2_0 and cond_m5_m1 and cond_m6_m4, lambda: eval_64()),
			(cond_m2_0 and cond_m5_m4 and cond_m6_m1, lambda: eval_64()),
			(cond_m2_m1 and cond_m3_0 and cond_m6_m5, lambda: eval_55()),
			(cond_m2_0 and cond_m3_m1 and cond_m5_m4, lambda: eval_64()),
			(cond_m2_0 and cond_m3_m1 and cond_m6_m4, lambda: eval_64()),
			(cond_m2_0 and cond_m4_m1 and cond_m5_m3, lambda: eval_64()),
			(cond_m2_0 and cond_m4_m1 and cond_m6_m3, lambda: eval_64()),
			(cond_m2_0 and cond_m4_m3 and cond_m5_m1, lambda: eval_62()),
			(cond_m2_0 and cond_m4_m3 and cond_m6_m1, lambda: eval_62()),
			(cond_m2_0 and cond_m5_m1 and cond_m6_m3, lambda: eval_64()),
			(cond_m2_0 and cond_m5_m3 and cond_m6_m1, lambda: eval_64()),
			(cond_m2_m1 and cond_m3_0 and cond_m5_m4, lambda: eval_63()),
			(cond_m2_m1 and cond_m3_0 and cond_m6_m4, lambda: eval_63()),
			(cond_m2_m1 and cond_m4_0 and cond_m6_m5, lambda: eval_55()),
			(cond_m3_0 and cond_m4_m1 and cond_m6_m5, lambda: eval_61()),
			(cond_m3_0 and cond_m5_m1 and cond_m6_m4, lambda: eval_64()),
			(cond_m3_0 and cond_m5_m4 and cond_m6_m1, lambda: eval_64()),
			(cond_m3_m1 and cond_m4_0 and cond_m6_m5, lambda: eval_61()),
			(cond_m2_m1 and cond_m5_0 and cond_m6_m4, lambda: eval_63()),
			(cond_m2_m1 and cond_m5_m4 and cond_m6_0, lambda: eval_63()),
			(cond_m3_m1 and cond_m5_0 and cond_m6_m4, lambda: eval_64()),
			(cond_m3_m1 and cond_m5_m4 and cond_m6_0, lambda: eval_64()),
			(cond_m4_0 and cond_m5_m1 and cond_m6_m3, lambda: eval_64()),
			(cond_m4_0 and cond_m5_m3 and cond_m6_m1, lambda: eval_64()),
			(cond_m4_m1 and cond_m5_0 and cond_m6_m3, lambda: eval_64()),
			(cond_m4_m1 and cond_m5_m3 and cond_m6_0, lambda: eval_64()),
			(cond_m4_m3 and cond_m5_0 and cond_m6_m1, lambda: eval_62()),
			(cond_m4_m3 and cond_m5_m1 and cond_m6_0, lambda: eval_62()),
			(cond_m2_m1 and cond_m4_0 and cond_m5_m3, lambda: eval_63()),
			(cond_m2_m1 and cond_m4_0 and cond_m6_m3, lambda: eval_63()),
			(cond_m2_m1 and cond_m4_m3 and cond_m5_0, lambda: eval_56()),
			(cond_m3_0 and cond_m4_m1 and cond_m5_m2, lambda: eval_64()),
			(cond_m3_0 and cond_m4_m1 and cond_m6_m2, lambda: eval_64()),
			(cond_m3_0 and cond_m4_m2 and cond_m5_m1, lambda: eval_64()),
			(cond_m3_0 and cond_m4_m2 and cond_m6_m1, lambda: eval_64()),
			(cond_m3_0 and cond_m5_m1 and cond_m6_m2, lambda: eval_64()),
			(cond_m3_0 and cond_m5_m2 and cond_m6_m1, lambda: eval_64()),
			(cond_m3_m1 and cond_m4_0 and cond_m5_m2, lambda: eval_64()),
			(cond_m3_m1 and cond_m4_0 and cond_m6_m2, lambda: eval_64()),
			(cond_m3_m1 and cond_m4_m2 and cond_m5_0, lambda: eval_64()),
			(cond_m3_m2 and cond_m4_0 and cond_m5_m1, lambda: eval_64()),
			(cond_m3_m2 and cond_m4_0 and cond_m6_m1, lambda: eval_64()),
			(cond_m3_m2 and cond_m4_m1 and cond_m5_0, lambda: eval_64()),
			(cond_m2_m1 and cond_m4_m3 and cond_m6_0, lambda: eval_56()),
			(cond_m2_m1 and cond_m5_0 and cond_m6_m3, lambda: eval_63()),
			(cond_m2_m1 and cond_m5_m3 and cond_m6_0, lambda: eval_63()),
			(cond_m3_m1 and cond_m4_m2 and cond_m6_0, lambda: eval_64()),
			(cond_m3_m1 and cond_m5_0 and cond_m6_m2, lambda: eval_64()),
			(cond_m3_m1 and cond_m5_m2 and cond_m6_0, lambda: eval_64()),
			(cond_m3_m2 and cond_m4_m1 and cond_m6_0, lambda: eval_64()),
			(cond_m3_m2 and cond_m5_0 and cond_m6_m1, lambda: eval_64()),
			(cond_m3_m2 and cond_m5_m1 and cond_m6_0, lambda: eval_64()),
			(cond_m4_0 and cond_m5_m1 and cond_m6_m2, lambda: eval_64()),
			(cond_m4_0 and cond_m5_m2 and cond_m6_m1, lambda: eval_64()),
			(cond_m4_m1 and cond_m5_0 and cond_m6_m2, lambda: eval_64()),
			(cond_m4_m1 and cond_m5_m2 and cond_m6_0, lambda: eval_64()),
			(cond_m4_m2 and cond_m5_0 and cond_m6_m1, lambda: eval_64()),
			(cond_m4_m2 and cond_m5_m1 and cond_m6_0, lambda: eval_64()),
			(cond_m2_0 and cond_m3_m1 and cond_m4_m1, lambda: eval_62()),
			(cond_m2_0 and cond_m3_m1 and cond_m5_m1, lambda: eval_64()),
			(cond_m2_0 and cond_m3_m1 and cond_m6_m1, lambda: eval_64()),
			(cond_m2_0 and cond_m4_m1 and cond_m5_m1, lambda: eval_64()),
			(cond_m2_0 and cond_m4_m1 and cond_m6_m1, lambda: eval_64()),
			(cond_m2_0 and cond_m5_m1 and cond_m6_m1, lambda: eval_61()),
			(cond_m2_m1 and cond_m3_0 and cond_m4_m1, lambda: eval_63()),
			(cond_m2_m1 and cond_m3_0 and cond_m5_m1, lambda: eval_58()),
			(cond_m2_m1 and cond_m3_0 and cond_m6_m1, lambda: eval_58()),
			(cond_m2_m1 and cond_m3_m1 and cond_m4_0, lambda: eval_63()),
			(cond_m2_m1 and cond_m3_m1 and cond_m5_0, lambda: eval_57()),
			(cond_m2_m1 and cond_m4_0 and cond_m5_m1, lambda: eval_58()),
			(cond_m2_m1 and cond_m4_0 and cond_m6_m1, lambda: eval_58()),
			(cond_m2_m1 and cond_m4_m1 and cond_m5_0, lambda: eval_57()),
			(cond_m3_0 and cond_m4_m1 and cond_m5_m1, lambda: eval_64()),
			(cond_m3_0 and cond_m4_m1 and cond_m6_m1, lambda: eval_64()),
			(cond_m3_0 and cond_m5_m1 and cond_m6_m1, lambda: eval_60()),
			(cond_m3_m1 and cond_m4_0 and cond_m5_m1, lambda: eval_64()),
			(cond_m3_m1 and cond_m4_0 and cond_m6_m1, lambda: eval_64()),
			(cond_m3_m1 and cond_m4_m1 and cond_m5_0, lambda: eval_59()),
			(cond_m2_m1 and cond_m3_m1 and cond_m6_0, lambda: eval_57()),
			(cond_m2_m1 and cond_m4_m1 and cond_m6_0, lambda: eval_57()),
			(cond_m2_m1 and cond_m5_0 and cond_m6_m1, lambda: eval_63()),
			(cond_m2_m1 and cond_m5_m1 and cond_m6_0, lambda: eval_63()),
			(cond_m3_m1 and cond_m4_m1 and cond_m6_0, lambda: eval_59()),
			(cond_m3_m1 and cond_m5_0 and cond_m6_m1, lambda: eval_64()),
			(cond_m3_m1 and cond_m5_m1 and cond_m6_0, lambda: eval_64()),
			(cond_m4_0 and cond_m5_m1 and cond_m6_m1, lambda: eval_60()),
			(cond_m4_m1 and cond_m5_0 and cond_m6_m1, lambda: eval_64()),
			(cond_m4_m1 and cond_m5_m1 and cond_m6_0, lambda: eval_64()),
			(cond_m1_0 and cond_m6_m5, lambda: eval_61()),
			(cond_m1_0 and cond_m5_m4, lambda: eval_64()),
			(cond_m1_0 and cond_m6_m4, lambda: eval_64()),
			(cond_m1_0 and cond_m4_m3, lambda: eval_62()),
			(cond_m1_0 and cond_m5_m3, lambda: eval_64()),
			(cond_m1_0 and cond_m6_m3, lambda: eval_64()),
			(cond_m1_0 and cond_m3_m2, lambda: eval_64()),
			(cond_m1_0 and cond_m4_m2, lambda: eval_64()),
			(cond_m1_0 and cond_m5_m2, lambda: eval_64()),
			(cond_m1_0 and cond_m6_m2, lambda: eval_64()),
			(cond_m2_0 and cond_m6_m5, lambda: eval_61()),
			(cond_m2_0 and cond_m5_m4, lambda: eval_64()),
			(cond_m2_0 and cond_m6_m4, lambda: eval_64()),
			(cond_m2_0 and cond_m4_m3, lambda: eval_62()),
			(cond_m2_0 and cond_m5_m3, lambda: eval_64()),
			(cond_m2_0 and cond_m6_m3, lambda: eval_64()),
			(cond_m3_0 and cond_m6_m5, lambda: eval_61()),
			(cond_m3_0 and cond_m5_m4, lambda: eval_64()),
			(cond_m3_0 and cond_m6_m4, lambda: eval_64()),
			(cond_m4_0 and cond_m6_m5, lambda: eval_61()),
			(cond_m5_0 and cond_m6_m4, lambda: eval_64()),
			(cond_m5_m4 and cond_m6_0, lambda: eval_64()),
			(cond_m4_0 and cond_m5_m3, lambda: eval_64()),
			(cond_m4_0 and cond_m6_m3, lambda: eval_64()),
			(cond_m4_m3 and cond_m5_0, lambda: eval_62()),
			(cond_m4_m3 and cond_m6_0, lambda: eval_62()),
			(cond_m5_0 and cond_m6_m3, lambda: eval_64()),
			(cond_m5_m3 and cond_m6_0, lambda: eval_64()),
			(cond_m3_0 and cond_m4_m2, lambda: eval_64()),
			(cond_m3_0 and cond_m5_m2, lambda: eval_64()),
			(cond_m3_0 and cond_m6_m2, lambda: eval_64()),
			(cond_m3_m2 and cond_m4_0, lambda: eval_64()),
			(cond_m3_m2 and cond_m5_0, lambda: eval_64()),
			(cond_m4_0 and cond_m5_m2, lambda: eval_64()),
			(cond_m4_0 and cond_m6_m2, lambda: eval_64()),
			(cond_m4_m2 and cond_m5_0, lambda: eval_64()),
			(cond_m3_m2 and cond_m6_0, lambda: eval_64()),
			(cond_m4_m2 and cond_m6_0, lambda: eval_64()),
			(cond_m5_0 and cond_m6_m2, lambda: eval_64()),
			(cond_m5_m2 and cond_m6_0, lambda: eval_64()),
			(cond_m2_0 and cond_m3_m1, lambda: eval_64()),
			(cond_m2_0 and cond_m4_m1, lambda: eval_64()),
			(cond_m2_0 and cond_m5_m1, lambda: eval_64()),
			(cond_m2_0 and cond_m6_m1, lambda: eval_64()),
			(cond_m2_m1 and cond_m3_0, lambda: eval_63()),
			(cond_m2_m1 and cond_m4_0, lambda: eval_63()),
			(cond_m3_0 and cond_m4_m1, lambda: eval_64()),
			(cond_m3_0 and cond_m5_m1, lambda: eval_64()),
			(cond_m3_0 and cond_m6_m1, lambda: eval_64()),
			(cond_m3_m1 and cond_m4_0, lambda: eval_64()),
			(cond_m2_m1 and cond_m5_0, lambda: eval_63()),
			(cond_m3_m1 and cond_m5_0, lambda: eval_64()),
			(cond_m4_0 and cond_m5_m1, lambda: eval_64()),
			(cond_m4_0 and cond_m6_m1, lambda: eval_64()),
			(cond_m4_m1 and cond_m5_0, lambda: eval_64()),
			(cond_m2_m1 and cond_m6_0, lambda: eval_63()),
			(cond_m3_m1 and cond_m6_0, lambda: eval_64()),
			(cond_m4_m1 and cond_m6_0, lambda: eval_64()),
			(cond_m5_0 and cond_m6_m1, lambda: eval_64()),
			(cond_m5_m1 and cond_m6_0, lambda: eval_64()),
			(cond_m1_0, lambda: eval_64()),
			(cond_m2_0, lambda: eval_64()),
			(cond_m3_0, lambda: eval_64()),
			(cond_m4_0, lambda: eval_64()),
			(cond_m5_0, lambda: eval_64()),
			(cond_m6_0, lambda: eval_64()),
			(cond_m2_m1 and cond_m3_m1 and cond_m4_m1 and cond_m5_m1 and cond_m6_m1, lambda: eval_48()),
			(cond_m3_m2 and cond_m4_m2 and cond_m5_m2 and cond_m6_m2, lambda: eval_50()),
			(cond_m2_m1 and cond_m4_m3 and cond_m5_m3 and cond_m6_m3, lambda: eval_48()),
			(cond_m3_m1 and cond_m4_m2 and cond_m5_m2 and cond_m6_m2, lambda: eval_61()),
			(cond_m3_m2 and cond_m4_m1 and cond_m5_m2 and cond_m6_m2, lambda: eval_61()),
			(cond_m3_m2 and cond_m4_m2 and cond_m5_m1 and cond_m6_m2, lambda: eval_62()),
			(cond_m3_m2 and cond_m4_m2 and cond_m5_m2 and cond_m6_m1, lambda: eval_62()),
			(cond_m2_m1 and cond_m3_m1 and cond_m5_m4 and cond_m6_m4, lambda: eval_55()),
			(cond_m2_m1 and cond_m4_m1 and cond_m5_m3 and cond_m6_m3, lambda: eval_55()),
			(cond_m2_m1 and cond_m4_m3 and cond_m5_m1 and cond_m6_m3, lambda: eval_56()),
			(cond_m2_m1 and cond_m4_m3 and cond_m5_m3 and cond_m6_m1, lambda: eval_56()),
			(cond_m3_m1 and cond_m4_m1 and cond_m5_m2 and cond_m6_m2, lambda: eval_50()),
			(cond_m3_m1 and cond_m4_m2 and cond_m5_m1 and cond_m6_m2, lambda: eval_64()),
			(cond_m3_m1 and cond_m4_m2 and cond_m5_m2 and cond_m6_m1, lambda: eval_64()),
			(cond_m3_m2 and cond_m4_m1 and cond_m5_m1 and cond_m6_m2, lambda: eval_64()),
			(cond_m3_m2 and cond_m4_m1 and cond_m5_m2 and cond_m6_m1, lambda: eval_64()),
			(cond_m3_m2 and cond_m4_m2 and cond_m5_m1 and cond_m6_m1, lambda: eval_50()),
			(cond_m2_m1 and cond_m3_m1 and cond_m4_m1 and cond_m6_m5, lambda: eval_48()),
			(cond_m2_m1 and cond_m3_m1 and cond_m5_m1 and cond_m6_m4, lambda: eval_63()),
			(cond_m2_m1 and cond_m3_m1 and cond_m5_m4 and cond_m6_m1, lambda: eval_63()),
			(cond_m2_m1 and cond_m4_m1 and cond_m5_m1 and cond_m6_m3, lambda: eval_63()),
			(cond_m2_m1 and cond_m4_m1 and cond_m5_m3 and cond_m6_m1, lambda: eval_63()),
			(cond_m2_m1 and cond_m4_m3 and cond_m5_m1 and cond_m6_m1, lambda: eval_48()),
			(cond_m3_m1 and cond_m4_m1 and cond_m5_m1 and cond_m6_m2, lambda: eval_62()),
			(cond_m3_m1 and cond_m4_m1 and cond_m5_m2 and cond_m6_m1, lambda: eval_62()),
			(cond_m3_m1 and cond_m4_m2 and cond_m5_m1 and cond_m6_m1, lambda: eval_61()),
			(cond_m3_m2 and cond_m4_m1 and cond_m5_m1 and cond_m6_m1, lambda: eval_61()),
			(cond_m2_m1 and cond_m3_m1 and cond_m4_m1 and cond_m5_m1, lambda: eval_56()),
			(cond_m2_m1 and cond_m3_m1 and cond_m4_m1 and cond_m6_m1, lambda: eval_56()),
			(cond_m2_m1 and cond_m3_m1 and cond_m5_m1 and cond_m6_m1, lambda: eval_55()),
			(cond_m2_m1 and cond_m4_m1 and cond_m5_m1 and cond_m6_m1, lambda: eval_55()),
			(cond_m3_m1 and cond_m4_m1 and cond_m5_m1 and cond_m6_m1, lambda: eval_50()),
			(cond_m4_m3 and cond_m5_m3 and cond_m6_m3, lambda: eval_50()),
			(cond_m3_m2 and cond_m5_m4 and cond_m6_m4, lambda: eval_61()),
			(cond_m4_m2 and cond_m5_m3 and cond_m6_m3, lambda: eval_61()),
			(cond_m4_m3 and cond_m5_m2 and cond_m6_m3, lambda: eval_62()),
			(cond_m4_m3 and cond_m5_m3 and cond_m6_m2, lambda: eval_62()),
			(cond_m3_m2 and cond_m4_m2 and cond_m6_m5, lambda: eval_50()),
			(cond_m3_m2 and cond_m5_m2 and cond_m6_m4, lambda: eval_64()),
			(cond_m3_m2 and cond_m5_m4 and cond_m6_m2, lambda: eval_64()),
			(cond_m4_m2 and cond_m5_m2 and cond_m6_m3, lambda: eval_64()),
			(cond_m4_m2 and cond_m5_m3 and cond_m6_m2, lambda: eval_64()),
			(cond_m4_m3 and cond_m5_m2 and cond_m6_m2, lambda: eval_50()),
			(cond_m3_m2 and cond_m4_m2 and cond_m5_m2, lambda: eval_62()),
			(cond_m3_m2 and cond_m4_m2 and cond_m6_m2, lambda: eval_62()),
			(cond_m3_m2 and cond_m5_m2 and cond_m6_m2, lambda: eval_61()),
			(cond_m4_m2 and cond_m5_m2 and cond_m6_m2, lambda: eval_61()),
			(cond_m2_m1 and cond_m5_m4 and cond_m6_m4, lambda: eval_55()),
			(cond_m3_m1 and cond_m5_m4 and cond_m6_m4, lambda: eval_61()),
			(cond_m4_m1 and cond_m5_m3 and cond_m6_m3, lambda: eval_61()),
			(cond_m4_m3 and cond_m5_m1 and cond_m6_m3, lambda: eval_62()),
			(cond_m4_m3 and cond_m5_m3 and cond_m6_m1, lambda: eval_62()),
			(cond_m2_m1 and cond_m4_m3 and cond_m6_m5, lambda: eval_48()),
			(cond_m2_m1 and cond_m5_m3 and cond_m6_m4, lambda: eval_63()),
			(cond_m2_m1 and cond_m5_m4 and cond_m6_m3, lambda: eval_63()),
			(cond_m3_m1 and cond_m4_m2 and cond_m6_m5, lambda: eval_61()),
			(cond_m3_m1 and cond_m5_m2 and cond_m6_m4, lambda: eval_64()),
			(cond_m3_m1 and cond_m5_m4 and cond_m6_m2, lambda: eval_64()),
			(cond_m3_m2 and cond_m4_m1 and cond_m6_m5, lambda: eval_61()),
			(cond_m3_m2 and cond_m5_m1 and cond_m6_m4, lambda: eval_64()),
			(cond_m3_m2 and cond_m5_m4 and cond_m6_m1, lambda: eval_64()),
			(cond_m4_m1 and cond_m5_m2 and cond_m6_m3, lambda: eval_64()),
			(cond_m4_m1 and cond_m5_m3 and cond_m6_m2, lambda: eval_64()),
			(cond_m4_m2 and cond_m5_m1 and cond_m6_m3, lambda: eval_64()),
			(cond_m4_m2 and cond_m5_m3 and cond_m6_m1, lambda: eval_64()),
			(cond_m4_m3 and cond_m5_m1 and cond_m6_m2, lambda: eval_62()),
			(cond_m4_m3 and cond_m5_m2 and cond_m6_m1, lambda: eval_62()),
			(cond_m2_m1 and cond_m4_m3 and cond_m5_m3, lambda: eval_56()),
			(cond_m2_m1 and cond_m4_m3 and cond_m6_m3, lambda: eval_56()),
			(cond_m2_m1 and cond_m5_m3 and cond_m6_m3, lambda: eval_55()),
			(cond_m3_m1 and cond_m4_m2 and cond_m5_m2, lambda: eval_64()),
			(cond_m3_m1 and cond_m4_m2 and cond_m6_m2, lambda: eval_64()),
			(cond_m3_m1 and cond_m5_m2 and cond_m6_m2, lambda: eval_61()),
			(cond_m3_m2 and cond_m4_m1 and cond_m5_m2, lambda: eval_64()),
			(cond_m3_m2 and cond_m4_m1 and cond_m6_m2, lambda: eval_64()),
			(cond_m3_m2 and cond_m4_m2 and cond_m5_m1, lambda: eval_62()),
			(cond_m3_m2 and cond_m4_m2 and cond_m6_m1, lambda: eval_62()),
			(cond_m3_m2 and cond_m5_m1 and cond_m6_m2, lambda: eval_64()),
			(cond_m3_m2 and cond_m5_m2 and cond_m6_m1, lambda: eval_64()),
			(cond_m4_m1 and cond_m5_m2 and cond_m6_m2, lambda: eval_61()),
			(cond_m4_m2 and cond_m5_m1 and cond_m6_m2, lambda: eval_64()),
			(cond_m4_m2 and cond_m5_m2 and cond_m6_m1, lambda: eval_64()),
			(cond_m2_m1 and cond_m3_m1 and cond_m6_m5, lambda: eval_55()),
			(cond_m2_m1 and cond_m4_m1 and cond_m6_m5, lambda: eval_55()),
			(cond_m2_m1 and cond_m5_m1 and cond_m6_m4, lambda: eval_63()),
			(cond_m2_m1 and cond_m5_m4 and cond_m6_m1, lambda: eval_63()),
			(cond_m3_m1 and cond_m4_m1 and cond_m6_m5, lambda: eval_50()),
			(cond_m3_m1 and cond_m5_m1 and cond_m6_m4, lambda: eval_64()),
			(cond_m3_m1 and cond_m5_m4 and cond_m6_m1, lambda: eval_64()),
			(cond_m4_m1 and cond_m5_m1 and cond_m6_m3, lambda: eval_64()),
			(cond_m4_m1 and cond_m5_m3 and cond_m6_m1, lambda: eval_64()),
			(cond_m4_m3 and cond_m5_m1 and cond_m6_m1, lambda: eval_50()),
			(cond_m2_m1 and cond_m3_m1 and cond_m5_m4, lambda: eval_63()),
			(cond_m2_m1 and cond_m3_m1 and cond_m6_m4, lambda: eval_63()),
			(cond_m2_m1 and cond_m4_m1 and cond_m5_m3, lambda: eval_63()),
			(cond_m2_m1 and cond_m4_m1 and cond_m6_m3, lambda: eval_63()),
			(cond_m2_m1 and cond_m4_m3 and cond_m5_m1, lambda: eval_56()),
			(cond_m2_m1 and cond_m4_m3 and cond_m6_m1, lambda: eval_56()),
			(cond_m2_m1 and cond_m5_m1 and cond_m6_m3, lambda: eval_63()),
			(cond_m2_m1 and cond_m5_m3 and cond_m6_m1, lambda: eval_63()),
			(cond_m3_m1 and cond_m4_m1 and cond_m5_m2, lambda: eval_62()),
			(cond_m3_m1 and cond_m4_m1 and cond_m6_m2, lambda: eval_62()),
			(cond_m3_m1 and cond_m4_m2 and cond_m5_m1, lambda: eval_64()),
			(cond_m3_m1 and cond_m4_m2 and cond_m6_m1, lambda: eval_64()),
			(cond_m3_m1 and cond_m5_m1 and cond_m6_m2, lambda: eval_64()),
			(cond_m3_m1 and cond_m5_m2 and cond_m6_m1, lambda: eval_64()),
			(cond_m3_m2 and cond_m4_m1 and cond_m5_m1, lambda: eval_64()),
			(cond_m3_m2 and cond_m4_m1 and cond_m6_m1, lambda: eval_64()),
			(cond_m3_m2 and cond_m5_m1 and cond_m6_m1, lambda: eval_61()),
			(cond_m4_m1 and cond_m5_m1 and cond_m6_m2, lambda: eval_64()),
			(cond_m4_m1 and cond_m5_m2 and cond_m6_m1, lambda: eval_64()),
			(cond_m4_m2 and cond_m5_m1 and cond_m6_m1, lambda: eval_61()),
			(cond_m2_m1 and cond_m3_m1 and cond_m4_m1, lambda: eval_56()),
			(cond_m2_m1 and cond_m3_m1 and cond_m5_m1, lambda: eval_63()),
			(cond_m2_m1 and cond_m3_m1 and cond_m6_m1, lambda: eval_63()),
			(cond_m2_m1 and cond_m4_m1 and cond_m5_m1, lambda: eval_63()),
			(cond_m2_m1 and cond_m4_m1 and cond_m6_m1, lambda: eval_63()),
			(cond_m2_m1 and cond_m5_m1 and cond_m6_m1, lambda: eval_55()),
			(cond_m3_m1 and cond_m4_m1 and cond_m5_m1, lambda: eval_62()),
			(cond_m3_m1 and cond_m4_m1 and cond_m6_m1, lambda: eval_62()),
			(cond_m3_m1 and cond_m5_m1 and cond_m6_m1, lambda: eval_61()),
			(cond_m4_m1 and cond_m5_m1 and cond_m6_m1, lambda: eval_61()),
			(cond_m5_m4 and cond_m6_m4, lambda: eval_61()),
			(cond_m4_m3 and cond_m6_m5, lambda: eval_50()),
			(cond_m5_m3 and cond_m6_m4, lambda: eval_64()),
			(cond_m5_m4 and cond_m6_m3, lambda: eval_64()),
			(cond_m4_m3 and cond_m5_m3, lambda: eval_62()),
			(cond_m4_m3 and cond_m6_m3, lambda: eval_62()),
			(cond_m5_m3 and cond_m6_m3, lambda: eval_61()),
			(cond_m3_m2 and cond_m6_m5, lambda: eval_61()),
			(cond_m4_m2 and cond_m6_m5, lambda: eval_61()),
			(cond_m5_m2 and cond_m6_m4, lambda: eval_64()),
			(cond_m5_m4 and cond_m6_m2, lambda: eval_64()),
			(cond_m3_m2 and cond_m5_m4, lambda: eval_64()),
			(cond_m3_m2 and cond_m6_m4, lambda: eval_64()),
			(cond_m4_m2 and cond_m5_m3, lambda: eval_64()),
			(cond_m4_m2 and cond_m6_m3, lambda: eval_64()),
			(cond_m4_m3 and cond_m5_m2, lambda: eval_62()),
			(cond_m4_m3 and cond_m6_m2, lambda: eval_62()),
			(cond_m5_m2 and cond_m6_m3, lambda: eval_64()),
			(cond_m5_m3 and cond_m6_m2, lambda: eval_64()),
			(cond_m3_m2 and cond_m4_m2, lambda: eval_62()),
			(cond_m3_m2 and cond_m5_m2, lambda: eval_64()),
			(cond_m3_m2 and cond_m6_m2, lambda: eval_64()),
			(cond_m4_m2 and cond_m5_m2, lambda: eval_64()),
			(cond_m4_m2 and cond_m6_m2, lambda: eval_64()),
			(cond_m5_m2 and cond_m6_m2, lambda: eval_61()),
			(cond_m2_m1 and cond_m6_m5, lambda: eval_55()),
			(cond_m3_m1 and cond_m6_m5, lambda: eval_61()),
			(cond_m4_m1 and cond_m6_m5, lambda: eval_61()),
			(cond_m5_m1 and cond_m6_m4, lambda: eval_64()),
			(cond_m5_m4 and cond_m6_m1, lambda: eval_64()),
			(cond_m2_m1 and cond_m5_m4, lambda: eval_63()),
			(cond_m2_m1 and cond_m6_m4, lambda: eval_63()),
			(cond_m3_m1 and cond_m5_m4, lambda: eval_64()),
			(cond_m3_m1 and cond_m6_m4, lambda: eval_64()),
			(cond_m4_m1 and cond_m5_m3, lambda: eval_64()),
			(cond_m4_m1 and cond_m6_m3, lambda: eval_64()),
			(cond_m4_m3 and cond_m5_m1, lambda: eval_62()),
			(cond_m4_m3 and cond_m6_m1, lambda: eval_62()),
			(cond_m5_m1 and cond_m6_m3, lambda: eval_64()),
			(cond_m5_m3 and cond_m6_m1, lambda: eval_64()),
			(cond_m2_m1 and cond_m4_m3, lambda: eval_56()),
			(cond_m2_m1 and cond_m5_m3, lambda: eval_63()),
			(cond_m2_m1 and cond_m6_m3, lambda: eval_63()),
			(cond_m3_m1 and cond_m4_m2, lambda: eval_64()),
			(cond_m3_m1 and cond_m5_m2, lambda: eval_64()),
			(cond_m3_m1 and cond_m6_m2, lambda: eval_64()),
			(cond_m3_m2 and cond_m4_m1, lambda: eval_64()),
			(cond_m3_m2 and cond_m5_m1, lambda: eval_64()),
			(cond_m3_m2 and cond_m6_m1, lambda: eval_64()),
			(cond_m4_m1 and cond_m5_m2, lambda: eval_64()),
			(cond_m4_m1 and cond_m6_m2, lambda: eval_64()),
			(cond_m4_m2 and cond_m5_m1, lambda: eval_64()),
			(cond_m4_m2 and cond_m6_m1, lambda: eval_64()),
			(cond_m5_m1 and cond_m6_m2, lambda: eval_64()),
			(cond_m5_m2 and cond_m6_m1, lambda: eval_64()),
			(cond_m2_m1 and cond_m3_m1, lambda: eval_63()),
			(cond_m2_m1 and cond_m4_m1, lambda: eval_63()),
			(cond_m2_m1 and cond_m5_m1, lambda: eval_63()),
			(cond_m2_m1 and cond_m6_m1, lambda: eval_63()),
			(cond_m3_m1 and cond_m4_m1, lambda: eval_62()),
			(cond_m3_m1 and cond_m5_m1, lambda: eval_64()),
			(cond_m3_m1 and cond_m6_m1, lambda: eval_64()),
			(cond_m4_m1 and cond_m5_m1, lambda: eval_64()),
			(cond_m4_m1 and cond_m6_m1, lambda: eval_64()),
			(cond_m5_m1 and cond_m6_m1, lambda: eval_61()),
			(cond_m6_m5, lambda: eval_61()),
			(cond_m5_m4, lambda: eval_64()),
			(cond_m6_m4, lambda: eval_64()),
			(cond_m4_m3, lambda: eval_62()),
			(cond_m5_m3, lambda: eval_64()),
			(cond_m6_m3, lambda: eval_64()),
			(cond_m3_m2, lambda: eval_64()),
			(cond_m4_m2, lambda: eval_64()),
			(cond_m5_m2, lambda: eval_64()),
			(cond_m6_m2, lambda: eval_64()),
			(cond_m2_m1, lambda: eval_63()),
			(cond_m3_m1, lambda: eval_64()),
			(cond_m4_m1, lambda: eval_64()),
			(cond_m5_m1, lambda: eval_64()),
			(cond_m6_m1, lambda: eval_64()),
			(True, lambda: eval_64())
		]

		for condition,action in conditions:
			if condition:
				return action()

	except Exception as e:
		raise Exception(f"There was an error when evaluating the T113344 integral with masses {m1}, {m2}, {m3}, {m4}, {m5}, {m6} from {e}")